module.exports = {
  root: true,
  env: {
    browser: true, // 代码将运行在浏览器环境中
  },
  extends: [
    'standard', // 使用 standard 风格指南
    'plugin:react/recommended', // 启用 React 插件及其推荐规则
    'plugin:@typescript-eslint/recommended', // 启用 @typescript-eslint 插件及其推荐规则
    'plugin:react/jsx-runtime', // 支持 React 17 的 JSX 转换
    'plugin:prettier/recommended', // 使用 Prettier 来格式化代码，并将其集成到 ESLint 中
  ],
  parser: '@typescript-eslint/parser', // 使用 @typescript-eslint 解析器来解析 TypeScript 代码
  parserOptions: {
    tsconfigRootDir: __dirname,
    ecmaVersion: 2020, // 使用 ECMAScript 版本
    sourceType: 'module', // 允许使用 ES 模块
    project: 'tsconfig.json', // 指定 TypeScript 配置文件
    ecmaFeatures: {
      jsx: true, // 允许解析 JSX 语法
    },
  },
  plugins: [
    'react', // 启用 React 插件
    '@typescript-eslint', // 启用 @typescript-eslint 插件
    'prettier', // 启用 Prettier 插件
    'mobx', // 启用 MobX 插件
    'react-hooks', // 启用 React Hooks 插件
  ],
  rules: {
    'react/jsx-filename-extension': [1, { extensions: ['.jsx', '.tsx'] }], // 允许在 .jsx 和 .tsx 文件中使用 JSX 语法
    'react/react-in-jsx-scope': 'off', // 不要求在每个 JSX 文件中引入 React
    '@typescript-eslint/explicit-module-boundary-types': 'off', // 关闭要求在模块边界处显式定义函数返回类型的规则
    'prettier/prettier': ['error', { singleQuote: true, jsxSingleQuote: true }],
    'react-hooks/rules-of-hooks': 'error', // 检查 Hook 的规则
    'react-hooks/exhaustive-deps': 'warn', // 检查 effect 依赖
    'no-console': process.env.NODE_ENV === 'production' ? 'warn' : 'off',
    'no-debugger': process.env.NODE_ENV === 'production' ? 'warn' : 'off',
    // 其他规则
    /** ts 相关规则 */
    '@typescript-eslint/naming-convention': [
      'error',
      {
        selector: 'interface',
        format: ['PascalCase'],
        prefix: ['I'],
      },
      {
        selector: 'typeAlias',
        format: ['PascalCase'],
        // prefix: ['T'],
      },
      {
        selector: 'enum',
        format: ['PascalCase'],
        prefix: ['E'],
      },
    ], // interface 必须以I开头，type必须以T开头，enum必须以E开头
    '@typescript-eslint/explicit-member-accessibility': 0, // 允许省略类成员的访问修饰符
    '@typescript-eslint/explicit-function-return-type': 0, // 允许省略函数返回类型
    '@typescript-eslint/no-empty-interface': 0, // 允许定义空接口
    '@typescript-eslint/no-explicit-any': 0, // 允许使用 `any` 类型
    '@typescript-eslint/no-object-literal-type-assertion': 0, // 允许对象字面量类型断言

    '@typescript-eslint/no-use-before-define': 0, // 允许在定义之前使用变量
    '@typescript-eslint/no-var-requires': 0, // 允许使用 `require` 语法
    '@typescript-eslint/no-inferrable-types': 0, // 允许对推断类型进行显式类型声明
    '@typescript-eslint/no-unused-vars': 1, // 定义未使用，警告
    /** react 相关规则 */
    /** js 相关配置 */
    'no-use-before-define': 0,
    'jsx-quotes': [1, 'prefer-single'], // 推荐使用单引号
    'no-var': 2, // 要求使用 let 或 const 而不是 var
    'no-useless-constructor': 0, // 允许不必要的构造函数
    'no-undef': 0, // 允许未定义的变量
    'one-var': 0, // 允许多变量声明
    'no-new-func': 0, // 允许使用 Function 构造函数
    'no-unused-expressions': 0, // 允许未使用的表达式
    quotes: [2, 'single'], // 强制使用单引号
    'no-constant-condition': 0, // 允许常量条件
    'no-mixed-operators': 0, // 允许混合操作符
    'no-useless-return': 0, // 允许不必要的 return
    'no-return-await': 0, // 允许 return await
    'no-unreachable': 0, // 允许无法到达的代码
    'no-new': 0, // 允许使用 new 操作符
    'comma-dangle': [0, 'always-multiline'], // 允许多行时尾逗号
    'lines-between-class-members': 0, // 允许类成员之间没有空行
    'react/prop-types': 0,
  },
  settings: {
    react: {
      version: 'detect',
    },
  },
}
