import { FC, useState } from 'react'
import { DtApp } from '@dt/ui-mobile'
import { IonReactHashRouter } from '@ionic/react-router'
import { useInitNotice } from '@init/notice'
import { ApolloProvider } from '@apollo/client'
import { client } from '@dt/fe-business'
import RouterDashboard from './RouterDashboard'
import { AgreementModal, Preview } from '@cps'
import ENV from '@env'
import { localStore } from '@dt/fe-base'
import { getDeviceId } from '@utils/device'
import AppUpdateModal from '@cps/modals/AppUpdateModal'

import('./App.global.scss')

const App: FC = () => {
  document.title = ENV.env + '*壹向RMS'
  /**
   *  全局监听消息变化，用于从通知跳转对应页面
   */
  useInitNotice()
  const isAgreement = localStore.get('ls.agreement')
  const [isAgreementModal, setIsAgreementModal] = useState(isAgreement)
  const [showSimple, setShowSimple] = useState(false)
  const handleAgreement = async () => {
    setIsAgreementModal(true)
    setShowSimple(false)
    // 获取设备 id
    const deviceId = await getDeviceId('rms')
    window.Config.deviceId = deviceId
    localStore.set('ls.currentDeviceId', deviceId)
    window.__eventBus.emit(window.__eventBus.eventEnumMap.AgreementSuccess, {
      deviceId,
    })
  }
  return (
    <DtApp className='app-container'>
      {isAgreementModal ? (
        <ApolloProvider client={client}>
          <IonReactHashRouter>
            <RouterDashboard />
          </IonReactHashRouter>
          <AppUpdateModal />
        </ApolloProvider>
      ) : (
        <>
          <AgreementModal
            onAgree={handleAgreement}
            onCancel={() => setShowSimple(true)}
          />
          {showSimple && <Preview onAgreement={handleAgreement} />}
        </>
      )}
    </DtApp>
  )
}

export default App
