import React from 'react'
import { classNames } from '@dt/fe-base'
import { DtIcon, DtItemBlock, DtMenuButton } from '@dt/ui-mobile'
import { appMobx, routeMangerMobx } from '@mobx'
import CustomerServicerIcon from '../CustomerServicer'

import type { IMenuItem } from '@mobx/route.mobx'
import { observer } from 'mobx-react'
import './Link.scss'
import { useHistory } from 'react-router-dom'

function matchRoute(pathname: string, path: string) {
  const regex = new RegExp(`^${path}/?$`)
  if (regex.test(pathname)) {
    return true // 如果匹配成功，返回 true
  }
  return false // 如果没有匹配的路由，返回 false
}

const Link: React.FC<IMenuItem> = (props) => {
  const { icon, path, label } = props
  const _ns = 'link-item'
  const { curPath } = appMobx
  const isActive = matchRoute(curPath, path)
  const history = useHistory()
  const handleChange = () => {
    history.replace(`${path}`)
  }

  if (path === '/chat') {
    return <CustomerServicerIcon />
  }

  return (
    <DtMenuButton
      className={classNames(_ns, {
        [`${_ns}-active`]: isActive,
      })}
      id={path.replace(/\//g, '')}
      onClick={handleChange}
    >
      <div className='menu-btn'>
        {path === '/home' && (
          <div className='icon'>
            {icon && (
              <DtIcon
                icon={icon}
                style={{
                  fontSize: 24,
                  color: 'var(--dt-text-high)',
                  marginRight: 12,
                }}
              />
            )}
          </div>
        )}
        <div
          className={classNames('title', {
            'title-single': path === '/home',
          })}
        >
          {label?.()}
        </div>
      </div>
    </DtMenuButton>
  )
}

export default observer(Link)
