import React from 'react'
import { DtIcon } from '@dt/ui-mobile'
import { appMobx } from '@mobx'
import Link from './Link'
import type { IMenuItem } from '@mobx/route.mobx'
import { observer } from 'mobx-react'
import './MenuWrap.scss'
import { useHistory } from 'react-router-dom'
import i18n from '@dt/fe-base/dist/i18n'
import { chevronRight } from '@dt/ui-ionic-icon'

type TGroup = {
  label?: string
  menu: IMenuItem[]
  key: string
}
interface IProps {
  o?: TGroup
  isExpand?: boolean
  setIsExpandMenu: (menu: string) => void
}
const MenuWrap: React.FC<IProps> = (props) => {
  const { o, isExpand, setIsExpandMenu } = props
  const _ns = 'link-item'
  const { curPath } = appMobx
  const history = useHistory()

  return (
    <div className='menu-wrap'>
      {o?.label && (
        <div
          className='menu-head'
          onClick={() => {
            if (isExpand) {
              setIsExpandMenu('')
            } else {
              setIsExpandMenu(o?.key || '')
            }
          }}
        >
          <div className='icon'>
            {
              <DtIcon
                icon={o?.menu[0]?.icon}
                style={{
                  fontSize: 24,
                  color: 'var(--dt-text-high)',
                  marginRight: 12,
                }}
              />
            }
          </div>

          <div className='title'>{i18n.t(`menu.${o.label}`)}</div>
          {isExpand ? (
            <DtIcon
              icon={chevronRight}
              className='icon-right icon-right-expand'
            />
          ) : (
            <DtIcon icon={chevronRight} className='icon-right' />
          )}
        </div>
      )}
      {!o?.label &&
        o?.menu.length === 1 &&
        o?.menu?.map((m) => <Link key={m.path} {...m}></Link>)}
      {isExpand && (
        <div className='menu-item-list-wrap'>
          {o?.menu?.map((m) => <Link key={m.path} {...m}></Link>)}
          {/* <div className='menu-item-wrap'> */}
          {/* </div> */}
        </div>
      )}
    </div>
  )
}

export default observer(MenuWrap)
