import {
  DtContent,
  DtHeader,
  DtMenu,
  DtMenuToggle,
  DtItemBlock,
} from '@dt/ui-mobile'
import React, { useEffect, useState, useRef, useMemo } from 'react'
import {
  DtBusinessAvatar,
  DtTaskMask,
  EDtTaskType,
  ITaskMaskProps,
} from '@dt/ui-mobile-business'
import { useHistory, useLocation } from 'react-router-dom'
import { routeMangerMobx } from '@mobx'
import { observer } from 'mobx-react'
import { localStore as store, classNames } from '@dt/fe-base'
import { useSafeArea } from '@common/hooks/useSafeArea'
import { App } from '@dt/fe-capacitor'
import MessageIcon, { IMessageIconRefs } from '../MessageIcon'
import './index.scss'
import i18n from '@dt/fe-base/dist/i18n'
import { PermissionSdk } from '@dt/fe-business'
import NoPermissionModal from '@cps/modals/NoPermissionModal'
import taskMobx from '@mobx/task.mobx'
import MenuWrap from './MenuWrap'
import CustomerServicerIcon from '../CustomerServicer'

const rootPaths = [
  '/home',
  '/storeDetail',
  '/mainline/home',
  '/mainline/device',
  '/menu/product',
  '/mainline/kitchen',
  '/user/user',
  '/setting/home',
  '/supply/goods',
  '/supply/order',
  '/supply/supplier',
  '/supply/report',
  '/report/home',
]

const takeTypeConfigMap = {
  [EDtTaskType.OPEN_PRODUCT]: {
    path: '/menu/product',
    id: 'menuproduct',
  },
  [EDtTaskType.OPEN_POS_DEVICE]: {
    path: '/mainline/device',
    id: 'mainlinedevice',
  },
  [EDtTaskType.OPEN_PRINTER]: {
    path: '/mainline/device',
    id: 'mainlinedevice',
  },
  [EDtTaskType.OPEN_POS_ORDER]: {
    path: '/mainline/home',
    id: 'mainlinehome',
  },
  [EDtTaskType.OPEN_WECHAT_ALIPAY]: {
    path: '/mainline/home',
    id: 'mainlinehome',
  },
  [EDtTaskType.OPEN_USER]: {
    path: '/user/user',
    id: 'useruser',
  },
  [EDtTaskType.OPEN_TAKEOUT_MEITUAN]: {
    path: '/mainline/home',
    id: 'mainlinehome',
  },
  [EDtTaskType.OPEN_TAKEOUT_ELEME]: {
    path: '/mainline/home',
    id: 'mainlinehome',
  },
}

const Menu: React.FC<React.PropsWithChildren> = (props) => {
  const _ns = 'menu-view'
  const history = useHistory()
  const location = useLocation()
  const [safeArea] = useSafeArea()
  const [paddingTop, setPaddingTop] = useState<string>('')
  const [userInfo, setUserInfo] = useState({
    userName: '',
    roleInfo: {
      total: 0,
      data: {
        roleId: '',
        roleName: '',
      },
    },
    phone: '',
  })
  const [brandInfo, setBrandInfo] = useState({
    logo: '',
    storeName: '',
    brandName: '',
    brandId: '',
  })
  const [noPermissionModal, setNoPermissionModal] = useState(false)

  const [disabled, setDisabled] = useState(false)
  const [swipeGesture, setSwipeGesture] = useState(false)
  const [isShowMenu, setIsShowMenu] = useState(false)
  const pathName = useRef('')
  const messageRef = useRef<IMessageIconRefs>(null)
  const contentRef = useRef<any>(null)
  const [isOpenTask, setIsOpenTask] = useState(false)
  const [isExpandMenu, setIsExpandMenu] = React.useState('')
  const [messageCount, setMessageCount] = useState(0)
  /** 任务弹窗 */
  const taskOptions = useMemo(() => {
    if (!taskMobx.targetTask) {
      return {
        isOpen: false,
        steps: [],
      }
    }
    const targetStep = () => {
      const config = takeTypeConfigMap[taskMobx.targetTask!]
      if (!config) return null
      return {
        target: `#${config.id}`,
        targetId: 'menu-view-btn',
        popover: {
          content: <h2>{i18n.t(`task.popover.${taskMobx.targetTask}`)}</h2>,
          placement:
            taskMobx.targetTask === EDtTaskType.OPEN_USER ? 'top' : 'bottom',
        },
        padding: 0,
        handle: () => {
          ;(document?.getElementById(config.id) as any)?.click()
          setIsOpenTask(false)
        },
      }
    }
    return {
      isOpen: true,
      nextType: 'touchChild',
      steps: [targetStep()],
      onClose: () => {
        setIsOpenTask(false)
      },
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [taskMobx.targetTask])
  // 链接
  const handleTo = (path: string) => {
    history.replace(path)
  }

  useEffect(() => {
    App.getPlatform() !== 'web' &&
      setPaddingTop(`${safeArea?.top ? safeArea?.top : ''}`)
  }, [safeArea])

  useEffect(() => {
    pathName.current = location.pathname
    if (location.pathname.includes('/login')) {
      setDisabled(true)
    } else {
      setDisabled(false)
    }
    if (rootPaths.includes(location.pathname)) {
      setSwipeGesture(true)
    } else {
      setSwipeGesture(false)
    }
  }, [location])

  useEffect(() => {
    window.__eventBus.on(
      window.__eventBus?.eventEnumMap?.FinishChangeStore,
      () => {
        if (
          [
            '/mainline/device',
            '/mainline/home',
            '/menu/product',
            '/mainline/kitchen',
          ].includes(pathName.current)
        ) {
          !PermissionSdk.checkModulePermissionKey(pathName.current) &&
            setNoPermissionModal(true)
        }
      },
    )
    setMessageCount(window?.DtMsgUnReadCount || 0)
    const msgCountId = window.__eventBus.on(
      window.__eventBus?.eventEnumMap?.DtMsgUnreadCountUpdate,
      (res: any) => {
        setMessageCount(res || 0)
      },
    )
    return () => {
      if (msgCountId !== undefined) {
        window.__eventBus?.off(msgCountId)
      }
    }
  }, [])

  /** 滚动到指定元素 id */
  const scrollIntoView = (lineId: string) => {
    document
      .getElementById(lineId)
      ?.scrollIntoView({ block: 'start', behavior: 'smooth' })
    console.log('scrollIntoView', lineId)
  }

  return (
    <DtMenu
      disabled={disabled}
      swipeGesture={swipeGesture}
      contentId='mobile-hq-page-content'
      id='menu-view-wrapper'
      className={_ns}
      onIonDidOpen={() => {
        setIsShowMenu(true)
      }}
      onIonDidClose={() => {
        setIsShowMenu(false)
      }}
      onIonWillOpen={() => {
        setUserInfo({
          userName:
            window.userInfo?.userName ||
            window.userInfo?.phone ||
            window.userInfo?.email ||
            '',
          roleInfo: window.userInfo?.roleInfo || { total: 0, data: {} },
          phone: window.userInfo?.phone || '',
        })
        setBrandInfo({
          logo: store.get('ls.brandInfo')?.logo || '',
          storeName: store.get('ls.storeInfo')?.storeName || '',
          brandName: store.get('ls.brandInfo')?.brandName || '',
          brandId: store.get('ls.brandInfo')?.brandId || '',
        })
        messageRef.current?.fetchMsgCount()
        if (taskMobx.targetTask) {
          const config = takeTypeConfigMap[taskMobx.targetTask!]
          scrollIntoView(config.id)
          setIsOpenTask(true)
        }
      }}
    >
      <DtHeader style={{ paddingTop: `${paddingTop}px` }}>
        <div className='header'>
          <DtMenuToggle
            className='brand-setting'
            onClick={() => {
              // handleTo('/setting/home')
              window.$DtMobx?.brandMobx?.setBrandEdit(true)
              history.push('/brand')
            }}
          >
            <DtBusinessAvatar url={brandInfo.logo} />
            <div className='brand-info'>
              <div className='title'>{brandInfo.brandName}</div>
              <div className='user-info'>
                <span className='user-name'>
                  {i18n.t('brand.idTitle')}：{brandInfo.brandId}
                </span>
              </div>
            </div>
          </DtMenuToggle>
          <CustomerServicerIcon />
        </div>
      </DtHeader>
      <DtContent className='menu-content' ref={contentRef} scrollEvents={true}>
        <div className='menu-list-wrap'>
          {routeMangerMobx.layoutMenu.map((o) => {
            if (!o.menu.length) {
              return null
            }
            return (
              <>
                <MenuWrap
                  o={o}
                  isExpand={isExpandMenu === o.key || window.runingTaskType}
                  setIsExpandMenu={setIsExpandMenu}
                />
              </>
            )
          })}
        </div>

        <div className='m-v-bottom-wrap'>
          <DtMenuToggle
            className='left-user-wrap'
            onClick={() => {
              handleTo('/setting/home')
            }}
          >
            <div className='l-content'>
              <div className='l-username'>Hello, {userInfo.userName}</div>
              <div className='l-phone'>{userInfo?.phone}</div>
            </div>
            {messageCount > 0 && (
              <div className='message-icon'>{messageCount}</div>
            )}
          </DtMenuToggle>
        </div>
      </DtContent>
      <NoPermissionModal
        visible={noPermissionModal}
        onClose={() => setNoPermissionModal(false)}
      />
      {props.children}
      {isShowMenu && isOpenTask && !!taskOptions && (
        <DtTaskMask {...(taskOptions as ITaskMaskProps)} />
      )}
    </DtMenu>
  )
}

export default observer(Menu)
