import { DtMenuButton } from '@dt/ui-mobile'
import React, { forwardRef, useEffect, useState } from 'react'
import { useLocation, useHistory } from 'react-router'
import './index.scss'
import { Inbox } from '@novu/react'
import ENV from '@env'
import { dark } from '@novu/react/themes'

export interface IMessageIconRefs {
  fetchMsgCount: () => void
}

const MessageIcon = forwardRef<IMessageIconRefs>((_, ref) => {
  const history = useHistory()
  const location = useLocation()

  const [isDarkMode, setIsDarkMode] = useState(false)

  useEffect(() => {
    const theme = localStorage.getItem('ls.currentTheme')
    setIsDarkMode(theme === 'dark')
  }, [location])

  const handleTo = (path: string) => {
    history.replace(path)
  }
  return (
    <DtMenuButton
      className='message-icon'
      onClick={() => {
        handleTo('/novu-message')
      }}
    >
      <div className='message-icon__main'>
        <Inbox
          subscriberId={ENV.novu.subscribe_prefix + window?.userInfo?.userId}
          applicationIdentifier={ENV.novu.applicationIdentifier}
          backendUrl={ENV.novu.backendUrl}
          socketUrl={ENV.novu.socketUrl}
          appearance={{
            baseTheme: isDarkMode ? dark : undefined,
            elements: {
              bellDot: {
                backgroundColor: 'var(--dt-error)',
              },
              bellContainer: {
                color: 'var(--dt-text-middle)',
              },
              bellIcon: {
                width: '24px',
                height: '24px',
              },
            },
          }}
          open={false}
        ></Inbox>
      </div>
    </DtMenuButton>
  )
})

MessageIcon.displayName = 'MessageIcon'

export default React.memo(MessageIcon)
