import React, { useEffect, useState } from 'react'
import { NovuProvider, useNovu } from '@novu/react'
import ENV from '@env'

interface INovuWarpperProps {
  children: React.ReactNode
}

const NovuWarpperHandle = () => {
  const novu = useNovu()
  useEffect(() => {
    const getUnreadCount = async () => {
      const { data } = await novu.notifications.count({ read: false })
      console.log('novu消息获取', data)
      window.DtMsgUnReadCount = data?.count || 0
      window.__eventBus?.emit(
        window.__eventBus?.eventEnumMap?.DtMsgUnreadCountUpdate,
        data?.count || 0,
      )
    }

    getUnreadCount()

    const handleId = window.__eventBus.on(
      window?.__eventBus?.eventEnumMap?.FinishUpdateBrand,
      getUnreadCount,
    )

    const clear = novu?.on('notifications.unread_count_changed', (res) => {
      window.DtMsgUnReadCount = res.result || 0
      window.__eventBus?.emit(
        window.__eventBus?.eventEnumMap?.DtMsgUnreadCountUpdate,
        res.result || 0,
      )
    })

    return () => {
      clear()
      window.__eventBus?.off(handleId)
    }
  }, [novu])

  return null
}

export default function NovuWarpper({ children }: INovuWarpperProps) {
  const [subscriberId, setSubscriberId] = useState(
    ENV.novu.subscribe_prefix + window?.userInfo?.userId,
  )
  useEffect(() => {
    const handleId = window.__eventBus?.on(
      window.__eventBus?.eventEnumMap?.UserInfoUpdate,
      (userInfo: any) => {
        setSubscriberId(ENV.novu.subscribe_prefix + userInfo?.userId)
      },
    )

    return () => {
      window.__eventBus?.off(handleId)
    }
  }, [])

  return (
    <NovuProvider
      subscriberId={subscriberId}
      applicationIdentifier={ENV.novu.applicationIdentifier}
      backendUrl={ENV.novu.backendUrl}
      socketUrl={ENV.novu.socketUrl}
    >
      <NovuWarpperHandle />
      {children}
    </NovuProvider>
  )
}
