import { createAnimation } from '@dt/ui-mobile'

/**
 * 页面切换
 * @param baseEl
 * @param opts
 * @returns
 */
export const pageAnimation = (baseEl: HTMLElement, opts?: any) => {
  console.log('pageAnimation', opts)
  const enteringAnimation = createAnimation()
    .addElement(opts.enteringEl)
    .fromTo('transform', 'translateX(100%)', 'translateX(0)')
    .fromTo('opacity', 0, 1)
  const leavingAnimation = createAnimation()
    .addElement(opts.leavingEl)
    .fromTo('transform', 'translateX(0)', 'translateX(100%)')
    .fromTo('opacity', 1, 0)
  const swipeBackAnimation = createAnimation()
    .addElement(opts.leavingEl)
    .fromTo('transform', 'translateX(0)', 'translateX(100%)')
    .fromTo('opacity', 1, 1)
    .afterStyles({ display: 'none' })
    .onFinish((e, animation) => {
      if (e === 0 && animation?.elements?.[0]) {
        animation.elements[0].style.display = ''
      }
    })

  const animation = createAnimation()

  /** 只要顶层的页面切换 */
  const enterIndex = Number(opts.enteringEl?.style.zIndex || '1')
  const leavingIndex = Number(opts.leavingEl?.style.zIndex || '0')
  if (enterIndex >= leavingIndex) {
    animation.duration(200).addAnimation([enteringAnimation])
  } else {
    animation
      .duration(opts.progressAnimation ? 1 : 200)
      .addAnimation([
        opts.progressAnimation ? swipeBackAnimation : leavingAnimation,
        createAnimation().addElement(opts.enteringEl).fromTo('opacity', 1, 1),
      ])
  }
  return animation
}

export const menuAnimation = (baseEl: HTMLElement) => {
  const enteringAnimation = createAnimation()
    .addElement(baseEl)
    .fromTo('transform', 'translateX(0)', 'translateX(100%)')
  const leavingAnimation = createAnimation()
    .addElement(baseEl)
    .fromTo('transform', 'translateX(100%)', 'translateX(0)')

  const animation = createAnimation().duration(150)

  return {
    enteringAnimation,
    leavingAnimation,
  }
}

interface IEnterAnimationOpt {
  keyframes?: any[] | undefined
  duration?: number
  backdrop?: boolean
  wrapperEle?: string
  wrapperDuration?: number
  easing?: string
  opacity?: string
}

export const animationFunc = (baseEl: any, opts?: IEnterAnimationOpt) => {
  const root = baseEl.shadowRoot
  const duration = opts?.duration || 200
  const backdrop = opts?.backdrop || true
  const easing = opts?.easing || 'ease-out'
  const opacity = opts?.opacity || '0.01'
  const wrapperEle = opts?.wrapperEle || '.modal-wrapper'
  const wrapperDuration = opts?.wrapperDuration
  const keyframes = opts?.keyframes || [
    { offset: 0, opacity: '0', transform: 'translateY(50%)' },
    { offset: 1, opacity: '1', transform: 'translateY(0)' },
  ]

  const backdropAnimation = createAnimation()
    .addElement(root?.querySelector('ion-backdrop'))
    .fromTo('opacity', opacity, 'var(--backdrop-opacity)')

  const wrapperAnimation = createAnimation()
    .addElement(root?.querySelector(wrapperEle))
    .duration(wrapperDuration || duration)
    .keyframes(keyframes)

  return createAnimation()
    .addElement(baseEl)
    .easing(easing)
    .duration(200)
    .addAnimation(
      backdrop ? [backdropAnimation, wrapperAnimation] : [wrapperAnimation],
    )
}

export const fullEnterAnimation = (baseEl: any) =>
  animationFunc(baseEl, {
    duration: 150,
    backdrop: false,
    keyframes: [
      { offset: 0, opacity: '0', transform: 'translateY(100%)' },
      { offset: 1, opacity: '1', transform: 'translatey(0)' },
    ],
  })

export const fullLeaveAnimation = fullEnterAnimation
  ? (baseEl: any) => fullEnterAnimation(baseEl).direction('reverse')
  : undefined

export const menuOpenContentAnimation = (baseEl: any) => {
  return createAnimation()
    .addElement(baseEl)
    .duration(100)
    .fromTo('scale', 1, 0.85)
    .fromTo('left', '0', '5vw')
    .fromTo('borderRadius', '0', '32px')
}

export const menuCloseContentAnimation = (baseEl: any) => {
  return createAnimation()
    .addElement(baseEl)
    .duration(100)
    .fromTo('scale', 0.85, 1)
    .fromTo('left', '5vw', '0')
    .fromTo('borderRadius', '32px', '0px')
}
