import { EEventNames } from './enum'

let handleId = 0
function getHandleId() {
  return ++handleId
}

class EventBus {
  /** 事件枚举 */
  eventEnumMap: any = EEventNames

  /** event bus map */
  private eventBusMap: any = {}

  /** handle map */
  private handleMap: any = {}

  /** 单次 handlemap */
  private onceHandleMap: any = {}

  /** 事件监听 */
  on(event: string, callback: (data?: any) => any): number
  on(event: string[], callback: (data?: any) => any): number[]
  on(
    event: string | string[],
    callback: (data?: any) => any,
  ): number | number[] {
    if (Array.isArray(event)) {
      return event.map((e) => this.on(e, callback))
    } else {
      if (!this.eventBusMap[event]) {
        this.eventBusMap[event] = {}
      }
      const handleId = getHandleId()
      this.eventBusMap[event][handleId] = callback
      this.handleMap[handleId] = event
      return handleId
    }
  }

  /** 监听一次的事件（触发一次后会自动off） */
  once(event: EEventNames, callback: any) {
    const theOnceHandleId = this.on(event, callback)
    this.onceHandleMap[theOnceHandleId] = 1
    return theOnceHandleId
  }

  /** 取消一个订阅，如果传入句柄则取消某一个订阅 */
  off(eventOrHandleId: string | number | number[]) {
    if (typeof eventOrHandleId === 'string') {
      delete this.eventBusMap[eventOrHandleId]
    } else {
      const handleIds =
        typeof eventOrHandleId === 'number'
          ? [eventOrHandleId]
          : eventOrHandleId

      // handleIds
      handleIds.forEach((handleId) => {
        const event = this.handleMap[handleId]
        if (event) {
          delete this.eventBusMap[event][handleId]
          delete this.handleMap[handleId]
        }
      })
    }
  }

  /** 制造一个事件 */
  emit(event: string, data: any) {
    this.broadcast(event, data)
  }

  /** 广播一个事件 */
  broadcast(event: string, data: any) {
    if (this.eventBusMap[event]) {
      for (const handleId in this.eventBusMap[event]) {
        this.eventBusMap[event][handleId](data)
        // 对于处理一次的事件，触发即销毁
        if (this.onceHandleMap[handleId]) {
          this.off(handleId)
          delete this.onceHandleMap[handleId]
        }
      }
    }
  }
}

const eventBus = new EventBus()

window.__eventBus = eventBus
