import React, { useEffect } from 'react'
import { useHistory } from 'react-router-dom'

/**
 * 路由监听
 * @desc 解决首次路由进入时不会触发history.listen
 * @param {RouteComponentProps['history']} history - react-routet-dom的history
 * @param fn - 监听的回调
 */
export const useHistoryListen = (fn: (pathname: string) => void) => {
  const history = useHistory()
  useEffect(() => {
    const pathname = history?.location?.pathname || ''
    fn?.(pathname)
    const unregisterListener = history.listen(({ pathname }) => {
      fn?.(pathname)
    })
    return () => {
      unregisterListener()
    }
  }, [fn, history])
}

type TReturnType<T extends (...args: any[]) => any> = T extends (
  ...args: any[]
) => infer R
  ? R
  : never
type TNewHistory = TReturnType<typeof useHistoryNew>

let baseHistory: TNewHistory
// eslint-disable-next-line @typescript-eslint/no-unused-vars
let ionRoute: any

/** 设置全局history,允许在非页面内使用 */
export function setHistoryNew(_history: TNewHistory) {
  baseHistory = _history
}
/** 使用全局history */
export function getHistoryNew() {
  return baseHistory
}
/** 设置全局路由 */
export function setIonRoute(_ionRoute: any) {
  ionRoute = _ionRoute
}
/** 使用全局路由 */
export function useHistoryNew() {
  const history = useHistory()
  return history
}
