import { Capacitor } from '@capacitor/core'
import { AdvertisingId } from '@capacitor-community/advertising-id'
import ID5 from '@id5io/id5-api.js'
import { Device } from '@capacitor/device'
import { localStore } from '@dt/fe-base'

export async function getDeviceId(appKey: string): Promise<any> {
  if (Capacitor.getPlatform() !== 'web') {
    const requestTracking = await AdvertisingId.requestTracking()
    if (requestTracking.value === 'Authorized') {
      const getAdvertisingId = await AdvertisingId.getAdvertisingId()
      return `${getAdvertisingId.id}_${appKey}`
    } else {
      return Device.getId().then((deviceId) => {
        return `${deviceId.identifier}_${appKey}`
      })
    }
  } else {
    const deviceInfo = localStore.get('ls.deviceInfo')
    if (deviceInfo?.deviceId) {
      return Promise.resolve(deviceInfo?.deviceId)
    }
    const id5Instance = ID5.init({ partnerId: 173 })
    return new Promise((resolve) => {
      id5Instance.onAvailable(function (status: any) {
        if (status) {
          const id5Id = status.getUserId()
          if (id5Id) {
            return resolve(status.getUserId().replace('ID5*', ''))
          }
        }
        return resolve([Date.now(), Math.floor(Math.random() * 10000)].join(''))
      }, 5000)
    })
  }
}
