/** utils */

import { BrandBrand } from '@gql/graphql'
import { brandMobx, storeMobx } from '@mobx'
import { localStore as store } from '@dt/fe-base'

/**
 * 判断文件类型
 * @param filePath 文件路径
 * @returns
 */
export function getFileType(filePath: string): 'img' | 'video' | undefined {
  // 定义图片和视频的扩展名
  const imageExtensions = ['jpg', 'jpeg', 'png', 'gif', 'bmp', 'svg']
  const videoExtensions = ['mp4', 'mov', 'wmv', 'flv', 'avi', 'mkv', 'webm']

  // 使用正则表达式提取文件扩展名
  // eslint-disable-next-line no-useless-escape
  const extensionMatch = filePath.match(/\.([0-9a-z]+)(?:[\?#]|$)/i)
  if (extensionMatch && extensionMatch[1]) {
    const extension = extensionMatch[1].toLowerCase()

    // 判断扩展名是否属于图片或视频
    if (imageExtensions.includes(extension)) {
      return 'img'
    } else if (videoExtensions.includes(extension)) {
      return 'video'
    }
  }

  // 如果扩展名既不是图片也不是视频，则返回'unknown'
  return undefined
}

export const changeStore = async (storeId: number) => {
  await storeMobx.setCurrentStore(storeId)
}

/**
 * 切换品牌，门店肯定变了
 * @param brandId 品牌id
 * @param storeId 门店id
 */
export const changeBrand = async (
  brandId: number,
  storeId: number,
  callback?: () => void,
) => {
  if (brandId) {
    // 品牌列表中存在该品牌id
    if (brandMobx.brandList.some((item) => item.brandId === brandId)) {
      // 切换品牌
      await brandMobx.switchBrand({ newBrandId: brandId })
      await brandMobx.setBrandInfo(
        brandMobx.brandList.find((item) => item.brandId === brandId) ||
          ({} as BrandBrand),
      )
      // 重新获取门店信息
      await storeMobx.getStoreList(false)
      // 并设置门店
      await storeMobx.setCurrentStore(storeId)
      await callback?.()
    }
  }
}

export const clearStore = () => {
  // 登录退出时，保留颜色配置信息
  const colorMode = store.get('ls.colorMode')
  const currentDeviceId = store.get('ls.currentDeviceId')
  localStorage.clear()
  store.set('ls.colorMode', colorMode)
  store.set('ls.currentDeviceId', currentDeviceId)
}
