import React, { FC, useEffect, useState } from 'react'
import { DtModal, DtDatetime } from '@dt/ui-mobile'
import Icon from '../../../elements/Icon'
import './timeSelectModal.scss'

interface ITimeSelectModalProps {
  isOpen: boolean
  onOk: (val: any) => void
  onCancel: () => void
  value?: string
}

const TimeSelectModal: FC<ITimeSelectModalProps> = (props) => {
  const _ns = 'time-select-modal'
  const { isOpen, onOk, onCancel, value } = props
  const [time, setTime] = useState<string>('2024-06-19T00:00:00')

  useEffect(() => {
    setTime(`2024-06-19T${value}:00`)
  }, [value])

  return (
    <DtModal
      className={_ns}
      isOpen={isOpen}
      onWillDismiss={() => {
        onCancel()
      }}
    >
      <div>
        <div className='close-line '>
          <div
            className='close-box'
            onClick={() => {
              const str = time.split('T')[1].split(':')
              onOk(`${str[0]}:${str[1]}`)
            }}
          >
            <Icon name='success' size={24} />
          </div>
        </div>
        <DtDatetime
          presentation='time'
          size='cover'
          value={time}
          preferWheel={true}
          className='time-select'
          onIonChange={(e) => {
            setTime(e.detail.value as string)
          }}
        />
      </div>
    </DtModal>
  )
}

export default TimeSelectModal
