import i18n from '@dt/fe-base/dist/i18n'
import { DtButton, DtImg } from '@dt/ui-mobile'
import IMG_DARK from '@img/preview/dark_bg.png'
import IMG_LIGHT from '@img/preview/light_bg.png'
import IMG_EASY from '@img/preview/easy.png'
import IMG_EASY_LIGHT from '@img/preview/easy_light.png'
import IMG_FAST from '@img/preview/fast.png'
import IMG_FAST_LIGHT from '@img/preview/fast_light.png'
import IMG_AGILE from '@img/preview/agile.png'
import IMG_AGILE_LIGHT from '@img/preview/agile_light.png'
import IMG_ORDER from '@img/preview/order.png'
import IMG_ORDER_LIGHT from '@img/preview/order_light.png'
import IMG_PHONE_1 from '@img/preview/phone1.png'
import IMG_PHONE_2 from '@img/preview/phone2.png'
import IMG_PHONE_3 from '@img/preview/phone3.png'
import IMG_PHONE_4 from '@img/preview/phone4.png'
import { App } from '@dt/fe-capacitor'
import { localStore } from '@dt/fe-base'
import { ExitApp } from 'capacitor-exit-app'
import PrivacyText from '../../modals/PrivacyText'
import ServiceText from '../../modals/ServiceText'

import './index.scss'

interface IProps {
  onAgreement: () => void
}

const Preview = ({ onAgreement }: IProps) => {
  const isLight = localStore.get('ls.currentTheme') === 'light'
  const bg =
    localStore.get('ls.currentTheme') === 'light' ? IMG_LIGHT : IMG_DARK
  const _ns = 'preview'
  const handleCancel = () => {
    if (App.isNativePlatform()) {
      ExitApp.exitApp()
    } else {
      window.location.href = ''
    }
  }
  const handleAgreement = () => {
    localStore.set('ls.agreement', true)
    onAgreement()
  }
  return (
    <div className={`${_ns}`}>
      <div
        style={{ backgroundImage: `url(${bg})` }}
        className={`${_ns}__container`}
      >
        <div className={`${_ns}__header`}>
          <div className={`${_ns}__header__title`}>
            {i18n.t('agreement.previewTitle')}
          </div>
          <div className={`${_ns}__header__sub-title`}>
            {i18n.t('agreement.previewDesc')}
          </div>
          <div className={`${_ns}__header__line`} />
        </div>
        <div className={`${_ns}__content`}>
          <div
            className={`${_ns}__content__header`}
            style={{
              backgroundImage: `url(${isLight ? IMG_EASY_LIGHT : IMG_EASY})`,
            }}
          >
            <div>{i18n.t('agreement.previewBtn1')}</div>
            <div>{i18n.t('agreement.previewBtn2')}</div>
          </div>
          <div className={`${_ns}__content__phone`}>
            <DtImg src={IMG_PHONE_1} />
          </div>
        </div>
        <div className={`${_ns}__content`}>
          <div
            className={`${_ns}__content__header`}
            style={{
              backgroundImage: `url(${isLight ? IMG_FAST_LIGHT : IMG_FAST})`,
            }}
          >
            <div>{i18n.t('agreement.previewBtn3')}</div>
            <div>{i18n.t('agreement.previewBtn4')}</div>
          </div>
          <div className={`${_ns}__content__phone`}>
            <DtImg src={IMG_PHONE_2} />
          </div>
        </div>
        <div className={`${_ns}__content`}>
          <div
            className={`${_ns}__content__header`}
            style={{
              backgroundImage: `url(${isLight ? IMG_AGILE_LIGHT : IMG_AGILE})`,
            }}
          >
            <div>{i18n.t('agreement.previewBtn5')}</div>
            <div>{i18n.t('agreement.previewBtn6')}</div>
          </div>
          <div className={`${_ns}__content__phone`}>
            <DtImg src={IMG_PHONE_3} />
          </div>
        </div>
        <div className={`${_ns}__content`}>
          <div
            className={`${_ns}__content__header`}
            style={{
              backgroundImage: `url(${isLight ? IMG_ORDER_LIGHT : IMG_ORDER})`,
            }}
          >
            <div>{i18n.t('agreement.previewBtn7')}</div>
            <div>{i18n.t('agreement.previewBtn8')}</div>
          </div>
          <div className={`${_ns}__content__phone`}>
            <DtImg src={IMG_PHONE_4} />
          </div>
        </div>
        <div className={`${_ns}__footer`}>
          <div className={`${_ns}__footer__title`}>
            <ServiceText />
            {i18n.t('agreement.preview')}
            <PrivacyText />
          </div>
          <div className={`${_ns}__footer__btns`}>
            <DtButton onClick={handleCancel}>
              {i18n.t('agreement.cancel')}
            </DtButton>
            <DtButton onClick={handleAgreement}>
              {i18n.t('agreement.confirm')}
            </DtButton>
          </div>
        </div>
      </div>
    </div>
  )
}

export default Preview
