import { DtModal, DtHeader, DtButton } from '@dt/ui-mobile'
import i18n from '@dt/fe-base/dist/i18n'
import { useState } from 'react'
import { localStore } from '@dt/fe-base'
import ServiceText from '../ServiceText'
import PrivacyText from '../PrivacyText'

import './index.scss'

interface IProps {
  onAgree: () => void
  onCancel: () => void
}

const AgreementModal = ({ onAgree, onCancel }: IProps) => {
  const _ns = 'agreement-modal'
  const [visible, setVisible] = useState(true)
  const [isOpen, setIsOpen] = useState(false)
  const handleAgree = (count: number) => {
    if (count === 1) {
      setVisible(false)
    } else {
      setIsOpen(false)
    }
    localStore.set('ls.agreement', true)
    onAgree()
  }
  const handleCancel = (count: number) => {
    if (count === 1) {
      setVisible(false)
      setIsOpen(true)
    } else {
      setIsOpen(false)
      onCancel()
    }
  }
  return (
    <>
      <DtModal
        className={_ns}
        isOpen={visible}
        backdropBreakpoint={1}
        backdropDismiss={false}
      >
        <div>
          <DtHeader className={`${_ns}__header`}>
            {i18n.t('agreement.title')}
          </DtHeader>
          <div className={`${_ns}__content`}>
            <div className={`${_ns}__content__title`}>
              {i18n.t('agreement.content')}
            </div>
            <div className={`${_ns}__content__main`}>
              {i18n.t('agreement.content1')}
              <ServiceText />
              {i18n.t('agreement.content1_1')}
              <PrivacyText />
              {i18n.t('agreement.content1_2')}
              <PrivacyText />
              {i18n.t('agreement.content1_3')}
            </div>
            <div className={`${_ns}__content__main__item`}>
              {i18n.t('agreement.content2')}
            </div>
            <div className={`${_ns}__content__main__item`}>
              {i18n.t('agreement.content3')}
            </div>
            <div className={`${_ns}__content__main__item`}>
              {i18n.t('agreement.content4')}
            </div>
          </div>
          <div className={`${_ns}__footer`}>
            <DtButton onClick={() => handleCancel(1)}>
              {i18n.t('agreement.cancel')}
            </DtButton>
            <DtButton onClick={() => handleAgree(1)}>
              {i18n.t('agreement.confirm')}
            </DtButton>
          </div>
        </div>
      </DtModal>
      <DtModal
        className={_ns}
        isOpen={isOpen}
        backdropBreakpoint={1}
        backdropDismiss={false}
      >
        <div>
          <DtHeader className={`${_ns}__header`}>
            {i18n.t('agreement.agreement')}
          </DtHeader>
          <div className={`${_ns}__content`}>
            {i18n.t('agreement.agreementDesc1')}
            <PrivacyText />
            {i18n.t('agreement.agreementDesc2')}
          </div>
          <div className={`${_ns}__footer`}>
            <DtButton onClick={() => handleCancel(2)}>
              {i18n.t('agreement.cancel')}
            </DtButton>
            <DtButton onClick={() => handleAgree(2)}>
              {i18n.t('agreement.confirm')}
            </DtButton>
          </div>
        </div>
      </DtModal>
    </>
  )
}

export default AgreementModal
