/**
 * 比较两个版本号字符串（例如："1.2.3" 和 "1.2.4"）
 * @param {string} v1 第一个版本号字符串
 * @param {string} v2 第二个版本号字符串
 * @param {string} operator 比较运算符 ('>', '<', '>=', '<=', '=', '==')
 * @returns {boolean} 比较结果
 */
export function compareVersions(
  v1: string,
  v2: string,
  operator: string = '<',
) {
  // 通过分割组件来标准化版本字符串
  const v1Parts = v1.split('.').map(Number)
  const v2Parts = v2.split('.').map(Number)
  // 将数组填充到相同长度
  while (v1Parts.length < v2Parts.length) v1Parts.push(0)
  while (v2Parts.length < v1Parts.length) v2Parts.push(0)

  // 比较每个组件
  for (let i = 0; i < v1Parts.length; i++) {
    if (v1Parts[i] > v2Parts[i])
      return (
        operator === '>' ||
        operator === '>=' ||
        operator === '!=' ||
        operator === '!=='
      )
    if (v1Parts[i] < v2Parts[i])
      return (
        operator === '<' ||
        operator === '<=' ||
        operator === '!=' ||
        operator === '!=='
      )
  }

  // 版本相等的情况
  return (
    operator === '=' ||
    operator === '==' ||
    operator === '>=' ||
    operator === '<='
  )
}

// 简单比较函数，返回 -1, 0, 或 1
export function compare(v1: string, v2: string) {
  const v1Parts = v1.split('.').map(Number)
  const v2Parts = v2.split('.').map(Number)

  while (v1Parts.length < v2Parts.length) v1Parts.push(0)
  while (v2Parts.length < v1Parts.length) v2Parts.push(0)

  for (let i = 0; i < v1Parts.length; i++) {
    if (v1Parts[i] > v2Parts[i]) return 1
    if (v1Parts[i] < v2Parts[i]) return -1
  }
  return 0
}
