import React from 'react'
import { Modal } from '@dt/ui-mobile'
import { appMobx } from '@mobx'
import { observer } from 'mobx-react'
import { Browser } from '@dt/fe-capacitor'
import './index.scss'

const AppUpdateModal: React.FC = () => {
  const { upgradeInfo } = appMobx

  const handleUpdate = () => {
    // 实现更新逻辑
    if (upgradeInfo?.downloadUrl) {
      Browser.open({
        url: upgradeInfo.downloadUrl,
        presentationStyle: 'fullscreen',
      })
    }
  }

  if (!upgradeInfo) return null

  return (
    <Modal.ConfirmModal
      isOpen={upgradeInfo?.updateNative}
      onConfirm={handleUpdate}
      footerOptions={{
        showCancel: false,
        showConfirm: true,
        cancelTitle: '稍后再说',
        confirmTitle: '立即更新',
      }}
      headerOptions={{
        title: '更新提示',
        hideBtn: true,
      }}
      showFooter
      backdropDismiss={false}
      className='app-update-modal'
    >
      <div className='update-content'>
        <h3>当前App版本过低，为确保app正常使用，请立即更新。</h3>
      </div>
    </Modal.ConfirmModal>
  )
}

export default observer(AppUpdateModal)
