import { FC, useEffect } from 'react'
import { Modal, DraggableBtn } from '@dt/ui-mobile'
import i18n from '@dt/fe-base/dist/i18n'
import './index.scss'

interface IStoreModalProps {
  isOpen: boolean
  onClose: () => void
  onOk: () => void
  title: string
  message: string
}

const ConfirmModal: FC<IStoreModalProps> = (props) => {
  const _ns = 'confirm-modal'
  const { isOpen, onClose, onOk, title, message } = props
  return (
    <Modal.ConfirmModal
      isOpen={isOpen}
      title={title}
      autoHeight
      headerOptions={{
        leftIconClick: onClose,
        leftType: 'modal',
        size: 'large',
      }}
      className={_ns}
      message={message}
      onClose={onClose}
    >
      <div className={`${_ns}-content`}>
        <DraggableBtn
          desc={i18n.t('common.slideToConfirm')}
          onComplete={async () => {
            // eslint-disable-next-line no-async-promise-executor
            return new Promise<boolean>(async (resolve) => {
              await onOk()
              resolve(true)
            })
          }}
        >
          {i18n.t('common.ok')}
        </DraggableBtn>
      </div>
    </Modal.ConfirmModal>
  )
}

export default ConfirmModal
