import { useState, useEffect, useCallback, useRef } from 'react'
import { Modal, DtSearchBar, DtIcon } from '@dt/ui-mobile'
import { debounce } from '@dt/fe-base/dist/lodash'
import Mark from '@/assets/img/mapRemark.png'
import i18n from '@dt/fe-base/dist/i18n'
import storeMobx from '@mobx/store.mobx'

import { motion } from 'framer-motion'
import { Geolocation } from '@dt/fe-capacitor'

import {
  chevroExpand,
  chevronCollapse,
  closeCircleFilled,
  search,
} from '@dt/ui-ionic-icon'
import './index.scss'
interface ILocationModalProps {
  isEdit?: boolean
  isOpen: boolean
  initialLocation?: any
  onClose: () => void
  onChange: (location: any) => void
}

let map: any
let centerMarker: any

interface IMapContentProps {
  isEdit?: boolean
  mapExpand: boolean
  handleAddMark: (point: any, map: any, item?: any) => void
  setLocation: (location: any) => void
}

const MapContent = (props: IMapContentProps) => {
  const { mapExpand, isEdit, handleAddMark, setLocation } = props
  const baiduRef = useRef<HTMLDivElement>(null)

  const initBMap = useCallback(async (location: any) => {
    if (baiduRef && baiduRef.current) {
      const latitude = location.latitude
      const longitude = location.longitude
      const myIcon = new BMap.Icon(Mark, new BMap.Size(20, 32))
      console.log('baiduRef', baiduRef.current)
      map = new BMap.Map(baiduRef.current) // 创建Map实例
      const point = new BMap.Point(longitude, latitude)
      centerMarker = new BMap.Marker(point, {
        icon: myIcon,
      }) // 创建标注
      map.centerAndZoom(point, 16)
      map.addOverlay(centerMarker)
      map.enableScrollWheelZoom(true)
      map.addEventListener('click', (e: any) => {
        const cpoint = new BMap.Point(e.point.lng, e.point.lat)
        const myGeo = new BMap.Geocoder()
        console.log('point', e.point)
        myGeo.getLocation(cpoint, (result: any) => {
          if (result) {
            handleAddMark(
              { longitude: e.point.lng, latitude: e.point.lat },
              map,
              {
                ...result,
              },
            )
          }
        })
      })
    }
  }, [])

  useEffect(() => {
    if (baiduRef.current) {
      if (isEdit) {
        initBMap({
          latitude: storeMobx.currentStoreInfo?.store?.lbsLat,
          longitude: storeMobx.currentStoreInfo?.store?.lbsLng,
        })
      } else {
        Geolocation.getCurrentLocation()
          .then(async (res) => {
            if (res.latitude && res.longitude) {
              await initBMap({
                latitude: res.latitude,
                longitude: res.longitude,
              })
              const myGeo = new BMap.Geocoder({ extensions_town: true })
              myGeo.getLocation(
                new BMap.Point(res.longitude, res.latitude),
                (result: any) => {
                  if (result) {
                    setLocation({
                      province: result.content.address_detail.province,
                      city: result.content.address_detail.city,
                      address:
                        result.content.address_detail.province +
                        result.content.address_detail.city +
                        result.content.address_detail.district +
                        result.content.address_detail.street +
                        result.content.address_detail.street_number,
                      title: result.content.poi_desc,
                      point: result.point,
                    })
                  }
                },
              )
            } else {
              initBMap({ latitude: 30.280059, longitude: 120.161693 })
            }
          })
          .catch(() => {
            initBMap({ latitude: 30.280059, longitude: 120.161693 })
          })
      }
    }
  }, [baiduRef.current, initBMap, isEdit, setLocation])

  return (
    <motion.div
      className='map-content'
      initial={{
        height: 0,
        opacity: 0,
      }}
      animate={{
        height: mapExpand ? 'auto' : 0,
        opacity: mapExpand ? 1 : 0,
      }}
      transition={{ duration: 0.3 }}
    >
      <div
        className='hq-store-location-modal-content-map baidu-map-show'
        ref={baiduRef}
      ></div>
    </motion.div>
  )
}

export default function LocationModal(props: ILocationModalProps) {
  const { isOpen, initialLocation, isEdit, onClose, onChange } = props

  const [searchVal, setSearchVal] = useState('')
  const [searchArr, setSearchArr] = useState<any[]>([])
  const [location, setLocation] = useState<any>(initialLocation)
  const [mapExpand, setMapExpand] = useState<boolean>(false)
  const [isSearch, setIsSearch] = useState<boolean>(false)

  const handleAddMark = (point: any, map: any, item?: any) => {
    const poi = new BMap.Point(point.longitude, point.latitude)
    const myIcon = new BMap.Icon(Mark, new BMap.Size(20, 32))
    centerMarker = new BMap.Marker(poi, {
      icon: myIcon,
    })
    map.clearOverlays()
    map.addOverlay(centerMarker)
    map.centerAndZoom(poi, 16)
    setLocation({
      province: item.content.address_detail.province,
      city: item.content.address_detail.city,
      address:
        item.content.address_detail.province +
        item.content.address_detail.city +
        item.content.address_detail.district +
        item.content.address_detail.street +
        item.content.address_detail.street_number,
      title: item.content.poi_desc,
      point: item.point,
    })
  }

  const changeCenter = async (item: any) => {
    const myIcon = new BMap.Icon(Mark, new BMap.Size(20, 32))
    const pointI = new BMap.Point(item.point.lng, item.point.lat)
    centerMarker = new BMap.Marker(item.point, {
      icon: myIcon,
    }) // 创建标注
    map.clearOverlays()
    map.addOverlay(centerMarker)
    map.centerAndZoom(pointI, 16)
    setIsSearch(false)
    setLocation(item)

    setSearchVal(item.title)
  }

  const initState = useCallback(() => {
    setLocation(initialLocation)
    setMapExpand(false)
  }, [initialLocation])

  useEffect(() => {
    if (isOpen) {
      if (isEdit) {
        // 编辑
        setLocation({
          province: storeMobx.currentStoreInfo?.store?.county,
          city: storeMobx.currentStoreInfo?.store?.city,
          address: storeMobx.currentStoreInfo?.store?.address,
          title: '',
          point: {
            lng: storeMobx.currentStoreInfo?.store?.lbsLng,
            lat: storeMobx.currentStoreInfo?.store?.lbsLat,
          },
        })
      } else {
        // 新增
        initState()
      }
    }
  }, [isOpen])

  const searchLocal = (value: string | null | undefined) => {
    if (map) {
      const myKeys = value
      const local = new BMap.LocalSearch(map, {
        onSearchComplete: (res: any) => {
          console.log('res', res)
          if (!res) {
            setSearchArr([])
            return
          }
          const list = []
          for (let i = 0; i < res.getCurrentNumPois(); i++) {
            const poi = res.getPoi(i)
            if (!poi?.tags?.includes('行政区划')) {
              list.push(poi)
            }
          }
          setSearchArr(list)
        },
      })
      local.search(myKeys, map.getBounds())
    }
  }

  return (
    <Modal.PageModal
      className='hq-store-location-modal'
      onClose={onClose}
      title={i18n.t('store.storeLocation')}
      headerOptions={{
        showConfirm: true,
        onConfirmClick: () => onChange(location),
      }}
      isOpen={isOpen}
    >
      <div className='hq-store-location-modal-content'>
        <MapContent
          isEdit={isEdit}
          mapExpand={mapExpand}
          handleAddMark={handleAddMark}
          setLocation={setLocation}
        />
        <div></div>
        <div className='hq-store-location-modal-content-search'>
          <div className='hq-store-location-modal-content-search-bar'>
            <DtSearchBar
              onIonBlur={() => {
                setTimeout(() => {
                  setIsSearch(false)
                }, 100)
              }}
              searchIcon={search}
              clearIcon={closeCircleFilled}
              placeholder={i18n.t('store.storeLocation')}
              value={
                isSearch
                  ? searchVal
                  : location
                    ? `${location?.address || ''}${location?.title || ''}`
                    : ''
              }
              onIonInput={(e: any) => {
                setIsSearch(true)
                setSearchVal(e.detail.value)
                searchLocal(e.detail.value)
              }}
            />
            <div
              className='hq-store-location-modal-content-search-bar-btn'
              onClick={(e) => {
                e.stopPropagation()
                setMapExpand(!mapExpand)
              }}
            >
              {i18n.t('store.map')}
              <DtIcon icon={mapExpand ? chevronCollapse : chevroExpand} />
            </div>
          </div>
          <div className='hq-store-location-modal-content-search-area'>
            {isSearch &&
              searchArr.map((item: any, index: number) => (
                <div
                  key={index}
                  className='store-search-area-item'
                  onClick={() => {
                    changeCenter(item)
                  }}
                >
                  <div className='title'>{item.title}</div>
                  <div className='des'>
                    {item.province}
                    {item.city && `，${item.city}`}
                    {item.address && `，${item.address}`}
                  </div>
                </div>
              ))}
          </div>
        </div>
      </div>
    </Modal.PageModal>
  )
}
