import ENV from '@common/env'
import {
  BasicAuthenticator,
  Collection,
  Database,
  Replicator,
  ReplicatorConfiguration,
  ReplicatorType,
  URLEndpoint,
  CollectionConfig,
  ReplicatorActivityLevel,
} from '@dt/cbl-ionic'
// import { categoryMobx, productMobx } from '@mobx';

/**
 * 基础方法抽象类
 */
class CouchbaseClass {
  DB: string
  database: Database
  SCOPE: string
  COLLECTIONS: Collection[]
  _collection!: Collection
  API: string
  URI: string
  CHANNELS: string[]
  replicatorId!: string
  replicator!: Replicator
  lastActivityLevel!: number
  constructor(props: {
    config: {
      DB: string
      SCOPE: string
      COLLECTIONS: Collection[]
      API: string
    }
    CHANNELS: (string | number)[]
    database: Database
  }) {
    const {
      config: { DB, SCOPE, COLLECTIONS, API },
      CHANNELS,
      database,
    } = props
    this.database = database
    this.DB = DB
    this.SCOPE = SCOPE
    this.COLLECTIONS = COLLECTIONS
    console.error(
      'CouchbaseClass',
      DB,
      SCOPE,
      COLLECTIONS,
      CHANNELS,
      database,
      ENV.COUCHBASE_URI,
      API,
    )
    this.database.scope(SCOPE).then(async () => {
      this.syncDb()
    })
    this.API = API
    this.URI = ENV.COUCHBASE_URI + API
    this.CHANNELS = CHANNELS as string[]
    this.lastActivityLevel = ReplicatorActivityLevel.IDLE
  }
  /** 链接db */
  async syncDb() {
    console.error('CouchbaseClass', 'syncDb', this.DB)
    try {
      const target = new URLEndpoint(this.URI)
      const auth = new BasicAuthenticator('downtown', 'downtown2013')
      const config = new ReplicatorConfiguration(target)
      const collectionConfig = new CollectionConfig(this.CHANNELS, [])
      config.addCollections(this.COLLECTIONS, collectionConfig)
      config.setAuthenticator(auth)
      config.setReplicatorType(ReplicatorType.PULL)
      config.setAllowReplicatingInBackground(true)
      config.setContinuous(true)
      // 设置心跳间隔（秒）
      config.setHeartbeat(150)
      // 设置最大重试次数
      config.setMaxAttempts(8640)
      // 设置重试尝试之间的最大等待时间（秒）
      config.setMaxAttemptWaitTime(10)
      config.setAcceptOnlySelfSignedCerts(false)
      const replicator = await Replicator.create(config)
      replicator.start(true)
      this.replicatorId = replicator.getId() || ''
      replicator.addChangeListener((res) => {
        console.info('addChangeListener ===> sync', this.COLLECTIONS, res)
      })
      /** 临时测试 */
      replicator.addDocumentChangeListener((res) => {
        console.info(
          'main addReplicatorListener 有更新 ===>',
          this.COLLECTIONS,
          res,
        )
        // this.allDocs()
      })
      this.replicator = replicator
      console.warn(
        'syncDb',
        this.DB,
        this.SCOPE,
        this.COLLECTIONS,
        this.CHANNELS,
        this.replicatorId,
        this.URI,
      )
    } catch (error) {
      console.log('sync Error', error)
    }
  }
  /** 监听db变更 */
  watchDb(cb: (data: any) => void) {
    console.log(
      'watchDb',
      this.DB,
      this.SCOPE,
      this.COLLECTIONS,
      this.replicatorId,
    )
    this.replicator.addChangeListener((res) => {
      console.info('addChangeListener ===> ', this.COLLECTIONS, res)
      if (
        res.status.getActivityLevel() === ReplicatorActivityLevel.IDLE &&
        this.lastActivityLevel !== ReplicatorActivityLevel.IDLE
      ) {
        // 通知数据处理
        console.log('用新数据可以处理了')
        cb(res)
      }
      this.lastActivityLevel = res.status.getActivityLevel()
    })
    // this.replicator.addDocumentChangeListener((res: any) => {
    //   console.log('addDocumentReplicationListener 有更新 ===>', res)
    //   cb(res)
    // })
  }

  async getDoc(id: string) {
    this.database
      .getEngine()
      .collection_GetDocument({
        docId: id,
        name: this._collection.scope.database.getName(),
        scopeName: this._collection.scope.name,
        collectionName: this._collection.name,
      })
      .then((res) => {
        console.log('getDoc', res)
      })
      .catch((error) => {
        console.log('error Get', error)
      })
  }
}

export default CouchbaseClass
