import config from '../config'
import CouchbaseClass from '../basic.db'
import {
  Database,
  DatabaseConfiguration,
  FileSystem,
  CapacitorEngine,
  Scope,
  Collection,
} from '@dt/cbl-ionic'
import DatabaseList from '../database'
import { localStore as store } from '@dt/fe-base'
import { forEach, map } from '@dt/fe-base/dist/lodash'

class ProductDBClass {
  DB: string = 'product'
  SCOPE: string = 'saleunits'
  API: string = 'hq_product_saleunits'
  database: Database | undefined
  /** 售卖信息 */
  SaleInfoDB!: CouchbaseClass
  constructor() {
    // this.initDb()
  }
  /** 初始化 */
  async initDb() {
    try {
      const database = (this.database = DatabaseList.get(this.DB))
      console.log(database, 'database')
      const brandId =
        store.get('ls.brandInfo')?.brandId || window.brandInfo.brandId || 0
      const collections: Collection[] = await Promise.all(
        map(config.PRODUCT, async ([DB, SCOPE, COLLECTION]) => {
          const scope = new Scope(SCOPE, database)
          const _collection: Collection = await database.createCollection(
            COLLECTION,
            scope,
          )
          return _collection
        }),
      )
      this.SaleInfoDB = new CouchbaseClass({
        config: {
          DB: this.DB,
          SCOPE: this.SCOPE,
          COLLECTIONS: collections,
          API: this.API,
        },
        CHANNELS: [`BrandId_${brandId}`],
        database,
      })
    } catch (error) {
      console.log('initDbError', error)
    }
  }

  async getQl(sql: string) {
    try {
      try {
        const query = this.database?.createQuery(sql)
        const res = await query?.execute()
        // console.log('getQl ====>', res)
        return res
      } catch (error) {
        console.log('error query', error)
      }
    } catch (error) {}
    return false
  }
  // async watch (cb?: any) {
  //   this.SaleInfoDB?.watchDb(cb)
  // }

  // async getAll () {
  //   this.SaleInfoDB?.allDocs()
  // }
}

export default new ProductDBClass()
