import { map } from '@dt/fe-base/dist/lodash'
import BaseDb from './base.db'
import { localStore as store } from '@dt/fe-base'
import couchbaseDb from '@couchbase/database'
import ProductBaseDb from '@couchbase/product/base.db'

class ProductDB {
  constructor() {}
  async checkDb() {
    const db = couchbaseDb.get('product')
    if (!db) {
      await couchbaseDb.initDb('product')
      await ProductBaseDb.initDb()
    }
    return true
  }
  async init() {
    const suCategoryList = await this.getCategory()
    const comboSuList = await this.getComboSu()
    const saleInfoList = await this.getSaleInfo()
    const singleSuList = await this.getSingleSu()
    const additionalGroupList = await this.getAdditionalGroup()
    return {
      suCategoryList,
      comboSuList,
      saleInfoList,
      singleSuList,
      additionalGroupList,
    }
  }
  /** 获取销售属性 */
  async getSaleInfo() {
    await this.checkDb()
    const brandId =
      store.get('ls.brandInfo')?.brandId || window.brandInfo.brandId || 0
    const res: any = await BaseDb.getQl(
      `SELECT saleInfo.* FROM saleunits.saleInfo WHERE brandId = ${brandId}`,
    )
    console.log('getSaleInfo ==>', res)
    if (res?.length) {
      return map(res, (item: any) => {
        return item.saleInfo
      })
    }
    return []
  }
  /** 获取单品 */
  async getSingleSu() {
    await this.checkDb()
    const brandId =
      store.get('ls.brandInfo')?.brandId || window.brandInfo.brandId || 0
    const res: any = await BaseDb.getQl(
      `SELECT * FROM saleunits.singleSu WHERE brandId = ${brandId}`,
    )
    console.log('getSingleSu ==>', res)
    if (res?.length) {
      return map(res, (item: any) => {
        return item.singleSu
      })
    }
    return []
  }
  /** 获取分组 */
  async getCategory(data?: { storeId?: number; saleScene?: any }) {
    await this.checkDb()
    const brandId =
      store.get('ls.brandInfo')?.brandId || window.brandInfo.brandId || 0
    const res: any = await BaseDb.getQl(
      `SELECT * FROM saleunits.suCategory WHERE brandId = ${brandId} ${data ? `AND ${data.storeId ? `storeId = ${data.storeId}` : ''} ${data.storeId ? `AND saleScene = ${data.saleScene}` : ''}` : ''}`,
    )
    console.log('getCategory ==>', res)
    if (res?.length) {
      return map(res, (item: any) => {
        return item.suCategory
      })
    }
    return []
  }
  /** 获取套餐 */
  async getComboSu() {
    await this.checkDb()
    const brandId =
      store.get('ls.brandInfo')?.brandId || window.brandInfo.brandId || 0
    const res: any = await BaseDb.getQl(
      `SELECT * FROM saleunits.comboSu WHERE brandId = ${brandId}`,
    )
    console.log('getComboSu ==>', res)
    if (res?.length) {
      return map(res, (item: any) => {
        return item.comboSu
      })
    }
    return []
  }
  /** 获取加料组 */
  async getAdditionalGroup() {
    await this.checkDb()
    const brandId =
      store.get('ls.brandInfo')?.brandId || window.brandInfo.brandId || 0
    const res: any = await BaseDb.getQl(
      `SELECT * FROM saleunits.additionalGroup WHERE brandId = ${brandId}`,
    )
    console.log('getModifier ==>', res)
    if (res?.length) {
      return map(res, (item: any) => {
        return item.additionalGroup
      })
    }
    return []
  }
}

export default new ProductDB()
