/* eslint-disable */
import * as types from './graphql'
import { TypedDocumentNode as DocumentNode } from '@graphql-typed-document-node/core'

/**
 * Map of all GraphQL operations in the project.
 *
 * This map has several performance disadvantages:
 * 1. It is not tree-shakeable, so it will include all operations in the project.
 * 2. It is not minifiable, so the string of a GraphQL query will be multiple times inside the bundle.
 * 3. It does not support dead code elimination, so it will add unused operations.
 *
 * Therefore it is highly recommended to use the babel or swc plugin for production.
 * Learn more about it here: https://the-guild.dev/graphql/codegen/plugins/presets/preset-client#reducing-bundle-size
 */
const documents = {
  '\n  fragment BrandBrand on BrandBrand  {\n    brandId\n    brandName\n    brandNameAlias\n    logo\n    addUser\n    modifyUser\n    traceId\n    status\n    isDel\n    addTime\n    sysAddTime\n    sysModifyTime\n    modifyTime\n    storeCnt\n    dataSource\n  }\n':
    types.BrandBrandFragmentDoc,
  '\n  query FindBrand($input: InputBrandBrandFindRequest!) {\n    FindBrand(input: $input)  {\n      brandId\n      brandName\n      brandNameAlias\n      logo\n      addUser\n      modifyUser\n      traceId\n      status\n      isDel\n      addTime\n      sysAddTime\n      sysModifyTime\n      modifyTime\n      storeCnt\n      dataSource\n      migration\n    }\n  }\n':
    types.FindBrandDocument,
  '\n  query ListBrands($input: InputBrandBrandIdRequest!) {\n    ListBrands(input: $input) {...BrandBrand}\n  }\n':
    types.ListBrandsDocument,
  '\n  mutation CreateBrand($input: InputBrandBrandCreateRequest!) {\n    CreateBrand(input: $input) {...BrandBrand}\n  }\n':
    types.CreateBrandDocument,
  '\n  mutation UpdateBrand($input: InputBrandBrandUpdateRequest!) {\n    UpdateBrand(input: $input) {...BrandBrand}\n  }\n':
    types.UpdateBrandDocument,
  '\n  mutation HQSelectBrand($input: InputUserUserCenterHQSelectBrandReq!) {\n    HQSelectBrand(input: $input) {\n      accessToken\n      accessExpire\n      refreshToken\n      mqToken\n    }\n  }\n':
    types.HqSelectBrandDocument,
  '\n  query GetUserBrandStoreSelection($input: InputRolePermUserCenterGetUserBrandStoreSelectionReq!) {\n    GetUserBrandStoreSelection(input: $input)  {\n      brandId\n      storeId\n    }\n  }\n':
    types.GetUserBrandStoreSelectionDocument,
  '\n  mutation SaveDeviceInfo($input: InputDevicemonitorSaveDeviceInfoReq!) {\n    SaveDeviceInfo(input: $input) \n  }\n':
    types.SaveDeviceInfoDocument,
  '\n  query QueryDeviceInfo($input: InputDevicemonitorQueryDeviceInfoReq!) {\n    QueryDeviceInfo(input: $input)  {\n      brandId\n      storeId\n      appVersion\n      appName\n      osVersion\n      manufacturer\n      model\n      platform\n      packageName\n      deviceName\n      deviceId\n      addTime\n      systemAddTime\n      modifyTime\n      systemModifyTime\n    }\n  }\n':
    types.QueryDeviceInfoDocument,
  '\n  query GetSingleCategoryMessages($input: InputNotificationCenterCenterSingleUnreadCategoryRequest!) {\n    GetSingleCategoryMessages(input: $input)  {\n      singleCategory {\n        categoryId\n        categoryName\n        categoryCount\n        NotificationList {\n          msgType\n          eventId\n          templateId\n          content\n          code\n          msgPushMode\n          title\n          payload\n          notificationId\n          categoryId\n          isRead\n          SendTime\n        }\n      }\n      totalCount\n    }\n  }\n':
    types.GetSingleCategoryMessagesDocument,
  '\n  query MarkCategoryAsRead($input: InputNotificationCenterCenterMarkCategoryAsReadRequest!) {\n    MarkCategoryAsRead(input: $input) \n  }\n':
    types.MarkCategoryAsReadDocument,
  '\n  query GetDiscountTagPage($input: InputCostRecordGetDiscountTagPageReq!) {\n    GetDiscountTagPage(input: $input)  {\n      total\n    }\n  }\n':
    types.GetDiscountTagPageDocument,
  '\n  query GetShelfSuCount($input: InputSaleunitBrandStoreIdReq!) {\n    GetShelfSuCount(input: $input)  {\n      shelfSuNum\n    }\n  }\n':
    types.GetShelfSuCountDocument,
  '\n  query GetMergedReason($GetRefundReasonInput:InputOrderconfigGetRefundReasonRequest!,$GetDiscountReasonInput:InputOrderconfigGetDiscountReasonRequest!) {\n    GetRefundReason(input: $GetRefundReasonInput) {\n      isMust\n      items {\n        name\n      }\n    }\n    GetDiscountReason(input: $GetDiscountReasonInput) {\n      name\n    }\n  }\n':
    types.GetMergedReasonDocument,
  '\n  query GetMergedPrinterList($GetOrderReceiptListInput: InputOrderconfigGetOrderReceiptListReq!,$ListKitchenInput: InputKitchenworkstationListKitchenRequest!) {\n    GetOrderReceiptList(input: $GetOrderReceiptListInput) { \n      printerId\n      brandId\n      storeId\n      deviceId\n      name\n      enableGraphicPrint\n      enableBeep\n      receiptList {\n        receipt\n        channel\n        eatType\n        count\n      }\n      physicalPrinterId\n      printer {\n        id\n        printNodeId\n        name\n        type\n        paperSize\n        connectType\n        address\n        encoding\n        errorCode\n        direction\n        margin\n        space\n        ackLevel\n      }\n      addTime\n    }\n    ListKitchen(input: $ListKitchenInput) { \n      total\n      list {\n        workstationNo\n        workstationName\n        storeId\n        brandId\n        suList {\n          suNo\n        }\n        printerList {\n          printerId\n          storeId\n          brandId\n          workstationNo\n          printerName\n          deviceId\n          physicalPrinterId\n          diningStyles\n          receipt {\n            kitchenTicket {\n              enablePrint\n              count\n              printingMode\n              sameMealIsPrintedTogether\n              packagesArePrintedTogether\n            }\n            voidItemTicket {\n              enablePrint\n              count\n            }\n            changeTableTicket {\n              enablePrint\n              count\n            }\n          }\n          receiptType\n          addTime\n          printer {\n            id\n            printNodeId\n            name\n            type\n            paperSize\n            connectType\n            address\n            encoding\n            errorCode\n            direction\n            margin\n            space\n            ackLevel\n          }\n        }\n        isDefault\n      }\n    }\n  }\n':
    types.GetMergedPrinterListDocument,
  '\n  query GetMergeTakeoutInfo($GetTakeoutStoreInfoInput: InputTakeoutStoreGetTakeoutStoreInfoRequest!,$CountRelationProductInput: InputTakeoutProductCountRelationProductRequest!){\n    GetTakeoutStoreInfo(input: $GetTakeoutStoreInfoInput)  {\n      brandId\n      storeId\n      outStoreId\n      channelType\n      storeBusinessStatus\n      hasAuth\n    }\n    CountRelationProduct(input: $CountRelationProductInput) {\n      count\n      isAllAssociated\n    }\n  }\n':
    types.GetMergeTakeoutInfoDocument,
  '\n    query GetStoreStoreModule($input: InputOnlinesalesGetStoreStoreModuleRequest!) {\n      GetStoreStoreModule(input: $input)  {\n        saleModuleKey\n        valid\n      }\n    }\n':
    types.GetStoreStoreModuleDocument,
  '\n  fragment TodoStep on TodoStep  {\n    name\n    id\n  }\n':
    types.TodoStepFragmentDoc,
  '\n  fragment TodoReward on TodoReward  {\n    rewardNo\n    name\n    storeTryDays\n    provide\n    number\n  }\n':
    types.TodoRewardFragmentDoc,
  '\n  fragment TodoExtend on TodoExtend  {\n    isCopyEnd\n  }\n':
    types.TodoExtendFragmentDoc,
  '\n  fragment TodoCheck on TodoCheck  {\n    name\n    checkPass\n    subType\n    steps {...TodoStep}\n    rewards {...TodoReward}\n    required\n    prevChecks\n    extend {...TodoExtend}\n  }\n':
    types.TodoCheckFragmentDoc,
  '\n  fragment TodoTodoListRspData on TodoTodoListRspData  {\n    todoNo\n    brandId\n    storeId\n    name\n    finished\n    required\n    checkList {...TodoCheck}\n    todoType\n    enable\n    id\n  }\n':
    types.TodoTodoListRspDataFragmentDoc,
  '\n  fragment TodoStoreModule on TodoStoreModule  {\n    saleModuleKey\n    saleModuleType\n    days\n  }\n':
    types.TodoStoreModuleFragmentDoc,
  '\n  fragment TodoTodoFinishedRspData on TodoTodoFinishedRspData  {\n    brandId\n    storeId\n    name\n    storeModule {...TodoStoreModule}\n    bizId\n  }\n':
    types.TodoTodoFinishedRspDataFragmentDoc,
  '\n  fragment TakeoutPrinterTimeConfigReceipt on TakeoutPrinterTimeConfigReceipt  {\n    receiptType\n    printType\n    makeTime\n    deliverTime\n  }\n':
    types.TakeoutPrinterTimeConfigReceiptFragmentDoc,
  '\n  fragment TakeoutPrinterTimeConfigTakeoutPrinterTimeConfigDetailRespData on TakeoutPrinterTimeConfigTakeoutPrinterTimeConfigDetailRespData  {\n    takeoutPrinterTimeConfigNo\n    brandId\n    storeId\n    receipts {...TakeoutPrinterTimeConfigReceipt}\n  }\n':
    types.TakeoutPrinterTimeConfigTakeoutPrinterTimeConfigDetailRespDataFragmentDoc,
  '\n  fragment StoreTaskStoreTaskListRspData on StoreTaskStoreTaskListRspData  {\n    basicTaskNo\n    storeTaskNo\n    brandId\n    storeId\n    type\n    name\n    desc\n    sort\n    status\n    completeMethod\n    updatedAt\n    isCanReverse\n    isCanComplete\n    isCanCancel\n  }\n':
    types.StoreTaskStoreTaskListRspDataFragmentDoc,
  '\n  query TodoList($input: InputTodoTodoListReq!) {\n    TodoList(input: $input) {...TodoTodoListRspData}\n  }\n':
    types.TodoListDocument,
  '\n  mutation TodoFinished($input: InputTodoTodoFinishedReq!) {\n    TodoFinished(input: $input) {...TodoTodoFinishedRspData}\n  }\n':
    types.TodoFinishedDocument,
  '\n  query TodoDelete($input: InputTodoTodoDeleteReq!) {\n    TodoDelete(input: $input) \n  }\n':
    types.TodoDeleteDocument,
  '\n  query TodoExtentUpdate($input: InputTodoTodoExtentUpdateReq!) {\n    TodoExtentUpdate(input: $input) \n  }\n':
    types.TodoExtentUpdateDocument,
  '\n  query TakeoutPrinterTimeConfigDetail($input: InputTakeoutPrinterTimeConfigTakeoutPrinterTimeConfigDetailReq!) {\n    TakeoutPrinterTimeConfigDetail(input: $input) {...TakeoutPrinterTimeConfigTakeoutPrinterTimeConfigDetailRespData}\n  }\n':
    types.TakeoutPrinterTimeConfigDetailDocument,
  '\n  mutation TakeoutPrinterTimeConfigSave($input: InputTakeoutPrinterTimeConfigTakeoutPrinterTimeConfigSaveReq!) {\n    TakeoutPrinterTimeConfigSave(input: $input) \n  }\n':
    types.TakeoutPrinterTimeConfigSaveDocument,
  '\n  mutation TakeoutPrinterTimeConfigCopy($input: InputTakeoutPrinterTimeConfigTakeoutPrinterTimeConfigCopyReq!) {\n    TakeoutPrinterTimeConfigCopy(input: $input) \n  }\n':
    types.TakeoutPrinterTimeConfigCopyDocument,
  '\n  query StoreTaskList($input: InputStoreTaskStoreTaskListReq!) {\n    StoreTaskList(input: $input) {...StoreTaskStoreTaskListRspData}\n  }\n':
    types.StoreTaskListDocument,
  '\n  query StoreTaskComplete($input: InputStoreTaskStoreTaskCompleteReq!) {\n    StoreTaskComplete(input: $input) \n  }\n':
    types.StoreTaskCompleteDocument,
  '\n  query GetColorMode($input: InputDeviceGetColorModeReq!) {\n    GetColorMode(input: $input)  {\n      brandId\n      storeId\n      machineNo\n      colorMode\n    }\n  }\n':
    types.GetColorModeDocument,
  '\n  query GetStore($input: InputStoreBusinessGetStoreRequest!) {\n    GetStore(input: $input) {\n      storeId\n      brandId\n      storeName\n      logo\n      tel\n      mobile\n      state\n      county\n      city\n      address\n      addressDetail\n      cityCode\n      lbsLng\n      lbsLat\n      status\n      remark\n      storeNumber\n      isPosAll\n      autoSoldOut\n      isPlate\n      isPlateRequired\n    }\n  }\n':
    types.GetStoreDocument,
  '\n  query StoreAll($input: InputStoreBusinessStoreAllRequest!) {\n    StoreAll(input: $input) {\n      store {\n        storeId\n        brandId\n        storeName\n        logo\n        tel\n        mobile\n        state\n        county\n        city\n        address\n        addressDetail\n        cityCode\n        lbsLng\n        lbsLat\n        status\n        remark\n        storeNumber\n        isPosAll\n        autoSoldOut\n        isPlate\n        isPlateRequired\n        dataSource\n      }\n      storeBusiness {\n        storeId\n        configMethod\n        loopMethod\n        businessType\n        monday {\n          startTime\n          endTime\n        }\n        tuesday {\n          startTime\n          endTime\n        }\n        wednesday {\n          startTime\n          endTime\n        }\n        thursday {\n          startTime\n          endTime\n        }\n        friday {\n          startTime\n          endTime\n        }\n        saturday {\n          startTime\n          endTime\n        }\n        sunday {\n          startTime\n          endTime\n        }\n        id\n        brandId\n        isPosAll\n      }\n    }\n  }\n':
    types.StoreAllDocument,
  '\n  mutation CreateStore($input: InputStoreBusinessCreatStore!) {\n    CreateStore(input: $input) {\n      storeId\n      brandId\n      storeName\n      logo\n      tel\n      mobile\n      state\n      county\n      city\n      address\n      addressDetail\n      cityCode\n      lbsLng\n      lbsLat\n      status\n      remark\n      storeNumber\n      isPosAll\n      autoSoldOut\n      isPlate\n      isPlateRequired\n    }\n  }\n':
    types.CreateStoreDocument,
  '\n  mutation UpdateStore($input: InputStoreBusinessStore!) {\n    UpdateStore(input: $input) {\n      storeId\n      brandId\n      storeName\n      logo\n      tel\n      mobile\n      state\n      county\n      city\n      address\n      addressDetail\n      cityCode\n      lbsLng\n      lbsLat\n      status\n      remark\n      storeNumber\n      isPosAll\n      autoSoldOut\n      isPlate\n      isPlateRequired\n    }\n  }\n':
    types.UpdateStoreDocument,
  '\n  mutation DeleteStore($input: InputStoreBusinessDeleteStoreRequest!) {\n    DeleteStore(input: $input) {\n      storeId\n      brandId\n      storeName\n      logo\n      tel\n      mobile\n      state\n      county\n      city\n      address\n      addressDetail\n      cityCode\n      lbsLng\n      lbsLat\n      status\n      remark\n      storeNumber\n      isPosAll\n      autoSoldOut\n      isPlate\n      isPlateRequired\n    }\n  }\n':
    types.DeleteStoreDocument,
  '\n  query UserBrandStoreSelection($input: InputRolePermUserCenterUserBrandStoreSelectionReq!) {\n    UserBrandStoreSelection(input: $input) \n  }\n':
    types.UserBrandStoreSelectionDocument,
  '\n  query HqUserInfo($input: InputUserUserCenterHqUserInfoReq!) {\n    HqUserInfo(input: $input)  {\n      userId\n      userName\n      phone\n      email\n      dataSource\n      roleInfo {\n        total\n        data {\n          roleId\n          roleName\n        }\n      }\n      employeeId\n      storeData {\n        total\n        data {\n          storeName\n          storeId\n        }\n      }\n    }\n  }\n':
    types.HqUserInfoDocument,
  '\n    query CurrentUserPerm($input: InputRolePermUserCenterCurrentUserPermReq!) {\n        CurrentUserPerm(input: $input) {\n            userId\n            brandId\n            roleType\n            roleName\n            roleKey\n            rolePermList {\n                id\n                serverKey\n                serverType\n                name\n                label\n                url\n                level\n                routerVersion\n                order\n                children {\n                    id\n                    serverKey\n                    serverType\n                    name\n                    label\n                    url\n                    level\n                    routerVersion\n                    order\n                    children {\n                        id\n                        serverKey\n                        serverType\n                        name\n                        label\n                        url\n                        level\n                        routerVersion\n                        order\n                    parentKey\n                    }\n                parentKey\n                }\n                parentKey\n            }\n            username\n            storeIds\n        }\n    }\n':
    types.CurrentUserPermDocument,
  '\n    mutation SaveUserIdAndJPushId($input: InputUserUserCenterSaveUserIdAndJPushIdReq!) {\n      SaveUserIdAndJPushId(input: $input)\n    }\n':
    types.SaveUserIdAndJPushIdDocument,
  '\n  mutation CurrentUserHomeCard($input: InputUserUserCenterCurrentUserHomeCardReq!) {\n    CurrentUserHomeCard(input: $input) \n  }\n':
    types.CurrentUserHomeCardDocument,
  '\n  query GetCurrentUserHomeCard($input: InputUserUserCenterGetCurrentUserHomeCardReq!) {\n    GetCurrentUserHomeCard(input: $input)  {\n      cards\n    }\n  }\n':
    types.GetCurrentUserHomeCardDocument,
}

/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 *
 *
 * @example
 * ```ts
 * const query = gql(`query GetUser($id: ID!) { user(id: $id) { name } }`);
 * ```
 *
 * The query argument is unknown!
 * Please regenerate the types.
 */
export function gql(source: string): unknown

/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  fragment BrandBrand on BrandBrand  {\n    brandId\n    brandName\n    brandNameAlias\n    logo\n    addUser\n    modifyUser\n    traceId\n    status\n    isDel\n    addTime\n    sysAddTime\n    sysModifyTime\n    modifyTime\n    storeCnt\n    dataSource\n  }\n',
): (typeof documents)['\n  fragment BrandBrand on BrandBrand  {\n    brandId\n    brandName\n    brandNameAlias\n    logo\n    addUser\n    modifyUser\n    traceId\n    status\n    isDel\n    addTime\n    sysAddTime\n    sysModifyTime\n    modifyTime\n    storeCnt\n    dataSource\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query FindBrand($input: InputBrandBrandFindRequest!) {\n    FindBrand(input: $input)  {\n      brandId\n      brandName\n      brandNameAlias\n      logo\n      addUser\n      modifyUser\n      traceId\n      status\n      isDel\n      addTime\n      sysAddTime\n      sysModifyTime\n      modifyTime\n      storeCnt\n      dataSource\n      migration\n    }\n  }\n',
): (typeof documents)['\n  query FindBrand($input: InputBrandBrandFindRequest!) {\n    FindBrand(input: $input)  {\n      brandId\n      brandName\n      brandNameAlias\n      logo\n      addUser\n      modifyUser\n      traceId\n      status\n      isDel\n      addTime\n      sysAddTime\n      sysModifyTime\n      modifyTime\n      storeCnt\n      dataSource\n      migration\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query ListBrands($input: InputBrandBrandIdRequest!) {\n    ListBrands(input: $input) {...BrandBrand}\n  }\n',
): (typeof documents)['\n  query ListBrands($input: InputBrandBrandIdRequest!) {\n    ListBrands(input: $input) {...BrandBrand}\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  mutation CreateBrand($input: InputBrandBrandCreateRequest!) {\n    CreateBrand(input: $input) {...BrandBrand}\n  }\n',
): (typeof documents)['\n  mutation CreateBrand($input: InputBrandBrandCreateRequest!) {\n    CreateBrand(input: $input) {...BrandBrand}\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  mutation UpdateBrand($input: InputBrandBrandUpdateRequest!) {\n    UpdateBrand(input: $input) {...BrandBrand}\n  }\n',
): (typeof documents)['\n  mutation UpdateBrand($input: InputBrandBrandUpdateRequest!) {\n    UpdateBrand(input: $input) {...BrandBrand}\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  mutation HQSelectBrand($input: InputUserUserCenterHQSelectBrandReq!) {\n    HQSelectBrand(input: $input) {\n      accessToken\n      accessExpire\n      refreshToken\n      mqToken\n    }\n  }\n',
): (typeof documents)['\n  mutation HQSelectBrand($input: InputUserUserCenterHQSelectBrandReq!) {\n    HQSelectBrand(input: $input) {\n      accessToken\n      accessExpire\n      refreshToken\n      mqToken\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query GetUserBrandStoreSelection($input: InputRolePermUserCenterGetUserBrandStoreSelectionReq!) {\n    GetUserBrandStoreSelection(input: $input)  {\n      brandId\n      storeId\n    }\n  }\n',
): (typeof documents)['\n  query GetUserBrandStoreSelection($input: InputRolePermUserCenterGetUserBrandStoreSelectionReq!) {\n    GetUserBrandStoreSelection(input: $input)  {\n      brandId\n      storeId\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  mutation SaveDeviceInfo($input: InputDevicemonitorSaveDeviceInfoReq!) {\n    SaveDeviceInfo(input: $input) \n  }\n',
): (typeof documents)['\n  mutation SaveDeviceInfo($input: InputDevicemonitorSaveDeviceInfoReq!) {\n    SaveDeviceInfo(input: $input) \n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query QueryDeviceInfo($input: InputDevicemonitorQueryDeviceInfoReq!) {\n    QueryDeviceInfo(input: $input)  {\n      brandId\n      storeId\n      appVersion\n      appName\n      osVersion\n      manufacturer\n      model\n      platform\n      packageName\n      deviceName\n      deviceId\n      addTime\n      systemAddTime\n      modifyTime\n      systemModifyTime\n    }\n  }\n',
): (typeof documents)['\n  query QueryDeviceInfo($input: InputDevicemonitorQueryDeviceInfoReq!) {\n    QueryDeviceInfo(input: $input)  {\n      brandId\n      storeId\n      appVersion\n      appName\n      osVersion\n      manufacturer\n      model\n      platform\n      packageName\n      deviceName\n      deviceId\n      addTime\n      systemAddTime\n      modifyTime\n      systemModifyTime\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query GetSingleCategoryMessages($input: InputNotificationCenterCenterSingleUnreadCategoryRequest!) {\n    GetSingleCategoryMessages(input: $input)  {\n      singleCategory {\n        categoryId\n        categoryName\n        categoryCount\n        NotificationList {\n          msgType\n          eventId\n          templateId\n          content\n          code\n          msgPushMode\n          title\n          payload\n          notificationId\n          categoryId\n          isRead\n          SendTime\n        }\n      }\n      totalCount\n    }\n  }\n',
): (typeof documents)['\n  query GetSingleCategoryMessages($input: InputNotificationCenterCenterSingleUnreadCategoryRequest!) {\n    GetSingleCategoryMessages(input: $input)  {\n      singleCategory {\n        categoryId\n        categoryName\n        categoryCount\n        NotificationList {\n          msgType\n          eventId\n          templateId\n          content\n          code\n          msgPushMode\n          title\n          payload\n          notificationId\n          categoryId\n          isRead\n          SendTime\n        }\n      }\n      totalCount\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query MarkCategoryAsRead($input: InputNotificationCenterCenterMarkCategoryAsReadRequest!) {\n    MarkCategoryAsRead(input: $input) \n  }\n',
): (typeof documents)['\n  query MarkCategoryAsRead($input: InputNotificationCenterCenterMarkCategoryAsReadRequest!) {\n    MarkCategoryAsRead(input: $input) \n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query GetDiscountTagPage($input: InputCostRecordGetDiscountTagPageReq!) {\n    GetDiscountTagPage(input: $input)  {\n      total\n    }\n  }\n',
): (typeof documents)['\n  query GetDiscountTagPage($input: InputCostRecordGetDiscountTagPageReq!) {\n    GetDiscountTagPage(input: $input)  {\n      total\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query GetShelfSuCount($input: InputSaleunitBrandStoreIdReq!) {\n    GetShelfSuCount(input: $input)  {\n      shelfSuNum\n    }\n  }\n',
): (typeof documents)['\n  query GetShelfSuCount($input: InputSaleunitBrandStoreIdReq!) {\n    GetShelfSuCount(input: $input)  {\n      shelfSuNum\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query GetMergedReason($GetRefundReasonInput:InputOrderconfigGetRefundReasonRequest!,$GetDiscountReasonInput:InputOrderconfigGetDiscountReasonRequest!) {\n    GetRefundReason(input: $GetRefundReasonInput) {\n      isMust\n      items {\n        name\n      }\n    }\n    GetDiscountReason(input: $GetDiscountReasonInput) {\n      name\n    }\n  }\n',
): (typeof documents)['\n  query GetMergedReason($GetRefundReasonInput:InputOrderconfigGetRefundReasonRequest!,$GetDiscountReasonInput:InputOrderconfigGetDiscountReasonRequest!) {\n    GetRefundReason(input: $GetRefundReasonInput) {\n      isMust\n      items {\n        name\n      }\n    }\n    GetDiscountReason(input: $GetDiscountReasonInput) {\n      name\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query GetMergedPrinterList($GetOrderReceiptListInput: InputOrderconfigGetOrderReceiptListReq!,$ListKitchenInput: InputKitchenworkstationListKitchenRequest!) {\n    GetOrderReceiptList(input: $GetOrderReceiptListInput) { \n      printerId\n      brandId\n      storeId\n      deviceId\n      name\n      enableGraphicPrint\n      enableBeep\n      receiptList {\n        receipt\n        channel\n        eatType\n        count\n      }\n      physicalPrinterId\n      printer {\n        id\n        printNodeId\n        name\n        type\n        paperSize\n        connectType\n        address\n        encoding\n        errorCode\n        direction\n        margin\n        space\n        ackLevel\n      }\n      addTime\n    }\n    ListKitchen(input: $ListKitchenInput) { \n      total\n      list {\n        workstationNo\n        workstationName\n        storeId\n        brandId\n        suList {\n          suNo\n        }\n        printerList {\n          printerId\n          storeId\n          brandId\n          workstationNo\n          printerName\n          deviceId\n          physicalPrinterId\n          diningStyles\n          receipt {\n            kitchenTicket {\n              enablePrint\n              count\n              printingMode\n              sameMealIsPrintedTogether\n              packagesArePrintedTogether\n            }\n            voidItemTicket {\n              enablePrint\n              count\n            }\n            changeTableTicket {\n              enablePrint\n              count\n            }\n          }\n          receiptType\n          addTime\n          printer {\n            id\n            printNodeId\n            name\n            type\n            paperSize\n            connectType\n            address\n            encoding\n            errorCode\n            direction\n            margin\n            space\n            ackLevel\n          }\n        }\n        isDefault\n      }\n    }\n  }\n',
): (typeof documents)['\n  query GetMergedPrinterList($GetOrderReceiptListInput: InputOrderconfigGetOrderReceiptListReq!,$ListKitchenInput: InputKitchenworkstationListKitchenRequest!) {\n    GetOrderReceiptList(input: $GetOrderReceiptListInput) { \n      printerId\n      brandId\n      storeId\n      deviceId\n      name\n      enableGraphicPrint\n      enableBeep\n      receiptList {\n        receipt\n        channel\n        eatType\n        count\n      }\n      physicalPrinterId\n      printer {\n        id\n        printNodeId\n        name\n        type\n        paperSize\n        connectType\n        address\n        encoding\n        errorCode\n        direction\n        margin\n        space\n        ackLevel\n      }\n      addTime\n    }\n    ListKitchen(input: $ListKitchenInput) { \n      total\n      list {\n        workstationNo\n        workstationName\n        storeId\n        brandId\n        suList {\n          suNo\n        }\n        printerList {\n          printerId\n          storeId\n          brandId\n          workstationNo\n          printerName\n          deviceId\n          physicalPrinterId\n          diningStyles\n          receipt {\n            kitchenTicket {\n              enablePrint\n              count\n              printingMode\n              sameMealIsPrintedTogether\n              packagesArePrintedTogether\n            }\n            voidItemTicket {\n              enablePrint\n              count\n            }\n            changeTableTicket {\n              enablePrint\n              count\n            }\n          }\n          receiptType\n          addTime\n          printer {\n            id\n            printNodeId\n            name\n            type\n            paperSize\n            connectType\n            address\n            encoding\n            errorCode\n            direction\n            margin\n            space\n            ackLevel\n          }\n        }\n        isDefault\n      }\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query GetMergeTakeoutInfo($GetTakeoutStoreInfoInput: InputTakeoutStoreGetTakeoutStoreInfoRequest!,$CountRelationProductInput: InputTakeoutProductCountRelationProductRequest!){\n    GetTakeoutStoreInfo(input: $GetTakeoutStoreInfoInput)  {\n      brandId\n      storeId\n      outStoreId\n      channelType\n      storeBusinessStatus\n      hasAuth\n    }\n    CountRelationProduct(input: $CountRelationProductInput) {\n      count\n      isAllAssociated\n    }\n  }\n',
): (typeof documents)['\n  query GetMergeTakeoutInfo($GetTakeoutStoreInfoInput: InputTakeoutStoreGetTakeoutStoreInfoRequest!,$CountRelationProductInput: InputTakeoutProductCountRelationProductRequest!){\n    GetTakeoutStoreInfo(input: $GetTakeoutStoreInfoInput)  {\n      brandId\n      storeId\n      outStoreId\n      channelType\n      storeBusinessStatus\n      hasAuth\n    }\n    CountRelationProduct(input: $CountRelationProductInput) {\n      count\n      isAllAssociated\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n    query GetStoreStoreModule($input: InputOnlinesalesGetStoreStoreModuleRequest!) {\n      GetStoreStoreModule(input: $input)  {\n        saleModuleKey\n        valid\n      }\n    }\n',
): (typeof documents)['\n    query GetStoreStoreModule($input: InputOnlinesalesGetStoreStoreModuleRequest!) {\n      GetStoreStoreModule(input: $input)  {\n        saleModuleKey\n        valid\n      }\n    }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  fragment TodoStep on TodoStep  {\n    name\n    id\n  }\n',
): (typeof documents)['\n  fragment TodoStep on TodoStep  {\n    name\n    id\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  fragment TodoReward on TodoReward  {\n    rewardNo\n    name\n    storeTryDays\n    provide\n    number\n  }\n',
): (typeof documents)['\n  fragment TodoReward on TodoReward  {\n    rewardNo\n    name\n    storeTryDays\n    provide\n    number\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  fragment TodoExtend on TodoExtend  {\n    isCopyEnd\n  }\n',
): (typeof documents)['\n  fragment TodoExtend on TodoExtend  {\n    isCopyEnd\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  fragment TodoCheck on TodoCheck  {\n    name\n    checkPass\n    subType\n    steps {...TodoStep}\n    rewards {...TodoReward}\n    required\n    prevChecks\n    extend {...TodoExtend}\n  }\n',
): (typeof documents)['\n  fragment TodoCheck on TodoCheck  {\n    name\n    checkPass\n    subType\n    steps {...TodoStep}\n    rewards {...TodoReward}\n    required\n    prevChecks\n    extend {...TodoExtend}\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  fragment TodoTodoListRspData on TodoTodoListRspData  {\n    todoNo\n    brandId\n    storeId\n    name\n    finished\n    required\n    checkList {...TodoCheck}\n    todoType\n    enable\n    id\n  }\n',
): (typeof documents)['\n  fragment TodoTodoListRspData on TodoTodoListRspData  {\n    todoNo\n    brandId\n    storeId\n    name\n    finished\n    required\n    checkList {...TodoCheck}\n    todoType\n    enable\n    id\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  fragment TodoStoreModule on TodoStoreModule  {\n    saleModuleKey\n    saleModuleType\n    days\n  }\n',
): (typeof documents)['\n  fragment TodoStoreModule on TodoStoreModule  {\n    saleModuleKey\n    saleModuleType\n    days\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  fragment TodoTodoFinishedRspData on TodoTodoFinishedRspData  {\n    brandId\n    storeId\n    name\n    storeModule {...TodoStoreModule}\n    bizId\n  }\n',
): (typeof documents)['\n  fragment TodoTodoFinishedRspData on TodoTodoFinishedRspData  {\n    brandId\n    storeId\n    name\n    storeModule {...TodoStoreModule}\n    bizId\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  fragment TakeoutPrinterTimeConfigReceipt on TakeoutPrinterTimeConfigReceipt  {\n    receiptType\n    printType\n    makeTime\n    deliverTime\n  }\n',
): (typeof documents)['\n  fragment TakeoutPrinterTimeConfigReceipt on TakeoutPrinterTimeConfigReceipt  {\n    receiptType\n    printType\n    makeTime\n    deliverTime\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  fragment TakeoutPrinterTimeConfigTakeoutPrinterTimeConfigDetailRespData on TakeoutPrinterTimeConfigTakeoutPrinterTimeConfigDetailRespData  {\n    takeoutPrinterTimeConfigNo\n    brandId\n    storeId\n    receipts {...TakeoutPrinterTimeConfigReceipt}\n  }\n',
): (typeof documents)['\n  fragment TakeoutPrinterTimeConfigTakeoutPrinterTimeConfigDetailRespData on TakeoutPrinterTimeConfigTakeoutPrinterTimeConfigDetailRespData  {\n    takeoutPrinterTimeConfigNo\n    brandId\n    storeId\n    receipts {...TakeoutPrinterTimeConfigReceipt}\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  fragment StoreTaskStoreTaskListRspData on StoreTaskStoreTaskListRspData  {\n    basicTaskNo\n    storeTaskNo\n    brandId\n    storeId\n    type\n    name\n    desc\n    sort\n    status\n    completeMethod\n    updatedAt\n    isCanReverse\n    isCanComplete\n    isCanCancel\n  }\n',
): (typeof documents)['\n  fragment StoreTaskStoreTaskListRspData on StoreTaskStoreTaskListRspData  {\n    basicTaskNo\n    storeTaskNo\n    brandId\n    storeId\n    type\n    name\n    desc\n    sort\n    status\n    completeMethod\n    updatedAt\n    isCanReverse\n    isCanComplete\n    isCanCancel\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query TodoList($input: InputTodoTodoListReq!) {\n    TodoList(input: $input) {...TodoTodoListRspData}\n  }\n',
): (typeof documents)['\n  query TodoList($input: InputTodoTodoListReq!) {\n    TodoList(input: $input) {...TodoTodoListRspData}\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  mutation TodoFinished($input: InputTodoTodoFinishedReq!) {\n    TodoFinished(input: $input) {...TodoTodoFinishedRspData}\n  }\n',
): (typeof documents)['\n  mutation TodoFinished($input: InputTodoTodoFinishedReq!) {\n    TodoFinished(input: $input) {...TodoTodoFinishedRspData}\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query TodoDelete($input: InputTodoTodoDeleteReq!) {\n    TodoDelete(input: $input) \n  }\n',
): (typeof documents)['\n  query TodoDelete($input: InputTodoTodoDeleteReq!) {\n    TodoDelete(input: $input) \n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query TodoExtentUpdate($input: InputTodoTodoExtentUpdateReq!) {\n    TodoExtentUpdate(input: $input) \n  }\n',
): (typeof documents)['\n  query TodoExtentUpdate($input: InputTodoTodoExtentUpdateReq!) {\n    TodoExtentUpdate(input: $input) \n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query TakeoutPrinterTimeConfigDetail($input: InputTakeoutPrinterTimeConfigTakeoutPrinterTimeConfigDetailReq!) {\n    TakeoutPrinterTimeConfigDetail(input: $input) {...TakeoutPrinterTimeConfigTakeoutPrinterTimeConfigDetailRespData}\n  }\n',
): (typeof documents)['\n  query TakeoutPrinterTimeConfigDetail($input: InputTakeoutPrinterTimeConfigTakeoutPrinterTimeConfigDetailReq!) {\n    TakeoutPrinterTimeConfigDetail(input: $input) {...TakeoutPrinterTimeConfigTakeoutPrinterTimeConfigDetailRespData}\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  mutation TakeoutPrinterTimeConfigSave($input: InputTakeoutPrinterTimeConfigTakeoutPrinterTimeConfigSaveReq!) {\n    TakeoutPrinterTimeConfigSave(input: $input) \n  }\n',
): (typeof documents)['\n  mutation TakeoutPrinterTimeConfigSave($input: InputTakeoutPrinterTimeConfigTakeoutPrinterTimeConfigSaveReq!) {\n    TakeoutPrinterTimeConfigSave(input: $input) \n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  mutation TakeoutPrinterTimeConfigCopy($input: InputTakeoutPrinterTimeConfigTakeoutPrinterTimeConfigCopyReq!) {\n    TakeoutPrinterTimeConfigCopy(input: $input) \n  }\n',
): (typeof documents)['\n  mutation TakeoutPrinterTimeConfigCopy($input: InputTakeoutPrinterTimeConfigTakeoutPrinterTimeConfigCopyReq!) {\n    TakeoutPrinterTimeConfigCopy(input: $input) \n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query StoreTaskList($input: InputStoreTaskStoreTaskListReq!) {\n    StoreTaskList(input: $input) {...StoreTaskStoreTaskListRspData}\n  }\n',
): (typeof documents)['\n  query StoreTaskList($input: InputStoreTaskStoreTaskListReq!) {\n    StoreTaskList(input: $input) {...StoreTaskStoreTaskListRspData}\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query StoreTaskComplete($input: InputStoreTaskStoreTaskCompleteReq!) {\n    StoreTaskComplete(input: $input) \n  }\n',
): (typeof documents)['\n  query StoreTaskComplete($input: InputStoreTaskStoreTaskCompleteReq!) {\n    StoreTaskComplete(input: $input) \n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query GetColorMode($input: InputDeviceGetColorModeReq!) {\n    GetColorMode(input: $input)  {\n      brandId\n      storeId\n      machineNo\n      colorMode\n    }\n  }\n',
): (typeof documents)['\n  query GetColorMode($input: InputDeviceGetColorModeReq!) {\n    GetColorMode(input: $input)  {\n      brandId\n      storeId\n      machineNo\n      colorMode\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query GetStore($input: InputStoreBusinessGetStoreRequest!) {\n    GetStore(input: $input) {\n      storeId\n      brandId\n      storeName\n      logo\n      tel\n      mobile\n      state\n      county\n      city\n      address\n      addressDetail\n      cityCode\n      lbsLng\n      lbsLat\n      status\n      remark\n      storeNumber\n      isPosAll\n      autoSoldOut\n      isPlate\n      isPlateRequired\n    }\n  }\n',
): (typeof documents)['\n  query GetStore($input: InputStoreBusinessGetStoreRequest!) {\n    GetStore(input: $input) {\n      storeId\n      brandId\n      storeName\n      logo\n      tel\n      mobile\n      state\n      county\n      city\n      address\n      addressDetail\n      cityCode\n      lbsLng\n      lbsLat\n      status\n      remark\n      storeNumber\n      isPosAll\n      autoSoldOut\n      isPlate\n      isPlateRequired\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query StoreAll($input: InputStoreBusinessStoreAllRequest!) {\n    StoreAll(input: $input) {\n      store {\n        storeId\n        brandId\n        storeName\n        logo\n        tel\n        mobile\n        state\n        county\n        city\n        address\n        addressDetail\n        cityCode\n        lbsLng\n        lbsLat\n        status\n        remark\n        storeNumber\n        isPosAll\n        autoSoldOut\n        isPlate\n        isPlateRequired\n        dataSource\n      }\n      storeBusiness {\n        storeId\n        configMethod\n        loopMethod\n        businessType\n        monday {\n          startTime\n          endTime\n        }\n        tuesday {\n          startTime\n          endTime\n        }\n        wednesday {\n          startTime\n          endTime\n        }\n        thursday {\n          startTime\n          endTime\n        }\n        friday {\n          startTime\n          endTime\n        }\n        saturday {\n          startTime\n          endTime\n        }\n        sunday {\n          startTime\n          endTime\n        }\n        id\n        brandId\n        isPosAll\n      }\n    }\n  }\n',
): (typeof documents)['\n  query StoreAll($input: InputStoreBusinessStoreAllRequest!) {\n    StoreAll(input: $input) {\n      store {\n        storeId\n        brandId\n        storeName\n        logo\n        tel\n        mobile\n        state\n        county\n        city\n        address\n        addressDetail\n        cityCode\n        lbsLng\n        lbsLat\n        status\n        remark\n        storeNumber\n        isPosAll\n        autoSoldOut\n        isPlate\n        isPlateRequired\n        dataSource\n      }\n      storeBusiness {\n        storeId\n        configMethod\n        loopMethod\n        businessType\n        monday {\n          startTime\n          endTime\n        }\n        tuesday {\n          startTime\n          endTime\n        }\n        wednesday {\n          startTime\n          endTime\n        }\n        thursday {\n          startTime\n          endTime\n        }\n        friday {\n          startTime\n          endTime\n        }\n        saturday {\n          startTime\n          endTime\n        }\n        sunday {\n          startTime\n          endTime\n        }\n        id\n        brandId\n        isPosAll\n      }\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  mutation CreateStore($input: InputStoreBusinessCreatStore!) {\n    CreateStore(input: $input) {\n      storeId\n      brandId\n      storeName\n      logo\n      tel\n      mobile\n      state\n      county\n      city\n      address\n      addressDetail\n      cityCode\n      lbsLng\n      lbsLat\n      status\n      remark\n      storeNumber\n      isPosAll\n      autoSoldOut\n      isPlate\n      isPlateRequired\n    }\n  }\n',
): (typeof documents)['\n  mutation CreateStore($input: InputStoreBusinessCreatStore!) {\n    CreateStore(input: $input) {\n      storeId\n      brandId\n      storeName\n      logo\n      tel\n      mobile\n      state\n      county\n      city\n      address\n      addressDetail\n      cityCode\n      lbsLng\n      lbsLat\n      status\n      remark\n      storeNumber\n      isPosAll\n      autoSoldOut\n      isPlate\n      isPlateRequired\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  mutation UpdateStore($input: InputStoreBusinessStore!) {\n    UpdateStore(input: $input) {\n      storeId\n      brandId\n      storeName\n      logo\n      tel\n      mobile\n      state\n      county\n      city\n      address\n      addressDetail\n      cityCode\n      lbsLng\n      lbsLat\n      status\n      remark\n      storeNumber\n      isPosAll\n      autoSoldOut\n      isPlate\n      isPlateRequired\n    }\n  }\n',
): (typeof documents)['\n  mutation UpdateStore($input: InputStoreBusinessStore!) {\n    UpdateStore(input: $input) {\n      storeId\n      brandId\n      storeName\n      logo\n      tel\n      mobile\n      state\n      county\n      city\n      address\n      addressDetail\n      cityCode\n      lbsLng\n      lbsLat\n      status\n      remark\n      storeNumber\n      isPosAll\n      autoSoldOut\n      isPlate\n      isPlateRequired\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  mutation DeleteStore($input: InputStoreBusinessDeleteStoreRequest!) {\n    DeleteStore(input: $input) {\n      storeId\n      brandId\n      storeName\n      logo\n      tel\n      mobile\n      state\n      county\n      city\n      address\n      addressDetail\n      cityCode\n      lbsLng\n      lbsLat\n      status\n      remark\n      storeNumber\n      isPosAll\n      autoSoldOut\n      isPlate\n      isPlateRequired\n    }\n  }\n',
): (typeof documents)['\n  mutation DeleteStore($input: InputStoreBusinessDeleteStoreRequest!) {\n    DeleteStore(input: $input) {\n      storeId\n      brandId\n      storeName\n      logo\n      tel\n      mobile\n      state\n      county\n      city\n      address\n      addressDetail\n      cityCode\n      lbsLng\n      lbsLat\n      status\n      remark\n      storeNumber\n      isPosAll\n      autoSoldOut\n      isPlate\n      isPlateRequired\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query UserBrandStoreSelection($input: InputRolePermUserCenterUserBrandStoreSelectionReq!) {\n    UserBrandStoreSelection(input: $input) \n  }\n',
): (typeof documents)['\n  query UserBrandStoreSelection($input: InputRolePermUserCenterUserBrandStoreSelectionReq!) {\n    UserBrandStoreSelection(input: $input) \n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query HqUserInfo($input: InputUserUserCenterHqUserInfoReq!) {\n    HqUserInfo(input: $input)  {\n      userId\n      userName\n      phone\n      email\n      dataSource\n      roleInfo {\n        total\n        data {\n          roleId\n          roleName\n        }\n      }\n      employeeId\n      storeData {\n        total\n        data {\n          storeName\n          storeId\n        }\n      }\n    }\n  }\n',
): (typeof documents)['\n  query HqUserInfo($input: InputUserUserCenterHqUserInfoReq!) {\n    HqUserInfo(input: $input)  {\n      userId\n      userName\n      phone\n      email\n      dataSource\n      roleInfo {\n        total\n        data {\n          roleId\n          roleName\n        }\n      }\n      employeeId\n      storeData {\n        total\n        data {\n          storeName\n          storeId\n        }\n      }\n    }\n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n    query CurrentUserPerm($input: InputRolePermUserCenterCurrentUserPermReq!) {\n        CurrentUserPerm(input: $input) {\n            userId\n            brandId\n            roleType\n            roleName\n            roleKey\n            rolePermList {\n                id\n                serverKey\n                serverType\n                name\n                label\n                url\n                level\n                routerVersion\n                order\n                children {\n                    id\n                    serverKey\n                    serverType\n                    name\n                    label\n                    url\n                    level\n                    routerVersion\n                    order\n                    children {\n                        id\n                        serverKey\n                        serverType\n                        name\n                        label\n                        url\n                        level\n                        routerVersion\n                        order\n                    parentKey\n                    }\n                parentKey\n                }\n                parentKey\n            }\n            username\n            storeIds\n        }\n    }\n',
): (typeof documents)['\n    query CurrentUserPerm($input: InputRolePermUserCenterCurrentUserPermReq!) {\n        CurrentUserPerm(input: $input) {\n            userId\n            brandId\n            roleType\n            roleName\n            roleKey\n            rolePermList {\n                id\n                serverKey\n                serverType\n                name\n                label\n                url\n                level\n                routerVersion\n                order\n                children {\n                    id\n                    serverKey\n                    serverType\n                    name\n                    label\n                    url\n                    level\n                    routerVersion\n                    order\n                    children {\n                        id\n                        serverKey\n                        serverType\n                        name\n                        label\n                        url\n                        level\n                        routerVersion\n                        order\n                    parentKey\n                    }\n                parentKey\n                }\n                parentKey\n            }\n            username\n            storeIds\n        }\n    }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n    mutation SaveUserIdAndJPushId($input: InputUserUserCenterSaveUserIdAndJPushIdReq!) {\n      SaveUserIdAndJPushId(input: $input)\n    }\n',
): (typeof documents)['\n    mutation SaveUserIdAndJPushId($input: InputUserUserCenterSaveUserIdAndJPushIdReq!) {\n      SaveUserIdAndJPushId(input: $input)\n    }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  mutation CurrentUserHomeCard($input: InputUserUserCenterCurrentUserHomeCardReq!) {\n    CurrentUserHomeCard(input: $input) \n  }\n',
): (typeof documents)['\n  mutation CurrentUserHomeCard($input: InputUserUserCenterCurrentUserHomeCardReq!) {\n    CurrentUserHomeCard(input: $input) \n  }\n']
/**
 * The gql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function gql(
  source: '\n  query GetCurrentUserHomeCard($input: InputUserUserCenterGetCurrentUserHomeCardReq!) {\n    GetCurrentUserHomeCard(input: $input)  {\n      cards\n    }\n  }\n',
): (typeof documents)['\n  query GetCurrentUserHomeCard($input: InputUserUserCenterGetCurrentUserHomeCardReq!) {\n    GetCurrentUserHomeCard(input: $input)  {\n      cards\n    }\n  }\n']

export function gql(source: string) {
  return (documents as any)[source] ?? {}
}

export type DocumentType<TDocumentNode extends DocumentNode<any, any>> =
  TDocumentNode extends DocumentNode<infer TType, any> ? TType : never
