import { gql } from '@apollo/client'

// 获取门店列表
export const ListStore = gql(`
  query ListStore($input: Input_hqStore_ListStoreRequest!) {
    ListStore(input: $input) {
      list {
        storeId
        brandId
        storeName
        logo
        tel
        mobile
        state
        county
        city
        address
        addressDetail
        cityCode
        lbsLng
        lbsLat
        status
        remark
        storeNumber
        isPosAll
        autoSoldOut
        storeCode
        isPlate
        isPlateRequired
        isDinersNumRequired
        useSupply
        storeOrderMethod {
          client
          scene
          payModel
          diningMode
        }
        dataSource
        BusinessQualifications
      }
    }
  }
`)

// 获取门店列表(包含软删除的门店)
export const ListStoreWithDeleted = gql(`
  query ListStoreWithDeleted($input: Input_hqStore_ListStoreWithDeletedRequest!) {
    ListStoreWithDeleted(input: $input) {
      list {
        storeId
        brandId
        storeName
        logo
        tel
        mobile
        state
        county
        city
        address
        addressDetail
        cityCode
        lbsLng
        lbsLat
        status
        remark
        storeNumber
        isPosAll
        autoSoldOut
        storeCode
        isPlate
        isPlateRequired
        isDinersNumRequired
        useSupply
        storeOrderMethod {
          client
          scene
          payModel
          diningMode
        }
        dataSource
        BusinessQualifications
      }
    }
  }
`)

export const CreateStore = gql(`
  mutation CreateStore($input: Input_hqStore_CreateStoreRequest!) {
    CreateStore(input: $input) {
      storeId
      brandId
      storeName
    }
  }
`)

export const UpdateStore = gql(`
  mutation UpdateStore($input: Input_hqStore_UpdateStoreRequest!) {
    UpdateStore(input: $input)
  }
`)

export const DeleteStore = gql(`
  mutation DeleteStore($input: Input_hqStore_DeleteStoreRequest!) {
    DeleteStore(input: $input) {
      storeId
    }
  }
`)

// 获取门店详情
export const DetailStore = gql(`
  query DetailStore($input: Input_hqStore_DetailStoreRequest!) {
    DetailStore(input: $input) {
      storeId
      brandId
      storeName
      logo
      tel
      mobile
      state
      county
      city
      address
      addressDetail
      cityCode
      lbsLng
      lbsLat
      status
      remark
      storeNumber
      isPosAll
      autoSoldOut
      storeCode
      isPlate
      isPlateRequired
      isDinersNumRequired
      useSupply
      storeOrderMethod {
        client
        scene
        payModel
        diningMode
      }
      dataSource
      BusinessQualifications
    }
  }
`)

// 获取门店详情(包含营业时间)
export const DetailStoreWithBusiness = gql(`
  query DetailStoreWithBusiness($input: Input_hqStore_DetailStoreWithBusinessRequest!) {
    DetailStoreWithBusiness(input: $input) {
      store {
        storeId
        brandId
        storeName
        logo
        tel
        mobile
        state
        county
        city
        address
        addressDetail
        cityCode
        lbsLng
        lbsLat
        status
        remark
        storeNumber
        isPosAll
        autoSoldOut
        storeCode
        isPlate
        isPlateRequired
        isDinersNumRequired
        useSupply
        storeOrderMethod {
          client
          scene
          payModel
          diningMode
        }
        dataSource
        BusinessQualifications
      }
      storeBusiness {
        brandId
        storeId
        id
        businessType
        configMethod
        loopMethod
        monday {
          startTime
          endTime
        }
        tuesday {
          startTime
          endTime
        }
        wednesday {
          startTime
          endTime
        }
        thursday {
          startTime
          endTime
        }
        friday {
          startTime
          endTime
        }
        saturday {
          startTime
          endTime
        }
        sunday {
          startTime
          endTime
        }
      }
    }
  }
`)
