import '@config/index' // 全局配置
import '@common/eventBus' // 全局配置
import { i18nInit } from '@dt/fe-base/dist/i18n'
import { toastLayer, alertLayer } from '@dt/ui-mobile'
import { localStore, localStore as store, trace, vConsole } from '@dt/fe-base'
import {
  appMobx,
  userPermissionMobx,
  storeMobx,
  brandMobx,
  routeMangerMobx,
  deviceMobx,
} from '@mobx'
import { PermissionSdk } from '@dt/fe-business'
import baseDb from '@couchbase/database'
import ProductBaseDb from '@couchbase/product/base.db'
import ProductDataDb from '@couchbase/product/data.db'
import { App, Capacitor, NoticePush } from '@dt/fe-capacitor'
import { initNativePlugin } from './native'
import ENV from '@env'
import enUs from '@common/locales/en-US.json'
import zhCn from '@common/locales/zh-CN.json'
import { changeBrand } from '@utils/utils'
import { DarkMode } from '@aparajita/capacitor-dark-mode'
import { StatusBar, Style } from '@capacitor/status-bar'
import { setClientContext } from '@dt/fe-business/client'
import { getDeviceId } from '@utils/device'
import posthog from 'posthog-js'
import { compare } from 'compare-versions'
import { postDeviceInfo } from './device'

const ThemeType: { Light: IThemeProps; Dark: IThemeProps; Auto: IThemeProps } =
  {
    Light: 'light',
    Dark: 'dark',
    Auto: 'auto',
  }

// trace
async function _dealTrace() {
  const agreement = localStore.get('ls.agreement')
  if (!agreement) return
  // dtfe-base trace 前端监控
  // if (ENV.env?.includes('pro')) {
  //   try {
  //     const appInfo = await App.getAppInfo({
  //       ...(window.versionInfo.main || {}),
  //     })
  //     trace.init({
  //       pid: ENV.THIRD_ARMS.pid, // 应用id
  //       imgUrl: ENV.THIRD_ARMS.imgUrl,
  //       release: appInfo.fullVersion,
  //     })
  //     // 监控
  //     try {
  //       trace?.setConfig?.({
  //         uid: `${Config.brandId || ''}_${Config.storeId || ''}_${Config.userId || ''}_${Config.deviceId || ''}`,
  //       })
  //     } catch (error) {}
  //   } catch (error) {}
  // }
}

// 处理全局监听
function _dealListen() {
  // 网络监听
  App.onNetworkStatusChange((status) => {
    if (status.connected) {
      appMobx.setNetworkError(false)
    } else {
      appMobx.setNetworkError(true)
    }
  })

  // 监听appUrlOpen
  App.addListener('appUrlOpen', (e) => {
    const url = new URL(e.url)
    const method = url.searchParams.get('method')
    if (method === 'user') {
      location.hash = '/user/user'
      return
    }
    if (method === 'device') {
      location.hash = '/mainline/orderDevice'
      return
    }
    if (method === 'table') {
      location.hash = '/mainline/tableArea/create'
      return
    }
  })
  // 监听品牌改变
  window.__eventBus.on(
    window?.__eventBus?.eventEnumMap?.ChangeBrand,
    async ({
      brandId,
      storeId,
      callback,
    }: {
      brandId: number
      storeId: number
      callback: () => void
    }) => {
      await changeBrand(brandId, storeId, callback)
    },
  )
  // 监听门店改变
  window.__eventBus.on(
    window?.__eventBus?.eventEnumMap?.ChangeStore,
    async ({
      storeId,
      callback,
    }: {
      storeId: number
      callback: () => void
    }) => {
      console.log('storeId===>', storeId)
      if (storeId) {
        await storeMobx.setCurrentStore(storeId)
        await userPermissionMobx.modulePermissionUpdate(storeId)
        await callback()
      }
    },
  )
  // 监听退出登录
  window.__eventBus?.on(
    window.__eventBus?.eventEnumMap?.Logout,
    (data: { from: string }) => {
      console.log('logout', data)
      appMobx.setLogin(false)
      PermissionSdk.clearAll(true)
      storeMobx.clear()
      brandMobx.clear()
      routeMangerMobx.clear()
    },
  )
  // 监听绑定设备，解绑设备
  window.__eventBus?.on(
    window.__eventBus?.eventEnumMap?.BindHqDevice,
    (data: any) => {
      // 绑定设备监听
      console.log('BindHqDevice', data)
      location.reload()
    },
  )
  window.__eventBus?.on(
    window.__eventBus?.eventEnumMap?.LoginSuccess,
    async (data: any) => {
      const deviceInfo = localStore.get('ls.deviceInfo')
      const brandInfo = deviceInfo?.brandInfo || localStore.get('ls.brandInfo')
      const storeInfo = deviceInfo?.storeInfo || localStore.get('ls.storeInfo')
      if (deviceInfo) {
        _dealLogin()
        deviceMobx.init()
        const resp = await brandMobx.switchBrand({
          newBrandId: deviceInfo.brandId,
        })
        if (!resp) return
        brandInfo && brandMobx.setBrandInfo(brandInfo)
        if (storeInfo) {
          storeMobx.setEditStoreInfo(storeInfo)
          storeMobx.setCurrentStoreId(storeInfo?.storeId)
          storeMobx.setCurrentStore(storeInfo?.storeId)
        }
      }
    },
  )
  // 监听页面显隐，重新拉取数据
  window.addEventListener('visibilitychange', () => {
    let hiddenTime = 0
    if (document.visibilityState === 'hidden') {
      hiddenTime = Date.now()
    } else {
      // 隐藏超过3s再拉取
      if ((Date.now() - hiddenTime) / 1000 > 3) {
        console.log('触发拉取')
        deviceMobx.init()
      }
    }
  })
}

// 处理登录 & 品牌
async function _dealLogin() {
  const token = store.get('ls.authorization')?.accessToken
  const sessionId = store.get('ls.sessionId')

  // 兼容
  if (sessionId || token) {
    if (location.hash.includes('/login')) {
      return
    }
    const brandId = store.get('ls.brandInfo')?.brandId
    const storeId = store.get('ls.storeInfo')?.storeId
    const deviceId = store.get('ls.deviceInfo')?.deviceId
    console.log(store.get('ls.deviceInfo'), deviceId, 'deviceInfo222')
    // 未选跳转选品牌页面
    if (
      (!store.get('ls.isSelectedBrand') || !brandId) &&
      !location.hash.includes('/login') &&
      !deviceId
    ) {
      location.hash = '#/selectBrand'
      return
    } else {
      appMobx.setLogin(true)
      storeMobx.setCurrentStoreId(storeId)
      brandMobx.setCurrentBrandId(brandId)

      await PermissionSdk.init('hq', true)

      if (PermissionSdk.hasLoginPerm()) {
        await userPermissionMobx.getUserInfo(brandId, true)
        brandMobx.getBrandList(false, { brandId, notRefresh: true })
        if (storeId) {
          storeMobx.getStoreList(true, storeId, brandId)
          storeMobx.setCurrentStore(storeId)
          postDeviceInfo()
          await userPermissionMobx.modulePermissionUpdate(storeId)
        }
        // console.error(deviceId, 'deviceId33333333')
        if (deviceId) {
          console.log('deviceId 跳转', deviceId)
          location.hash = '#/login'
          return
        }
        if (!storeId) {
          location.hash = '#/store'
          storeMobx.sendFinishChangeStore()
        }
      } else {
        userPermissionMobx.updateNotLoginPermissionModal(true)
      }

      if (window?.userInfo?.userId) {
        posthog.onFeatureFlags(() => {
          const userId = window.userInfo.userId
          const employeeId = window.userInfo.employeeId
          const brandId =
            store.get('ls.brandInfo')?.brandId || window.brandInfo?.brandId || 0
          const userInfo = {
            email: window?.userInfo?.email,
            phone: window?.userInfo?.phone,
            name: window?.userInfo?.userName,
            userId,
            brandId,
          }
          console.log('onFeatureFlags posthog.identify', userId, userInfo)
          posthog.get_distinct_id() !== employeeId &&
            posthog.identify(employeeId, userInfo)
        })
      }
      if (deviceId) {
        console.log('deviceId 跳转', deviceId)
        location.hash = '#/login'
      }
    }
  } else if (!location.hash.includes('/login')) {
    location.hash = '#/login'
  }
}

// 初始化 db
async function initDb() {
  if (App.getPlatform() === 'web') {
    return true
  }

  /** 初始化 */
  await baseDb.initDb('product')
  await ProductBaseDb.initDb()

  window.couchbase = {
    productDb: ProductDataDb,
  }
  return true
}

function initLoad() {
  const loadingDom = document.getElementById('pre-loading')
  if (loadingDom) {
    loadingDom.style.display = 'none'
  }
}
const appendMapScript = () => {
  // 动态加载百度地图API
  const baiduMapScript = document.createElement('script')
  baiduMapScript.id = 'dt-baidu-map'
  baiduMapScript.type = 'text/javascript'
  baiduMapScript.defer = true
  baiduMapScript.async = true
  baiduMapScript.src =
    'https://api.map.baidu.com/api?v=3.0&ak=84oWCrEPVUDk1Ge6RaGzRzb57wki7MwY&callback=initBaiduMapSDK'
  document.body.appendChild(baiduMapScript)
}

const setBMapScript = () => {
  if (window.BMap) {
    return
  }

  const preScript = document.querySelector('#dt-baidu-map')
  if (preScript) {
    preScript.parentElement?.removeChild(preScript)
    appendMapScript()
    return
  }

  appendMapScript()
}

// 初始化 window 变量
function initWindow() {
  // bo
  window.bo = 'cn'

  // Config & userInfo & brandInfo & storeInfo
  const authorization = store.get('ls.authorization')

  const userInfo = store.get('ls.userInfo')
  const brandInfo = store.get('ls.brandInfo')
  const storeInfo = store.get('ls.storeInfo')
  const deviceInfo = store.get('ls.deviceInfo')
  window.toastLayer = toastLayer
  window.alertLayer = alertLayer
  window.userInfo = userInfo || {}
  window.brandInfo = brandInfo || {}
  window.storeInfo = storeInfo || {}
  window.deviceInfo = deviceInfo || {}
  // 兼容
  authorization?.accessToken &&
    (window.Config.token = authorization.accessToken)

  brandInfo?.brandId && (window.Config.brandId = brandInfo.brandId)
  storeInfo?.storeId && (window.Config.storeId = storeInfo.storeId)
  userInfo?.userId && (window.Config.userId = userInfo.userId)

  // version
  window.versionInfo = {
    ...(window.versionInfo || {}),
    main: buildInfo,
  }
  setBMapScript()
  console.log('versionInfo', window.versionInfo)
}

function initDevice() {
  deviceMobx.init(!location.hash.includes('/login'))
}

const handleChangeTheme = async (theme: IThemeProps = ThemeType.Dark) => {
  let curTheme = theme
  if (
    curTheme === ThemeType.Auto &&
    Capacitor.isPluginAvailable('DarkModeNative')
  ) {
    const isDarkMode = await DarkMode.isDarkMode()
    curTheme = isDarkMode?.dark ? ThemeType.Dark : ThemeType.Light
  }
  // 存储当前系统实际应用的主题色, 供初始化页面使用
  localStorage.setItem('ls.currentTheme', curTheme)
  if (curTheme === ThemeType.Light) {
    // 安卓状态栏颜色同步
    if (
      App.getPlatform() === 'android' &&
      Capacitor.isPluginAvailable('StatusBar')
    ) {
      await StatusBar.setOverlaysWebView({ overlay: true })
    }
    // ionic 组件深色主题色，不添加则为浅色主题
    document.documentElement.classList.remove('ion-palette-dark')
    // eshine交互定义的浅色主题
    document.documentElement.classList.add('light-theme')
    if (Capacitor.isPluginAvailable('StatusBar')) {
      await StatusBar.setStyle({ style: Style.Light })
    }
  } else if (curTheme === ThemeType.Dark) {
    document.documentElement.classList.remove('light-theme')
    document.documentElement.classList.add('ion-palette-dark')
    if (Capacitor.isPluginAvailable('StatusBar')) {
      await StatusBar.setStyle({ style: Style.Dark })
    }
  }
}
// 初始化主题色
export async function initTheme() {
  let curTheme: IThemeProps = store.get('ls.colorMode') || ThemeType.Dark
  if (Capacitor.isPluginAvailable('DarkModeNative')) {
    // dark插件可用状况下，默认自动跟随系统
    curTheme = store.get('ls.colorMode') || ThemeType.Auto
    await DarkMode.init({
      syncStatusBar: false,
    })
    // 监听系统主题色变化
    await DarkMode.addAppearanceListener((res) => {
      // 获取当前设置的主题
      const currentSetTheme = store.get('ls.colorMode')
      // 当前主题色不跟随系统时，不做处理
      if (currentSetTheme !== ThemeType.Auto) return
      const resTheme = res.dark ? ThemeType.Dark : ThemeType.Light
      console.log('触发颜色切换', res, resTheme)
      handleChangeTheme(resTheme)
    })
  } else if (curTheme === ThemeType.Auto) {
    console.log('theme unavailable')
    // 若app壳上dark插件未安装且为跟随系统模式，默认展示dark样式
    curTheme = ThemeType.Dark
  }
  store.set('ls.colorMode', curTheme)
  await handleChangeTheme(curTheme)

  // 监听主题色配置更改变化
  window.__eventBus?.on(
    window.__eventBus?.eventEnumMap?.ThemeChange,
    async (themeData: any) => {
      const resTheme = themeData?.theme || ThemeType.Dark
      handleChangeTheme(resTheme)
    },
  )
}

const initChatwoot = () => {
  console.log('initChatwoot')
  const script = document.createElement('script') as HTMLScriptElement
  const firstScript = document.getElementsByTagName('script')[0]
  script.src = ENV.chatWoot.baseUrl + '/packs/js/sdk.js'
  script.defer = true
  script.async = true
  firstScript.parentNode?.insertBefore(script, firstScript)
  script.onload = () => {
    if (window.chatwootSDK) {
      console.log('chatwoot script.onload')
      window.chatwootSDK.run({
        websiteToken: ENV.chatWoot.websiteToken,
        baseUrl: ENV.chatWoot.baseUrl,
      })
    }
  }
  window.addEventListener('chatwoot:ready', function () {
    console.log('chatwoot:ready')
    window.$chatwoot && window.$chatwoot.toggleBubbleVisibility('hide')
  })
}

const initPosthog = async () => {
  const agreement = localStore.get('ls.agreement')
  if (!agreement) return
  try {
    const appInfo = await App.getAppInfo()
    console.log('initPosthog', appInfo)
    // 在生产环境且版本大于等于1.0.10，或非生产环境时初始化
    if (
      (ENV.env === 'prod' && compare(appInfo.version, '1.0.10', '>=')) ||
      ENV.env !== 'prod' ||
      Capacitor.getPlatform() === 'web'
    ) {
      posthog.init(ENV.posthog.api_key, {
        api_host: ENV.posthog.api_host,
        capture_pageview: true,
      })
      window.$posthog = posthog
    }
  } catch (error) {
    console.error('PostHog 初始化失败:', error)
  }
}

/**
 * 初始化同意协议
 * 由于合规隐私后面才接入，之前已经登录的用户默认同意协议
 * 所以需要初始化同意协议
 */
const initAgreement = () => {
  const loginInfo = localStore.get('ls.loginInfo')
  if (loginInfo) {
    const isAgreement = localStore.get('ls.agreement')
    if (!isAgreement) {
      localStore.set('ls.agreement', true)
    }
  }
}
export async function init() {
  initLoad()
  initAgreement()
  // 原生能力 初始化
  await initNativePlugin()
  setClientContext(
    { uri: ENV.HQGQL, newUri: ENV.HQGQL_NEW },
    { serviceName: 'mobile-hq' },
  )
  // window 全局变量
  initWindow()

  // 前端监控
  _dealTrace()

  // 标记 init
  appMobx.setInited(true)

  /** 设备绑定 */
  initDevice()

  // i18n
  i18nInit({
    isDev: process.env.NODE_ENV === 'development',
    project: 'mobile-hq',
    bo: ENV.BO as 'cn',
    env: ENV.env,
    lang: window.Config?.lang || 'zh',
    resources: {
      'zh-CN': {
        i18n: zhCn,
      },
      'en-US': {
        i18n: enUs,
      },
      'de-DE': {
        i18n: enUs,
      },
    },
  })

  // vconsole
  vConsole.init()

  // 监听
  _dealListen()

  // 登录
  await _dealLogin()

  // init db
  initDb()

  // init 主题色
  await initTheme()

  // 初始化 chatwoot
  initChatwoot()

  // 初始化 PostHog 分析工具
  initPosthog()

  return Promise.resolve()
}

/** 同意协议成功后，初始化前端监控 */
window.__eventBus.on(
  window.__eventBus.eventEnumMap.AgreementSuccess,
  async () => {
    _dealTrace()
    initPosthog()
  },
)
