import { useEffect } from 'react'
import ENV from '@common/env'
import { format, localStore } from '@dt/fe-base'
import { PermissionSdk } from '@dt/fe-business'

import {
  brandMobx,
  storeMobx,
  mqttMobx,
  deviceMobx,
  userPermissionMobx,
} from '@mobx'

export const useMqttInit = () => {
  useEffect(() => {
    const init = async () => {
      const brandInfo = localStore.get('ls.brandInfo')
      const storeInfo = localStore.get('ls.storeInfo')
      const deviceInfo = localStore.get('ls.deviceInfo')
      const currentBrandId = brandMobx.currentBrandId || brandInfo?.brandId
      const currentStoreId = storeMobx.currentStoreId || storeInfo?.storeId
      if (currentBrandId && currentStoreId) {
        await mqttMobx.init({
          domain: ENV.MQTTSERVERDOMAIN,
          brandId: String(currentBrandId),
          storeId: String(currentStoreId),
          deviceId: deviceInfo?.deviceId || '',
          token: localStore.get('ls.authorization')?.mqToken || '',
        })
        // 品牌级别mqtt消息订阅
        mqttMobx.subscribe(`brands/${currentBrandId}`, async (res) => {
          const { bizType, payload } = res?.data || {}
          switch (bizType) {
            case 'config.perm.update':
              if (
                payload?.userIds?.includes(
                  localStore.get('ls.userInfo')?.userId,
                )
              ) {
                await PermissionSdk.permissionInfoUpdate({})

                if (PermissionSdk.hasLoginPerm()) {
                  userPermissionMobx.modulePermissionUpdate(
                    localStore.get('ls.storeInfo')?.storeId || 0,
                  )
                } else {
                  localStore.clearAll()
                  location.hash = '#/login'
                  // userPermissionMobx.updateNotLoginPermissionModal(true)
                }
              }
              break
            default:
              window.__eventBus?.emit?.(`mqtt.brand.${bizType}`, payload)
              break
          }
        })
        // 门店级别mqtt消息订阅
        mqttMobx.subscribe(`stores/${currentStoreId}`, (res) => {
          console.log(
            `门店级别mqtt消息(${format.toLocalLongTimeFormat(Date.now())}): => `,
            res,
          )
          const { bizType, payload } = res?.data || {}
          switch (bizType) {
            default:
              window.__eventBus?.emit?.(`mqtt.store.${bizType}`, payload)
              break
          }
        })
        if (deviceInfo) {
          // 门店级别mqtt消息订阅
          mqttMobx.subscribe(`devices/${deviceInfo.deviceId}`, (res) => {
            console.log(
              `设备级别mqtt消息(${format.toLocalLongTimeFormat(Date.now())}): => `,
              res,
            )
            switch (res.data.bizType) {
              case 'device.storeId.change':
                deviceMobx.unbind()
                return
            }
          })
        }
      }
    }

    init()

    return () => {
      mqttMobx.disConnect()
    }
  }, [brandMobx.currentBrandId, storeMobx.currentStoreId])
}
