import { localStore, pageSpy } from '@dt/fe-base'
import { App, Orientation, Trace, Bugly } from '@dt/fe-capacitor'
import ENV from '@env'
import { appMobx } from '@mobx'
import { LiveUpdate } from 'capacitor-plugin-live-update'
import { Capacitor } from '@capacitor/core'

const initSentry = async () => {
  // sentry 监控
  const appInfo = await App.getAppInfo({
    ...(window.versionInfo.main || {}),
  })
  // 监控
  try {
    Trace.init({
      dsn: 'https://9d0a70831c0ebede8d5ad50a496184ff@sentry.eshine.cn/4',
      env: ENV.env as any,
      release: `mobile-hq@${appInfo.fullVersion}`,
      captureReplayContent: !ENV.env.includes('pro'),
    })
    Trace?.setUser?.({
      id: `${Config.brandId || ''}_${Config.storeId || ''}_${Config.userId || ''}_${Config.deviceId || ''}`,
    })
    window.__sentry = Trace.Sentry
  } catch (error) {}
}

export const initNativePlugin = async () => {
  // 判断原生环境
  if (App.isNativePlatform()) {
    // 获取后台配置强制更新版本和下载地址
    appMobx.checkUpgrade()
    App.addListener('appStateChange', () => {
      appMobx.checkUpgrade()
    })
    if (Capacitor.isPluginAvailable('LiveUpdate')) {
      // 取版本信息
      try {
        const { info } = await LiveUpdate.fetchCurProjectsInfo()
        window.projectInfo = JSON.parse(info)
      } catch (e) {
        console.log(e)
      }
    }
    /**
     * 初始化消息，获取权限并获取极光id存入Config中,移入登录后执行
     */
    // try {
    //   await NoticePush.init()
    //   const JPushClientId = await NoticePush.getClientId()
    //   window.Config.jclientId = JPushClientId
    // } catch (e) {
    //   console.log('消息初始化失败 ====>', e)
    // }
    try {
      // 崩溃监控 Bugly => 初始化
      Bugly.initCrashReport()
        .then(() => {
          console.log('bugly initCrashReport success')
        })
        .catch((e) => {
          console.log('bugly error====>', e)
        })
    } catch (error) {
      console.log('bugly error====>', error)
    }

    if (!appMobx.showDebug) {
      const agreement = localStore.get('ls.agreement')
      if (!agreement) {
        window.__eventBus.on(
          window.__eventBus.eventEnumMap.AgreementSuccess,
          async () => {
            initSentry()
          },
        )
      } else {
        initSentry()
      }
    }
    App.getSafeArea()
    App.setStatusBar()
    Orientation.lock({ orientation: 'portrait' })
  }

  // 在线调试debug
  pageSpy.init({
    project: 'mobile-hq',
    title: `${window.Config.brandId || ''}_${window.Config.deviceId || ''}`,
  })

  // 语言
  window.Config.lang = await App.getLanguage()
}
