import { useEffect } from 'react'
import { App, NoticePush } from '@dt/fe-capacitor'
import { storeMobx } from '@mobx'
import { changeBrand } from '@utils/utils'
import { query } from '@dt/fe-business/client'
import { MarkCategoryAsRead } from '@/gqlDocuments/message'

export const useInitNotice = () => {
  const handlerNotice = async (data: any) => {
    const {
      rawData: { categoryId, brandId, storeId },
    } = data
    console.log('接收到的站外消息：', data)
    await change(brandId, storeId)
    // 广播事件，让其他模块接收到消息
    window.__eventBus?.emit?.(
      window.__eventBus?.eventEnumMap?.MessageReceived,
      data,
    )
    // 跳转前已读消息
    categoryId && (await query(MarkCategoryAsRead, { categoryId }))
    window.__eventBus.emit(window?.__eventBus?.eventEnumMap?.ReadMessage)
    // 跳转消息详情
    location.hash = '/message/home'
    // 跳转消息详情
    // location.hash = `/message/detail?categoryId=${categoryId}`
  }

  /**
   * 品牌切换
   * @param brandId
   */
  const change = async (brandId: number, storeId: number) => {
    if (brandId !== window.Config.brandId) {
      await changeBrand(brandId, storeId)
      return
    }
    await changeStore(storeId)
  }

  /**
   * 门店切换
   * @param storeId
   */
  const changeStore = async (storeId: number) => {
    if (storeId !== window.Config.storeId) {
      // 切换门店
      await storeMobx.setCurrentStore(storeId)
    }
  }

  useEffect(() => {
    const initNotice = async () => {
      if (!App.isNativePlatform()) return

      try {
        // 全局监听消息
        // TODO 本期站内信不弹，后期优化
        // NoticePush.emitter((data) => {
        //   const { rawData: { aps: { badge }, messageType }, title, content } = data;
        //   // 设置图标消息个数
        //   NoticePush.setBadgeNumber(badge);

        //   // 站内消息弹窗
        //   toastLayer.show({
        //     cssClass: 'notice-toast',
        //     swipeGesture: 'vertical',
        //     header: title,
        //     message: content,
        //     duration: 2000,
        //     position: 'top',
        //     positionAnchor: 'ion-header',
        //     buttons: [
        //       {
        //         icon: chevronForwardOutline,
        //         handler() {
        //           __history.push('/message-detail', { type: messageType });
        //         }
        //       }
        //     ],
        //     icon: toastStopIcon
        //   });
        // });

        // 监听站外信息打开动作，跳转消息详情
        NoticePush.open((data) => {
          handlerNotice(data)
        })
        // 启动推送消息
        NoticePush.addListener('launchNotificationReceived', (data) => {
          console.log('启动推送消息: =>', data)
          handlerNotice(data)
        })
      } catch (e) {
        console.log(e)
      }
    }

    initNotice()
  }, [])
}
