import { CommonApi } from '@api'
import { makeAutoObservable, runInAction } from 'mobx'
import { CapacitorCookies } from '@dt/fe-capacitor/dist/Core'
import { cookie, localStore, pageSpy, vConsole } from '@dt/fe-base'
import ConfigAPI from '@api/config.api'
import { App } from '@dt/fe-capacitor'
import { compareVersions } from '@cps/modals/AppUpdateModal/compare'
import { clearStore } from '@utils'

class AppMobx {
  constructor() {
    makeAutoObservable(this, {}, { autoBind: true })
    window.__eventBus.on(
      window.__eventBus.eventEnumMap.AgreementSuccess,
      async () => {
        this.checkUpgrade()
      },
    )
  }

  isLogin = false

  prePath = ''

  pageLoading = false

  inited = false

  // 网络异常toast
  networkError: boolean = false

  // 当前路由
  curPath: string = ''

  // menu 打开状态
  menuOpen: boolean = false

  // 是否展示debug
  showDebug: boolean = !!localStore.get(vConsole.lsKey)

  // 是否展示在线调试
  showOnlineDebug: boolean = !!cookie.getCookie(pageSpy.ckKey)

  // 是否展示升级弹窗
  showUpgradeModal: boolean = false

  // 升级信息
  upgradeInfo: IUpgradeInfo = {
    updateNative: false,
    version: '',
    downloadUrl: '',
  }

  setLogin(flag: boolean) {
    this.isLogin = flag
  }

  // 设置当前路由
  setCurPath(path: string) {
    this.curPath = path
  }

  // 设置菜单打开状态
  setMenuOpen(flag: boolean) {
    this.menuOpen = flag
  }

  // 展示/隐藏 debug
  setShowDebug(debug: boolean) {
    this.showDebug = debug
    debug ? vConsole.show() : vConsole.hide()
  }

  // 展示/隐藏 在线调试
  setShowOnlineDebug(onlineDebug: boolean) {
    this.showOnlineDebug = onlineDebug
    onlineDebug ? pageSpy.show() : pageSpy.hide()
  }

  // 展示升级弹窗
  setShowUpgradeModal(show: boolean) {
    this.showUpgradeModal = show
  }

  // 获取升级信息
  async checkUpgrade() {
    const agreement = localStore.get('ls.agreement')
    if (!agreement) return
    try {
      const { version = '' } = await App.getAppInfo()
      const res: any = await ConfigAPI.appVersionLatest(App.getPlatform())
      if (version && res.code === 0) {
        runInAction(() => {
          this.upgradeInfo = {
            updateNative: compareVersions(version, res?.data?.version),
            version: res?.data?.version,
            downloadUrl: res?.data?.url,
          }
          console.log('app更新数据upgradeInfo', this.upgradeInfo)
        })
        return true
      }
    } catch (error) {
      console.log('error', error)
    }
  }

  // 初始化
  async init() {
    // this.checkUpgrade()
    return true
  }
  // 设置网络异常
  setNetworkError(flag: boolean) {
    this.networkError = flag
  }

  setPrePath(path: string) {
    this.prePath = path
  }

  setPageLoading(loading: boolean) {
    this.pageLoading = loading
  }

  setInited(inited: boolean) {
    this.inited = inited
  }

  async logout() {
    await CommonApi.logout()
    clearStore()
    await CapacitorCookies.clearAllCookies()
  }
}

export default new AppMobx()
