import { makeAutoObservable } from 'mobx'
import { cardMap, TCardItem } from '@pages/home/components/Card'
class CardMobx {
  constructor() {
    makeAutoObservable(this)
  }
  allCards: typeof cardMap = {}
  cardNames: string[] = []
  get group() {
    const cardList: TCardItem[] = []
    const allCards = { ...this.allCards }
    this.cardNames.forEach((name) => {
      const item = allCards[name]
      if (item && !item.hide) {
        cardList.push({ name, ...item })
        delete allCards[name]
      }
    })
    const unaddedCardList = Object.entries(allCards).reduce(
      (result, [name, item]) => {
        if (!item.hide) {
          result.push({ name, ...item })
        }
        return result
      },
      [] as TCardItem[],
    )
    return { cardList, unaddedCardList }
  }
  setCardNames(cardNames: string[]) {
    this.cardNames = cardNames
  }
  setAllCards(cards: typeof cardMap) {
    this.allCards = cards
  }
  moveCard(fromName: string, toName: string) {
    const fromIndex = this.cardNames.indexOf(fromName)
    const toIndex = this.cardNames.indexOf(toName)
    const newList = [...this.cardNames]
    const [movedItem] = newList.splice(fromIndex, 1)
    newList.splice(toIndex, 0, movedItem)
    this.cardNames = newList
  }
  deleteCard(name: string) {
    const index = this.cardNames.indexOf(name)
    if (index !== -1) {
      const newList = [...this.cardNames]
      newList.splice(index, 1)
      this.cardNames = newList
    }
  }
  addCards(names: string[]) {
    this.cardNames = Array.from(new Set([...this.cardNames, ...names]))
  }
}

export default new CardMobx()
