import { makeAutoObservable, runInAction } from 'mobx'
import { localStore } from '@dt/fe-base'
import DeviceAPI from '@api/device.api'
import { getDeviceId } from '@utils/device'
import { App, CapacitorCookies, Storage } from '@dt/fe-capacitor'
import Cookies from 'js-cookie'
import brandMobx from './brand.mobx'

/**
 * 缓存设备与门店品牌信息
 * @param localInfo
 */
export const setLocalDeviceInfo = (localInfo: any) => {
  if (App.isNativePlatform()) {
    Cookies.remove('brandid')
    Cookies.set('brandid', `${localInfo.brandId}`, { expires: 30 })
    CapacitorCookies.clearAllCookies()
    CapacitorCookies.setCookie({
      key: 'brandid',
      value: localInfo.brandId.toString(),
      url: location.origin,
    })
  } else {
    Cookies.remove('brandid')
    Cookies.set('brandid', `${localInfo.brandId}`, { expires: 30 })
  }
  localStore.set('ls.isSelectedBrand', true)
  localStore.set('ls.deviceInfo', localInfo)
  localStore.set('ls.brandInfo', localInfo.brandInfo)
  App.isNativePlatform() &&
    Storage.set('brandId', localInfo.brandInfo.brandId.toString())
  localStore.set('ls.storeInfo', localInfo.storeInfo)
}
class DeviceMobx {
  constructor() {
    makeAutoObservable(this, {}, { autoBind: true })

    window.__eventBus.on(
      window.__eventBus.eventEnumMap.AgreementSuccess,
      async () => {
        this.init()
      },
    )
  }
  deviceInfo: IDeviceInfo | null = null
  deviceId: string = ''

  async init(canReload?: boolean) {
    const agreement = localStore.get('ls.agreement')
    if (!agreement) return
    try {
      const saveDeviceId = localStore.get('ls.currentDeviceId')
      const deviceId = saveDeviceId || (await getDeviceId('rms'))
      const res: any = await DeviceAPI.getDeviceInfo({
        deviceId,
      })
      if (res.data && res.data.storeDeviceId) {
        this.deviceInfo = res.data
        this.deviceId = res.data.deviceId
        setLocalDeviceInfo(res.data)
        canReload && brandMobx.reload()
      } else {
        const deviceInfo = localStore.get('ls.deviceInfo')
        if (deviceInfo) {
          this.unbind()
        }
      }
    } catch (error) {
      console.log(error)
    }
    return
  }
  unbind() {
    localStore.clearAll()
    location.href = '#/login'
    setTimeout(() => {
      location.reload()
    }, 200)
  }
}

export default new DeviceMobx()
