import { makeAutoObservable } from 'mobx'
// import { menuHome, menuMessage, menuMine } from '@icons'
import { keyBy } from '@dt/fe-base/dist/lodash'

// IMenuItemRedDot
export interface IMenuItemRedDot {
  index: number
}

// IMenuItemBarBadge
export interface IMenuItemBadge {
  index: number
  text: string
}

// IMenuItem
interface IMenuItem {
  key: '/home' | '/mine'
  icon: string
}

class Menu {
  constructor() {
    makeAutoObservable(this, {}, { autoBind: true })
  }
  showMenu = false

  /** 红点 */
  redDots: IMenuItemRedDot[] = []

  /** 角标 */
  badges: IMenuItemBadge[] = []

  /** 红点map */
  get redDotMap() {
    return keyBy(this.redDots, 'index')
  }

  /** 角标map */
  get badgeMap() {
    return keyBy(this.badges, 'index')
  }

  toggleMenu(show: boolean = false) {
    console.trace('toggleMenu', show)
    this.showMenu = show
  }

  /** 展示红点 */
  showRedDot(item: IMenuItemRedDot) {
    const idx = this.redDots.findIndex((d) => d.index === item.index)
    idx > -1 ? this.redDots.splice(idx, 1, item) : this.redDots.push(item)
  }

  /** 隐藏红点 */
  hideRedDot(item: IMenuItemRedDot) {
    const idx = this.redDots.findIndex((d) => d.index === item.index)
    idx > -1 ? this.redDots.splice(idx, 1) : null
  }

  /** 展示角标 */
  showBadge(item: IMenuItemBadge) {
    const idx = this.badges.findIndex((d) => d.index === item.index)
    idx > -1 ? this.badges.splice(idx, 1, item) : this.badges.push(item)
  }

  /** 隐藏角标 */
  hideBadge(item: IMenuItemBadge) {
    const idx = this.badges.findIndex((d) => d.index === item.index)
    idx > -1 ? this.badges.splice(idx, 1) : null
  }
}

export default new Menu()
