import { makeAutoObservable } from 'mobx'
import Task from '@sdk/mqtt/task'
import MQTTClient from '@sdk/mqtt'
import { localStore } from '@dt/fe-base'

class MQTTMobx {
  mqttInit = false
  topicList: string[] = []
  params: {
    domain: string
    token: string
    brandId: string
    deviceId?: string
    storeId: string
  } = {
    domain: '',
    token: '',
    brandId: '',
    storeId: '',
  }
  constructor() {
    makeAutoObservable(this)
    window.__eventBus.on(
      window.__eventBus.eventEnumMap.AgreementSuccess,
      async (deviceId: string) => {
        this.init({ ...this.params, deviceId })
      },
    )
  }
  async init(params: {
    domain: string
    token: string
    brandId: string
    deviceId?: string
    storeId: string
  }) {
    this.params = params
    const agreement = localStore.get('ls.agreement')
    if (!agreement) return
    const res = await Task.init(params)
    this.mqttInit = res
  }

  subscribe(topic: string, callback: (payload: any) => void) {
    if (!this.mqttInit) {
      console.log('mqtt mobx unInit')
      return
    }
    this.topicList.push(topic)
    MQTTClient.subscribe(topic, callback)
  }

  unsubscribe(topic: string) {
    this.topicList = this.topicList.filter((i) => i !== topic)
    MQTTClient.unsubscribe(topic)
  }

  disConnect() {
    console.log('mqtt disConnect', this.mqttInit)
    if (!this.mqttInit) return
    if (this.topicList.length) {
      this.topicList.forEach((topic) => {
        MQTTClient.unsubscribe(topic)
      })
    }
    MQTTClient.disconnect()
  }
}

export default new MQTTMobx()
