import { PermissionSdk } from '@dt/fe-business'
import { makeAutoObservable, runInAction } from 'mobx'
import { localStore, dayjs } from '@dt/fe-base'
import client, { newQuery } from '@dt/fe-business/client'
import { ListStore, DetailStoreWithBusiness } from '@/gqlDocumentsNew/store'
import { UserBrandStoreSelection } from '@/gqlDocuments/newStore'
import {
  StoreBusinessStore,
  StoreBusinessStoreBusiness,
  StoreBusinessStoreAll,
  StoreBusinessTime,
} from '@/gql/graphql'
import { find } from '@dt/fe-base/dist/lodash'
import { userPermissionMobx } from '@mobx'

type TWeek =
  | 'monday'
  | 'tuesday'
  | 'wednesday'
  | 'thursday'
  | 'friday'
  | 'saturday'
  | 'sunday'

type TGTime = StoreBusinessTime & { isCurrent?: boolean }

type TGroupTimeList = {
  nameList: string[]
  time: TGTime[]
  timeKeyObj: Record<string, boolean>
}

class StoreMobx {
  constructor() {
    makeAutoObservable(this)

    window.__eventBus.on(
      window?.__eventBus?.eventEnumMap?.ChangeCurrentStore,
      ({ storeId, from }: { storeId: number; from?: string }) => {
        console.log('ChangeCurrentStore', storeId, from)
        this.setCurrentStore(storeId)
      },
    )
  }

  storeList: StoreBusinessStore[] = []
  editStoreInfo: StoreBusinessStore | undefined
  currentStoreInfo = {} as StoreBusinessStoreAll
  timeConfig: Pick<
    StoreBusinessStoreBusiness,
    | 'monday'
    | 'tuesday'
    | 'wednesday'
    | 'thursday'
    | 'friday'
    | 'saturday'
    | 'sunday'
  > = {
    monday: [],
    tuesday: [],
    wednesday: [],
    thursday: [],
    friday: [],
    saturday: [],
    sunday: [],
  }

  isInit: boolean = false

  currentTime = dayjs().format('YYYY-MM-DD/dddd')

  timeGroupList: TGroupTimeList[] = []

  isInBusinessTime = false

  currentStoreId: undefined | number = undefined

  clear() {
    client.cache.reset()
    localStore.remove('ls.storeInfo')
    window.storeInfo = {}
    this.storeList = []
    this.editStoreInfo = undefined
    this.currentStoreInfo = {} as StoreBusinessStoreAll
    this.timeConfig = {
      monday: [],
      tuesday: [],
      wednesday: [],
      thursday: [],
      friday: [],
      saturday: [],
      sunday: [],
    }
    this.currentTime = dayjs().format('YYYY-MM-DD/dddd')
    this.timeGroupList = []
    this.isInBusinessTime = false
    this.currentStoreId = undefined
  }

  async getStoreList(init: boolean, id?: number, notRefresh = false) {
    const res: any = await newQuery(ListStore)
    if (!res?.errors) {
      const saveStoreInfo = localStore.get('ls.storeInfo')
      const storeList = res?.data?.ListStore?.list || []
      if (storeList.length > 0) {
        runInAction(() => {
          this.storeList = storeList as StoreBusinessStore[]
          const storeId = saveStoreInfo
            ? find(
                storeList,
                (store) => store.storeId === saveStoreInfo.storeId,
              )?.storeId || (storeList[0]?.storeId as number)
            : (storeList[0]?.storeId as number)
          // 初始化选择门店不需要默认选中第一个
          if (notRefresh) {
            return
          }
          if (!init) {
            if (!localStore.get('ls.storeInfo')?.storeId) {
              this.setCurrentStore(id || storeId)
            } else {
              this.setCurrentStore(
                id || localStore.get('ls.storeInfo')?.storeId,
              )
            }
          } else {
            this.setCurrentStore(storeId)
          }
        })
      } else {
        runInAction(() => {
          this.clear()
          PermissionSdk.clearModulePermissionList()
          const deviceInfo = localStore.get('ls.deviceInfo')
          if (!deviceInfo?.deviceId) {
            location.hash = '#/store'
          }
        })
      }
      this.sendFinishUpdateStoreList()
    }
  }

  async justUpdateList() {
    const res: any = await newQuery(ListStore)
    if (!res?.errors) {
      runInAction(() => {
        this.storeList = (res?.data?.ListStore?.list ||
          []) as StoreBusinessStore[]
      })
      this.sendFinishUpdateStoreList()
    }
  }

  async getStoreInfo(storeId: number) {
    const res: any = await newQuery(DetailStoreWithBusiness, { storeId })
    if (!res?.errors) {
      const storeAll = res?.data.DetailStoreWithBusiness
      const storeInfo = {
        ...storeAll.store,
        storeId: Number(storeAll.store?.storeId) || 0,
        brandId: Number(storeAll.store?.brandId) || 0,
      }
      window.storeInfo = storeInfo
      window.Config.storeId = storeInfo.storeId as number
      localStore.set('ls.storeInfo', storeInfo)
      await client.cache.reset()
      await userPermissionMobx.modulePermissionUpdate(storeId)
      const storeBusinessDetail = storeAll?.storeBusiness?.[0]
      const obj = {
        monday: storeBusinessDetail?.monday ?? [],
        tuesday: storeBusinessDetail?.tuesday ?? [],
        wednesday: storeBusinessDetail?.wednesday ?? [],
        thursday: storeBusinessDetail?.thursday ?? [],
        friday: storeBusinessDetail?.friday ?? [],
        saturday: storeBusinessDetail?.saturday ?? [],
        sunday: storeBusinessDetail?.sunday ?? [],
      }
      runInAction(() => {
        this.isInBusinessTime = false
        this.currentStoreInfo = storeAll as StoreBusinessStoreAll

        this.timeConfig = obj
        this.setTimeGroup(storeBusinessDetail?.configMethod || 'week')
      })
      return storeAll
    }
    return false
  }

  setTimeGroup(type: string) {
    const list: TGroupTimeList[] = []
    const currDay = dayjs().format('dddd').toLocaleLowerCase()
    const setCurrent = (day: TWeek, item: TGTime[]) => {
      if (currDay === day) {
        item.forEach((v) => {
          if (
            dayjs().isAfter(dayjs(v.startTime, 'HH:mm')) &&
            dayjs().isBefore(dayjs(v.endTime, 'HH:mm'))
          ) {
            ;(v as TGTime).isCurrent = true
            this.isInBusinessTime = true
          }
        })
      }
    }

    const setList = (key: TWeek) => {
      const timeList = this.timeConfig[key] ?? []

      const timeKeyObj = timeList.reduce(
        (prev, curr) => {
          if (curr) {
            const key = ((curr?.startTime as string) +
              '-' +
              curr?.endTime) as string
            prev[key] = true
          }
          return prev
        },
        {} as Record<string, boolean>,
      )

      setCurrent(key, this.timeConfig[key]!)

      list.push({
        nameList: [key],
        time: this.timeConfig[key] ?? [],
        timeKeyObj,
      })
    }

    if (type === 'day') {
      setList(currDay as TWeek)
    } else {
      Object.keys(this.timeConfig).forEach((v) => {
        if (v === 'monday') {
          setList('monday')
        } else {
          list.some((item, index) => {
            if (item.time?.length !== this.timeConfig[v as TWeek]?.length) {
              if (index === list.length - 1) {
                setList(v as TWeek)
                return true
              }
              return false
            } else {
              const curr = this.timeConfig[v as TWeek]!
              const res = curr.find(
                (e) => item.timeKeyObj[`${e.startTime! + '-' + e.endTime!}`],
              )
              if (!res) {
                if (index === list.length - 1) {
                  setList(v as TWeek)
                  return true
                }
                return false
              }
              item.nameList.push(v)
              setCurrent(v as TWeek, item.time)
              return true
            }
          })
        }
      })
    }
    this.currentTime = dayjs().format('YYYY-MM-DD/dddd')
    this.timeGroupList = list
  }

  // 门店信息完成切换事件
  sendFinishChangeStore() {
    window.__eventBus.emit(
      window?.__eventBus?.eventEnumMap?.FinishChangeStore,
      JSON.parse(JSON.stringify(this.currentStoreInfo.store || {})),
    )
  }

  sendFinishUpdateStoreList() {
    window.__eventBus.emit(
      window?.__eventBus?.eventEnumMap?.FinishUpdateStoreList,
      JSON.parse(JSON.stringify(this.storeList || [])),
    )
  }

  async setCurrentStore(storeId?: number) {
    if (storeId) {
      const res = await this.getStoreInfo(storeId)
      if (res) {
        this.uploadSelectStoreId(storeId)
        this.isInit = true
        this.currentStoreId = storeId
        window.Config.storeId = storeId as number
        this.sendFinishChangeStore()
      }
      return res
    }

    return false
  }

  uploadSelectStoreId(storeId: number) {
    return newQuery(UserBrandStoreSelection, {
      storeId,
      userId: localStore.get('ls.userInfo')?.userId || '',
    })
  }

  setEditStoreInfo(storeInfo: StoreBusinessStore | undefined) {
    this.editStoreInfo = storeInfo
  }

  setCurrentStoreId(id: number) {
    this.currentStoreId = id
    userPermissionMobx.modulePermissionUpdate(id)
  }

  setStoreList(list: StoreBusinessStore[]) {
    this.storeList = list
  }
}

export default new StoreMobx()
