import React, { useState, useRef } from 'react'
import { DtItemBlock, DtItemInput, DtIcon, toastLayer } from '@dt/ui-mobile'
import { newMutate } from '@dt/fe-business/client'
import { UpdateStore } from '@/gqlDocumentsNew/store'
import { useHistory } from 'react-router-dom'
import i18n from '@dt/fe-base/dist/i18n'
import {
  chevroExpand,
  chevronCollapse,
  location as locationIcon,
  chevronDown,
} from '@dt/ui-ionic-icon'
import { storeMobx } from '@mobx'
import StoreInput from './StoreInput'
import { observer } from 'mobx-react'
import LocationModal from '@/components/modals/LocationModal'
import './StoreBaseBlock.scss'

interface IStoreBaseBlockProps {
  hasPermission: boolean
}

const StoreBaseBlock = (props: IStoreBaseBlockProps) => {
  const { hasPermission } = props
  const [isShowMoreInfo, setIsShowMoreInfo] = useState(false)
  const [isShowLocationModal, setIsShowLocationModal] = useState(false)

  const pending = useRef(false)
  const history = useHistory()
  const onStoreInfoChange = async (
    type: string,
    data: any,
    required = true,
  ) => {
    if (pending.current) return false
    console.log('data', data)
    if (!data && required) {
      toastLayer.info(i18n.t('common.completeWarning'))
      return false
    }

    let res

    try {
      switch (type) {
        case 'address': {
          pending.current = true
          setIsShowLocationModal(false)
          const params = {
            storeName: storeMobx.currentStoreInfo?.store?.storeName,
            county: data.province,
            city: data.city,
            address: data.address + data.title,
            addressDetail:
              storeMobx.currentStoreInfo?.store?.addressDetail || '',
            lbsLng: String(data.point.lng),
            lbsLat: String(data.point.lat),
            isPosAll: true,
            status: 'enable',
          }
          res = await newMutate(UpdateStore, {
            ...params,
            storeId: storeMobx.currentStoreInfo?.store?.storeId,
          })
          break
        }
        case 'storeName': {
          pending.current = true
          const params = {
            storeName: data,
            county: storeMobx.currentStoreInfo?.store?.county,
            city: storeMobx.currentStoreInfo?.store?.city,
            address: storeMobx.currentStoreInfo?.store?.address,
            addressDetail:
              storeMobx.currentStoreInfo?.store?.addressDetail || '',
            lbsLng: String(storeMobx.currentStoreInfo?.store?.lbsLng),
            lbsLat: String(storeMobx.currentStoreInfo?.store?.lbsLat),
            isPosAll: true,
            status: 'enable',
          }
          res = await newMutate(UpdateStore, {
            ...params,
            storeId: storeMobx.currentStoreInfo?.store?.storeId,
          })

          break
        }

        case 'addressDetail': {
          pending.current = true
          const params = {
            storeName: storeMobx.currentStoreInfo?.store?.storeName,
            county: storeMobx.currentStoreInfo?.store?.county,
            city: storeMobx.currentStoreInfo?.store?.city,
            address: storeMobx.currentStoreInfo?.store?.address,
            addressDetail: data,
            lbsLng: String(storeMobx.currentStoreInfo?.store?.lbsLng),
            lbsLat: String(storeMobx.currentStoreInfo?.store?.lbsLat),
            isPosAll: true,
            status: 'enable',
          }
          res = await newMutate(UpdateStore, {
            ...params,
            storeId: storeMobx.currentStoreInfo?.store?.storeId,
          })
          break
        }

        default:
          break
      }
    } catch (error) {
      pending.current = false
      res = { errors: error }
    } finally {
      pending.current = false
    }

    if (!res?.errors) {
      storeMobx.setCurrentStore(storeMobx.currentStoreInfo?.store?.storeId)
      return true
    }
    return false
  }

  return (
    <>
      <DtItemBlock
        header={{
          title: <span className='title'>{i18n.t('store.baseInfo')}</span>,
        }}
        border
        className='hq-store-base-block-wrap no-margin'
        style={{ padding: 0 }}
      >
        {/* 门店名称 */}
        <StoreInput
          label={i18n.t('store.storeName')}
          value={storeMobx.currentStoreInfo?.store?.storeName}
          disabled={!hasPermission}
          storeId={storeMobx.currentStoreInfo?.store?.storeId}
          showSuffix={true}
          onChange={(value: string) => {
            return onStoreInfoChange('storeName', value)
          }}
        ></StoreInput>

        {/* 门店地址 */}
        <DtItemBlock.Header
          className='store-item-content-address'
          required
          extra={
            <div
              className='store-item-content-address-right'
              onClick={() => setIsShowLocationModal(true)}
            >
              <span>{storeMobx.currentStoreInfo?.store?.address}</span>
              <DtIcon icon={locationIcon} />
            </div>
          }
        >
          {i18n.t('store.storeLocation')}
        </DtItemBlock.Header>

        {/* 详细地址 */}
        <DtItemInput
          useType='newRow'
          dtInputMode='implicit'
          customLabel={i18n.t('store.detailAddress')}
          value={storeMobx.currentStoreInfo?.store?.addressDetail}
          disabled={!hasPermission}
          placeholder={i18n.t('common.inputPlaceholder')}
          onIonChange={(e) => {
            return onStoreInfoChange('addressDetail', e.detail.value, false)
          }}
        />

        {/* 联系电话 */}
        {/* {isShowMoreInfo && (
          <>
            <DtItemInput
              useType='newRow'
              dtInputMode='implicit'
              className='phone-input'
              customLabel={
                <div>
                  <div>{i18n.t('store.phone')}</div>
                  <div className='input-desc'>
                    {i18n.t('store.phonePlaceholder')}
                  </div>
                </div>
              }
              // value={storeMobx.currentStoreInfo?.store?.addressDetail}
              disabled={!hasPermission}
              placeholder={i18n.t('common.inputPlaceholder')}
            />
          </>
        )} */}

        {/* <DtItemBlock.Block>

      </DtItemBlock.Block> */}

        {/* 更多信息 */}
        {/* <DtItemBlock.Header
          onClick={() => setIsShowMoreInfo(!isShowMoreInfo)}
          style={{
            paddingTop: 0,
            minHeight: 72,
          }}
        >
          <div className='more-info-wrap'>
            {isShowMoreInfo ? (
              <>
                {i18n.t('store.collapse')}
                <DtIcon className='collapse-icon' icon={chevronDown} />
              </>
            ) : (
              <>
                {i18n.t('store.moreInfo')}
                <DtIcon icon={chevronDown} />
              </>
            )}
          </div>
        </DtItemBlock.Header> */}
      </DtItemBlock>
      {isShowLocationModal && (
        <LocationModal
          isEdit={true}
          isOpen={isShowLocationModal}
          onClose={() => setIsShowLocationModal(false)}
          onChange={(location: any) => onStoreInfoChange('address', location)}
        />
      )}
    </>
  )
}

export default observer(StoreBaseBlock)
