import React from 'react'
import { DtItemBlock, DtIcon } from '@dt/ui-mobile'
import { clock } from '@dt/ui-ionic-icon'
import { useHistory } from 'react-router-dom'
import i18n from '@dt/fe-base/dist/i18n'
import { storeMobx } from '@mobx'
import { observer } from 'mobx-react'
import './StoreBusinessTime.scss'
interface IStoreBusinessTimeProps {
  hasPermission: boolean
}

function StoreBusinessTime(props: IStoreBusinessTimeProps) {
  const { hasPermission } = props
  const history = useHistory()

  return (
    <DtItemBlock.Block>
      <DtItemBlock.Header
        desc={
          <span style={{ lineHeight: '130%' }}>
            {i18n.t('store.businessTimeDesc')}
          </span>
        }
      >
        {i18n.t('store.storeTime')}
      </DtItemBlock.Header>
      <div
        className='store-business-time-content'
        onClick={() => {
          if (!hasPermission) return

          history.push('/mainline/businessHoursEdit')
        }}
      >
        {storeMobx.currentStoreInfo?.storeBusiness?.[0]?.configMethod ===
        'day' ? (
          <div className='store-business-time-content-warper'>
            <div className='store-business-time-content-title'>
              <div className='text'>{i18n.t('store.everyday')}</div>
            </div>
            <div className='item-time-list'>
              {storeMobx.timeGroupList[0].time.map((item, index) => (
                <div
                  className='desc'
                  key={index}
                  style={{
                    color: item.isCurrent
                      ? 'var(--dt-price)'
                      : 'var(--dt-text-middle)',
                  }}
                >
                  {item?.startTime} ~ {item?.endTime}
                </div>
              ))}
            </div>
          </div>
        ) : (
          storeMobx.currentStoreInfo?.storeBusiness?.[0]?.configMethod ===
            'week' &&
          storeMobx.timeGroupList.map((key, index) => (
            <div className='store-business-time-content-warper' key={index}>
              <div className='store-business-time-content-title'>
                <div className='text' style={{ marginBottom: '8px' }}>
                  {key.nameList.map((k) => (
                    <span key={k}>{i18n.t(`store.${k}`)}</span>
                  ))}
                </div>
              </div>
              {key?.time!.length > 0 ? (
                <div className='item-time-list'>
                  {key.time?.map((item: any, index: number) => (
                    <div
                      className='desc'
                      key={index}
                      style={{
                        color: item.isCurrent
                          ? 'var(--dt-price)'
                          : 'var(--dt-text-middle)',
                      }}
                    >
                      {item.startTime} ~ {item.endTime}
                    </div>
                  ))}
                </div>
              ) : (
                <div className='close-text'>{i18n.t('store.notOpen')}</div>
              )}
            </div>
          ))
        )}
      </div>
    </DtItemBlock.Block>
  )
}

export default observer(StoreBusinessTime)
