import React, { useState, useEffect } from 'react'
import { DtItemInput } from '@dt/ui-mobile'
import i18n from '@dt/fe-base/dist/i18n'
import './StoreInput.scss'

const StoreInput = ({
  storeId,
  disabled,
  label,
  value,
  showSuffix = false,
  changeImmediate = false,
  onChange,
}: {
  label: string
  value: string
  changeImmediate?: boolean
  disabled: boolean
  storeId?: number
  showSuffix?: boolean
  onChange?: (value: string) => Promise<boolean>
}) => {
  const [showStoreId, setShowStoreId] = useState(showSuffix)

  const [storeName, setStoreName] = useState(value)

  useEffect(() => {
    setStoreName(value)
  }, [value])

  const handleChange = async (e: any) => {
    setStoreName(e.detail.value as string)
    if (!changeImmediate) {
      const res = await onChange?.(e.detail.value as string)

      if (!res) {
        setTimeout(() => {
          setStoreName(value)
        }, 0)
      }
    }
  }

  const handleInput = (e: any) => {
    if (changeImmediate) {
      setStoreName(e.detail.value as string)
      onChange?.(e.detail.value as string)
    }
  }

  return (
    <DtItemInput
      useType='newRow'
      dtInputMode='implicit'
      required
      placeholder={i18n.t('common.inputPlaceholder')}
      customLabel={label}
      value={storeName}
      disabled={disabled}
      onIonFocus={() => setShowStoreId(false)}
      onIonBlur={() => {
        showSuffix && setShowStoreId(true)
      }}
      onIonInput={handleInput}
      onIonChange={handleChange}
      suffix={
        <span
          className='hq-store-input-suffix'
          style={{ display: showStoreId ? 'block' : 'none' }}
        >
          ID：{storeId}
        </span>
      }
    ></DtItemInput>
  )
}

export default StoreInput
