import React, { useState } from 'react'
import { DtItemBlock, Modal, DtIcon } from '@dt/ui-mobile'
import { banCircle, chevronDown, trailing, checkmark } from '@dt/ui-ionic-icon'
import { classNames, localStore as store } from '@dt/fe-base'
import { newMutate } from '@dt/fe-business/client'
import i18n from '@dt/fe-base/dist/i18n'
import { observer } from 'mobx-react'
import { storeMobx } from '@mobx'
import { UpdateStore } from '@/gqlDocumentsNew/store'

import './StoreStatus.scss'
interface IStoreStatusProps {
  hasPermission: boolean
}

function StoreStatus(props: IStoreStatusProps) {
  const { hasPermission } = props

  const [statusModalShow, setStatusModalShow] = useState(false)
  const [confirmModalShow, setConfirmModalShow] = useState(false)
  const status = storeMobx.currentStoreInfo.store?.status

  const isOpen = status === 'enable'

  const handleOpenStore = () => {
    if (!hasPermission) return

    setStatusModalShow(true)
  }

  const toggleStoreStatus = async (willStatus: string) => {
    if (!hasPermission || willStatus === status) return
    if (willStatus === 'closed') {
      setConfirmModalShow(true)
    } else {
      const { errors } = await newMutate(UpdateStore, { status: 'enable' })
      if (!errors) {
        storeMobx.setCurrentStore(store.get('ls.storeInfo')?.storeId)
        setStatusModalShow(false)
      }
    }
  }

  const confirmCloseStore = async () => {
    const { errors } = await newMutate(UpdateStore, { status: 'closed' })

    if (!errors) {
      storeMobx.currentStoreInfo.store?.storeId &&
        storeMobx.setCurrentStore(storeMobx.currentStoreInfo.store?.storeId)
      setConfirmModalShow(false)
      setStatusModalShow(false)
    }
  }

  return (
    <DtItemBlock.Block>
      <DtItemBlock.Header
        extra={
          <div
            className={classNames('store-status-header-extra', {
              close: !isOpen,
            })}
            onClick={handleOpenStore}
          >
            {isOpen ? (
              <>
                <DtIcon icon={trailing} />
                <span>{i18n.t('store.openStore')}</span>
              </>
            ) : (
              <>
                <DtIcon icon={banCircle} />
                <span>{i18n.t('store.isClose')}</span>
              </>
            )}
            <DtIcon
              style={{ color: 'var(--dt-text-middle)' }}
              icon={chevronDown}
            />
          </div>
        }
      >
        {i18n.t('store.storeStatus')}
      </DtItemBlock.Header>
      <Modal.PageModal
        isOpen={statusModalShow}
        onClose={() => setStatusModalShow(false)}
        title={i18n.t('store.storeStatus2')}
      >
        <div className='store-status-modal'>
          <div
            onClick={() => toggleStoreStatus('closed')}
            className={classNames('store-status-modal-item', {
              active: status === 'closed',
            })}
          >
            <DtIcon icon={banCircle} />
            <span>{i18n.t('store.close')}</span>
            {status === 'closed' && (
              <DtIcon
                className='store-status-modal-item-icon'
                icon={checkmark}
              />
            )}
          </div>
          <div
            onClick={() => toggleStoreStatus('enable')}
            className={classNames('store-status-modal-item', {
              active: status === 'enable',
            })}
          >
            <DtIcon icon={trailing} />
            <span>{i18n.t('store.normalBusiness')}</span>
            {status === 'enable' && (
              <DtIcon
                className='store-status-modal-item-icon'
                icon={checkmark}
              />
            )}
          </div>
        </div>
      </Modal.PageModal>
      <Modal.ConfirmModal
        autoHeight
        className='store-status-confirm-modal'
        isOpen={confirmModalShow}
        onClose={() => setConfirmModalShow(false)}
        title={i18n.t('store.willClose')}
        showFooter
        headerOptions={{
          leftIconClick: () => setConfirmModalShow(false),
        }}
        onCancel={() => setConfirmModalShow(false)}
        onConfirm={confirmCloseStore}
        footerOptions={{
          showCancel: true,
          showConfirm: true,
        }}
      >
        <div className='store-status-confirm-modal-content'>
          {i18n.t('store.closePl')}
        </div>
      </Modal.ConfirmModal>
    </DtItemBlock.Block>
  )
}

export default observer(StoreStatus)
