import { Fragment, useEffect, useRef, useState } from 'react'
import { useHistory, useLocation } from 'react-router-dom'
import { ConfirmModal } from '@cps'
import { useIonViewDidEnter } from '@ionic/react'
import { DtContent, Button, DtItemBlock } from '@dt/ui-mobile'

import i18n from '@dt/fe-base/dist/i18n'
import { localStore as store } from '@dt/fe-base'

import { appMobx, brandMobx, deviceMobx, storeMobx } from '@mobx'
import { observer } from 'mobx-react'
import { newMutate } from '@dt/fe-business/client'
import {
  DtBusinessFab,
  DtBusinessNavHeader,
  DtBottomSeat,
} from '@dt/ui-mobile-business'
import { DeleteStore, UpdateStore } from '@/gqlDocumentsNew/store'
import StoreBaseBlock from './components/StoreBaseBlock'
import StoreStatus from './components/StoreStatus'
import './index.scss'
import { PermissionSdk } from '@dt/fe-business'
import StoreBusinessTime from './components/StoreBusinessTime'
const StoreDetail = () => {
  const _ns = 'page-store-detail-wrapper'
  const history = useHistory()

  const [delVisible, setDelVisible] = useState<boolean>(false)
  const [permission, setPermission] = useState({
    'hq.brandInfo': false,
    '/storeDetail': false,
  })
  const [confirmType, setConfirmType] = useState<'close' | 'delete'>('close')
  const location = useLocation()

  const init = useRef(false)

  useIonViewDidEnter(() => {
    init.current = true
    storeMobx.setCurrentStore(store.get('ls.storeInfo')?.storeId)
    storeMobx.getStoreList(false)
    PermissionSdk.check(['/storeDetail', 'hq.brandInfo']).then((res) => {
      setPermission(res)
    })
  }, [])

  useEffect(() => {
    appMobx.setPrePath(location.pathname)
    storeMobx.setCurrentStore(store.get('ls.storeInfo')?.storeId)
    storeMobx.getStoreList(false)
  }, [])

  useEffect(() => {
    if (init.current) {
      PermissionSdk.check(['/storeDetail', 'hq.brandInfo']).then((res) => {
        setPermission(res)
      })
    }
  }, [brandMobx.brandInfo])

  const delStore = () => {
    newMutate(DeleteStore, {
      storeId: storeMobx.currentStoreInfo.store?.storeId,
    }).then(({ errors }) => {
      if (!errors) {
        store.remove('ls.storeInfo')
        window.storeInfo = {}
        storeMobx.getStoreList(true)
        setDelVisible(false)
      }
    })
  }

  const closeStore = () => {
    newMutate(UpdateStore, { status: 'closed' }).then((res) => {
      if (!res.errors) {
        setDelVisible(false)
        storeMobx.currentStoreInfo.store?.storeId &&
          storeMobx.setCurrentStore(storeMobx.currentStoreInfo.store?.storeId)
      }
    })
  }

  return (
    <Fragment>
      <DtBusinessNavHeader
        title={i18n.t('store.title')}
        leftType='menu'
        selectOptions={{ showType: 'store' }}
        showExtra={!deviceMobx.deviceInfo?.deviceId}
      />
      <DtContent>
        <div className={`${_ns}-content`}>
          {storeMobx.storeList.length === 0 ? (
            <div className='no-store'>
              <div className='title'>{i18n.t('brand.noFind')}</div>
              <div className='desc'>
                {i18n.t('brand.noFindPl', {
                  name: brandMobx.brandInfo.brandName,
                })}
              </div>
              <div className='desc'>{i18n.t('brand.plCreateStore')}</div>
              {permission['/storeDetail'] && (
                <Button
                  style={{ width: 160 }}
                  usetype='primary'
                  size='large'
                  onClick={() => {
                    storeMobx.setEditStoreInfo(undefined)
                    storeMobx.setCurrentStore(undefined)
                    history.push('/store')
                  }}
                >
                  {i18n.t('store.newStore')}
                </Button>
              )}
            </div>
          ) : (
            <div>
              <StoreBaseBlock hasPermission={permission['/storeDetail']} />
              <DtItemBlock
                size='middle'
                header={{
                  title: (
                    <span className='title'>
                      {i18n.t('store.storeSetting')}
                    </span>
                  ),
                }}
                border
              >
                <StoreStatus hasPermission={permission['/storeDetail']} />
                {storeMobx.currentStoreInfo.store?.status === 'enable' && (
                  <StoreBusinessTime
                    hasPermission={permission['/storeDetail']}
                  />
                )}
              </DtItemBlock>
              {storeMobx.currentStoreInfo.store?.status === 'closed' &&
                !deviceMobx.deviceId && (
                  <Button
                    expand='full'
                    colorOptions={{
                      textColor: '#DF0C00',
                    }}
                    usetype='text'
                    onClick={() => {
                      if (!permission['/storeDetail']) return
                      setConfirmType('delete')
                      setDelVisible(true)
                    }}
                  >
                    {i18n.t('store.delStore')}
                  </Button>
                )}
              <DtBottomSeat />
            </div>
          )}
        </div>
        {permission['/storeDetail'] && !deviceMobx.deviceId && (
          <DtBusinessFab
            addText={i18n.t('store.store')}
            onAdd={() => {
              storeMobx.setEditStoreInfo(undefined)
              history.push('/store')
            }}
          />
        )}
      </DtContent>
      <ConfirmModal
        isOpen={delVisible}
        onOk={() => {
          if (confirmType === 'close') {
            closeStore()
          }
          if (confirmType === 'delete') {
            delStore()
          }
        }}
        onClose={() => {
          setDelVisible(false)
        }}
        title={
          confirmType === 'delete'
            ? i18n.t('store.delStore')
            : i18n.t('store.willClose')
        }
        message={
          confirmType === 'delete'
            ? i18n.t('store.delWarning')
            : i18n.t('store.closePl')
        }
      />
    </Fragment>
  )
}

export default observer(StoreDetail)
