import { useHistory } from 'react-router-dom'
import {
  DtContent,
  DtFooter,
  DtModal,
  DtRadio,
  DtRadioGroup,
  DtNavHeader,
} from '@dt/ui-mobile'
import { Icon } from '@cps'
import i18n from '@dt/fe-base/dist/i18n'
import { observer } from 'mobx-react'
import { localStore as store } from '@dt/fe-base'
import { BrandBrand } from '@/gql/graphql'
import { brandMobx } from '@mobx'
import './index.scss'

interface IBrandModalProps {
  isOpen: boolean
  onClose: () => void
  onOk: () => void
}

const BrandModal = (props: IBrandModalProps) => {
  const _ns = 'brand-choose-modal'
  const history = useHistory()
  const { isOpen, onClose, onOk } = props

  return (
    <DtModal
      isOpen={isOpen}
      className={_ns}
      onWillDismiss={() => {
        onClose()
      }}
    >
      <DtNavHeader
        title={i18n.t('brand.changeBrand')}
        leftIconClick={() => {
          onClose()
        }}
        leftType='modal'
      />
      <div className='brand-list-content'>
        <DtContent>
          <DtRadioGroup
            value={store.get('ls.brandInfo')?.brandId}
            onIonChange={async (e) => {
              if (e.target.value) {
                const resp = await brandMobx.switchBrand({
                  newBrandId: e.target.value,
                })
                if (!resp) return
                brandMobx.setBrandInfo(
                  brandMobx.brandList.find(
                    (item) => item.brandId === e.target.value,
                  ) || ({} as BrandBrand),
                )
                onOk()
              }
            }}
          >
            {brandMobx.brandList.map((item) => (
              <div className='brand-list-item' key={item.brandId}>
                <DtRadio
                  labelPlacement='end'
                  id={`${item.brandId}`}
                  value={item.brandId}
                  style={{ width: '100%' }}
                  mode='md'
                >
                  <div className='text-content'>
                    <div className='left'>{item.brandName}</div>
                    <div className='right'>
                      {i18n.t('brand.storeNum', { num: item.storeCnt })}
                    </div>
                  </div>
                </DtRadio>
              </div>
            ))}
          </DtRadioGroup>
        </DtContent>
      </div>
      <DtFooter>
        <div
          className='footer'
          onClick={() => {
            history.push('/brand')
            onClose()
          }}
        >
          <Icon name='add' size={14} />
          <div style={{ flex: 1 }}>{i18n.t('brand.addBrand')}</div>
          <Icon name='chevron-right' />
        </div>
      </DtFooter>
    </DtModal>
  )
}

export default observer(BrandModal)
