import { Modal, DtRadio, DtRadioGroup } from '@dt/ui-mobile'
import i18n from '@dt/fe-base/dist/i18n'
import { observer } from 'mobx-react'
import { storeMobx, brandMobx } from '@mobx'
import './index.scss'

interface IChooseModal {
  visible: boolean
  onClose: () => void
  onOk: (key: string) => void
}

function ChooseModal(props: IChooseModal) {
  const _ns = 'choose-store-modal'
  const { visible, onClose, onOk } = props

  return (
    <Modal.PageModal
      title={i18n.t('store.chooseStore')}
      className={_ns}
      autoHeight
      isOpen={visible}
      onClose={onClose}
    >
      <div className='modal-content'>
        <div className='desc'>{i18n.t('store.choosePl')}</div>
        <DtRadioGroup
          onIonChange={(e) => {
            onOk(e.target.value)
          }}
        >
          {storeMobx.storeList.length > 1 ? (
            <div className='item'>
              <DtRadio labelPlacement='end' value='changeStore'>
                {i18n.t('store.changeStore')}
              </DtRadio>
            </div>
          ) : (
            <div className='item'>
              <DtRadio labelPlacement='end' value='addStore'>
                {i18n.t('store.newStore')}
              </DtRadio>
            </div>
          )}

          {brandMobx.brandList.length > 1 ? (
            <div className='item'>
              <DtRadio labelPlacement='end' value='changeBrand'>
                {i18n.t('brand.changeBrand')}
              </DtRadio>
            </div>
          ) : (
            <div className='item'>
              <DtRadio labelPlacement='end' value='addBrand'>
                {i18n.t('brand.addBrand')}
              </DtRadio>
            </div>
          )}
        </DtRadioGroup>
      </div>
    </Modal.PageModal>
  )
}

export default observer(ChooseModal)
