import { FC, useEffect } from 'react'
import { useHistory } from 'react-router-dom'
import {
  DtContent,
  DtFooter,
  DtModal,
  DtRadioGroup,
  DtRadio,
  DtNavHeader,
} from '@dt/ui-mobile'
import { Icon } from '@cps'
import i18n from '@dt/fe-base/dist/i18n'
import { classNames, localStore as store } from '@dt/fe-base'
import { storeMobx } from '@mobx'
import './index.scss'

interface IStoreModalProps {
  isOpen: boolean
  onClose: () => void
  onOk: () => void
}

const StoreModal: FC<IStoreModalProps> = (props) => {
  const _ns = 'store-choose-modal'
  const history = useHistory()
  const { isOpen, onClose, onOk } = props

  useEffect(() => {
    if (isOpen) {
      storeMobx.getStoreList(false)
    }
  }, [isOpen])
  return (
    <DtModal
      isOpen={isOpen}
      className={_ns}
      onWillDismiss={() => {
        onClose()
      }}
    >
      <DtNavHeader
        title={i18n.t('store.changeStore')}
        leftIconClick={() => {
          onClose()
        }}
        leftType='modal'
      />
      <div className='store-list-content'>
        <DtContent>
          <DtRadioGroup
            value={store.get('ls.storeInfo')?.storeId}
            onIonChange={(e) => {
              storeMobx.setCurrentStore(
                storeMobx.storeList.find(
                  (item) => item.storeId === e.detail.value,
                )?.storeId || 0,
              )
              onOk()
            }}
          >
            {storeMobx.storeList.map((item) => (
              <div className='store-list-item' key={item.storeId}>
                <DtRadio
                  labelPlacement='end'
                  id={String(item.storeId)}
                  value={item.storeId}
                  style={{ width: '100%' }}
                  mode='md'
                >
                  <div className='text-content'>
                    <div className='left'>{item.storeName}</div>
                    <div
                      className={classNames('right', {
                        close: item.status !== 'enable',
                      })}
                    >
                      {item.status === 'enable'
                        ? i18n.t('store.normalBusiness')
                        : i18n.t('store.isClose')}
                    </div>
                  </div>
                </DtRadio>
              </div>
            ))}
          </DtRadioGroup>
        </DtContent>
      </div>
      <DtFooter>
        <div
          className='footer'
          onClick={() => {
            storeMobx.setEditStoreInfo(undefined)
            history.push('/store')
            onClose()
          }}
        >
          <Icon name='add' size={14} />
          <div style={{ flex: 1 }}>{i18n.t('store.newStore')}</div>
          <Icon name='chevron-right' />
        </div>
      </DtFooter>
    </DtModal>
  )
}

export default StoreModal
