import { FC, Fragment, useEffect, useState, useRef } from 'react'
import { useHistory } from 'react-router-dom'
import {
  DtContent,
  useDtToast,
  Input,
  DtItemCard,
  DtNavHeader,
} from '@dt/ui-mobile'
import { PermissionSdk } from '@dt/fe-business'
import i18n from '@dt/fe-base/dist/i18n'
import { brandMobx, storeMobx } from '@mobx'
import { observer } from 'mobx-react'
import { localStore as store } from '@dt/fe-base'
import { newMutate } from '@dt/fe-business/client'
import { CreateBrand, UpdateBrand } from '@/gqlDocumentsNew/brand'
import './index.scss'
import { BrandBrand } from '@/gql/graphql'
import { DtImageChooseModal, DtBusinessAvatar } from '@dt/ui-mobile-business'

const UserBrand: FC<any> = () => {
  const _ns = 'page-brand-wrapper'
  const history = useHistory()
  const [name, setName] = useState<string | null | undefined>()
  const [logo, setLogo] = useState<any>()
  const [imageVisible, setImageVisible] = useState<boolean>(false)
  const [present] = useDtToast()
  const isEdit = brandMobx.brandEdit

  const pending = useRef(false)

  const presentToast = (msg: string) => {
    present({
      color: 'danger',
      message: msg,
      duration: 1000,
      position: 'bottom',
    })
  }

  const confirm = async () => {
    if (pending.current) return
    if (!name) {
      presentToast(i18n.t('common.completeWarning'))
    } else {
      const brandId = store.get('ls.brandInfo')?.brandId
      const brand = {
        brandName: name,
        logo,
        brandId,
      }
      if (isEdit) {
        pending.current = true
        const { errors } = await newMutate(UpdateBrand, { ...brand })
        pending.current && (pending.current = false)
        if (!errors) {
          brandMobx.getBrandList(false, {
            brandId,
            notRefresh: true,
          })
          storeMobx.setEditStoreInfo(undefined)
          history.goBack()
          brandMobx.setBrandEdit(false)
        }
      } else {
        pending.current = true
        const { errors, data }: any = await newMutate(
          CreateBrand,
          {
            brandName: name,
            logo,
          },
          {
            headers: {
              'auth-version': PermissionSdk.AUTH_VERSION,
            },
          },
        )
        pending.current && (pending.current = false)
        if (!errors) {
          const brandId = data?.CreateBrand.brandId as number
          brandMobx.switchBrand({ newBrandId: brandId, notRefresh: true })
          brandMobx.setBrandInfo(data?.CreateBrand as BrandBrand, true)
          storeMobx.clear()
          setName('')
          setLogo(undefined)
          history.replace('/store')
        }
      }
    }
  }

  const imageConfirm = (data: any) => {
    setLogo(data[0].url)
    setImageVisible(false)
  }

  // useDtViewWillLeave(() => {
  //   appMobx.setPrePath(location.pathname)
  //   brandMobx.setBrandEdit(false)
  // })

  useEffect(() => {
    if (isEdit) {
      setLogo(store.get('ls.brandInfo').logo)
      setName(store.get('ls.brandInfo').brandName)
    }
  }, [isEdit])
  return (
    <Fragment>
      <DtNavHeader
        leftIconClick={() => {
          history.goBack()
          brandMobx.setBrandEdit(false)
        }}
        onConfirmClick={confirm}
        showConfirm
        leftType='back'
        hideBtn={!brandMobx.currentBrandId}
        title={isEdit ? i18n.t('brand.brandInfo') : i18n.t('brand.addBrand')}
      />

      <DtContent className={`${_ns}-content`}>
        <div className='brand-desc'>{i18n.t('brand.desc')}</div>
        <Input
          maxlength={48}
          placeholder={i18n.t('brand.brandPlaceholder')}
          size='large'
          useType='newRow'
          required
          value={name}
          customLabel={i18n.t('brand.name')}
          onIonInput={(e) => setName(e.detail.value)}
        />
        <DtItemCard style={{ marginTop: 16 }}>
          <DtItemCard.Header
            title={i18n.t('brand.clickUpload')}
            extra={
              <div
                className={`${_ns}-logo`}
                onClick={() => setImageVisible(true)}
              >
                <DtBusinessAvatar type='upload' url={logo} />
              </div>
            }
          ></DtItemCard.Header>
        </DtItemCard>
        {isEdit && (
          <Input
            className='brand-id-input'
            disabled
            size='large'
            useType='newRow'
            value={store.get('ls.brandInfo').brandId}
            customLabel={i18n.t('brand.idTitle')}
          />
        )}
      </DtContent>
      <DtImageChooseModal
        maxFileSizeMB={5}
        maxFiles={1}
        isOpen={imageVisible}
        onClose={() => setImageVisible(false)}
        onOk={imageConfirm}
        desc={
          <div>
            <div>{i18n.t('brand.picDesc')}</div>
            <div>{i18n.t('brand.picDesc2')}</div>
          </div>
        }
      />
    </Fragment>
  )
}

export default observer(UserBrand)
