import { FC, Fragment, useRef, useState } from 'react'
import { useHistory } from 'react-router-dom'
import { observer } from 'mobx-react'
import {
  DtContent,
  useDtToast,
  DtNavHeader,
  DtItemBlock,
  DtIcon,
  DtItemInput,
  DtCustomToast,
} from '@dt/ui-mobile'
import { location as locationIcon } from '@dt/ui-ionic-icon'
import LocationModal from '@components/modals/LocationModal'
import i18n from '@dt/fe-base/dist/i18n'
import { appMobx, brandMobx, storeMobx, userPermissionMobx } from '@mobx'

import { newMutate } from '@dt/fe-business/client'
import { CreateStore } from '@/gqlDocumentsNew/store'
import { localStore as store, classNames } from '@dt/fe-base'
import './index.scss'
import { PermissionSdk } from '@dt/fe-business'
import StoreInput from '../storeDetail/components/StoreInput'
import successIcon from '@/assets/img/createStoreSuccess.svg'
const UserStore: FC<any> = () => {
  const _ns = 'page-store-wrapper'
  const history = useHistory()
  const isEdit = !!storeMobx.editStoreInfo
  const [name, setName] = useState<string | null | undefined>()
  const [location, setLocation] = useState<any>()
  const [isShowLocationModal, setIsShowLocationModal] = useState<boolean>(false)
  const [locationDetail, setLocationDetail] = useState<
    string | null | undefined
  >()
  const [present] = useDtToast()
  const [isShowToast, setIsShowToast] = useState<boolean>(false)
  const pending = useRef(false)

  const presentToast = (msg: string) => {
    present({
      message: msg,
      duration: 1000,
      position: 'bottom',
    })
  }

  const confirm = () => {
    if (pending.current) return
    if (!name || !location) {
      presentToast(i18n.t('common.completeWarning'))
    } else {
      const params = {
        storeName: name,
        county: location.province,
        city: location.city,
        address: location.address + location.title,
        addressDetail: locationDetail || '',
        lbsLng: String(location.point.lng),
        lbsLat: String(location.point.lat),
      }
      pending.current = true

      newMutate(CreateStore, params)
        .then(async (res: any) => {
          if (!res?.errors) {
            setIsShowToast(true)
            window.Config.storeId = res?.data?.CreateStore.storeId
            await brandMobx.getBrandList(false, { notRefresh: true })
            await storeMobx.getStoreList(
              false,
              res?.data?.CreateStore?.storeId as number,
            )
            await PermissionSdk.permissionInfoUpdate({
              token: store.get('ls.authorization')?.accessToken || '',
              brandId: store.get('ls.brandInfo')?.brandId || 0,
            })
            if (PermissionSdk.hasLoginPerm()) {
              history.replace('/task')
            } else {
              userPermissionMobx.updateNotLoginPermissionModal(true)
            }
            setTimeout(() => {
              brandMobx.reload()
            }, 200)
          }
        })
        .finally(() => {
          pending.current && (pending.current = false)
        })
    }
  }

  const renderLocation = () => {
    const locationStr = `${location?.address || ''}${location?.title || ''}`
    return (
      <div
        className='store-item-content-address-right'
        onClick={() => setIsShowLocationModal(true)}
      >
        <span
          className={classNames({
            'location-text-empty': !locationStr,
          })}
        >
          {locationStr || i18n.t('store.locationPlaceholder')}
        </span>
        <DtIcon icon={locationIcon} />
      </div>
    )
  }
  return (
    <Fragment>
      <DtNavHeader
        leftType='back'
        showConfirm
        onConfirmClick={confirm}
        hideBtn={!(appMobx.prePath === '/storeDetail')}
        title={isEdit ? i18n.t('store.editStore') : i18n.t('store.addStore')}
      />
      <DtContent className={`${_ns}-content`}>
        <DtItemBlock style={{ paddingBottom: 0 }} size='middle' border>
          <StoreInput
            label={i18n.t('store.storeName')}
            value={name || ''}
            changeImmediate={true}
            disabled={false}
            showSuffix={false}
            onChange={(value: string) => {
              setName(value)
              return Promise.resolve(true)
            }}
          />
          <DtItemBlock.Header
            className='store-item-content-address'
            required
            extra={renderLocation()}
          >
            {i18n.t('store.storeLocation')}
          </DtItemBlock.Header>

          {/* 详细地址 */}
          <DtItemInput
            useType='newRow'
            dtInputMode='implicit'
            customLabel={i18n.t('store.detailAddress')}
            value={locationDetail}
            disabled={false}
            placeholder={i18n.t('common.inputPlaceholder')}
            onIonChange={(e) => {
              setLocationDetail(e.detail.value)
            }}
          />
        </DtItemBlock>
        {isShowLocationModal && (
          <LocationModal
            isEdit={false}
            isOpen={isShowLocationModal}
            initialLocation={location}
            onClose={() => setIsShowLocationModal(false)}
            onChange={(location: any) => {
              setLocation(location)
              setIsShowLocationModal(false)
            }}
          />
        )}
        <DtCustomToast
          isOpen={isShowToast}
          showMask
          imageSrc={successIcon}
          onMaskClick={() => {
            setIsShowToast(false)
          }}
          duration={1000}
          title={i18n.t('store.createStoreSuccess')}
          onClose={() => {
            setIsShowToast(false)
          }}
        />
      </DtContent>
    </Fragment>
  )
}

export default observer(UserStore)
