import { FC } from 'react'
import {
  DtButton,
  DtContent,
  DtFooter,
  DtModal,
  DtNavHeader,
} from '@dt/ui-mobile'
import i18n from '@dt/fe-base/dist/i18n'
import { useHistory } from 'react-router-dom'
import './index.scss'

interface ISuccessModalProps {
  isOpen: boolean
  onClose: () => void
  onOk: () => void
}

const SuccessModal: FC<ISuccessModalProps> = (props) => {
  const _ns = 'store-success-modal'
  const { isOpen, onClose, onOk } = props
  const history = useHistory()

  return (
    <DtModal
      className={_ns}
      isOpen={isOpen}
      onIonModalWillDismiss={() => {
        onClose()
      }}
    >
      <DtNavHeader
        leftType='modal'
        leftIconClick={() => {
          onClose()
          history.push('/storeDetail')
        }}
      />
      <DtContent>
        <div className='img-box'></div>
        <div className='success-text '>{i18n.t('store.successText')}</div>
        <div className='desc-text'>
          <div>{i18n.t('store.desc1')}</div>
          <div>{i18n.t('store.desc2')}</div>
        </div>
      </DtContent>
      <DtFooter>
        <div className={`${_ns}-footer`}>
          <DtButton
            className='btn'
            style={{ width: '100%' }}
            onClick={() => {
              history.push('/mainline/home')
              onOk()
            }}
          >
            {i18n.t('store.configureOrder')}
          </DtButton>
        </div>
      </DtFooter>
    </DtModal>
  )
}

export default SuccessModal
