import { DtContent, DtNavHeader } from '@dt/ui-mobile'
import envConfi from '@/common/env'
import { localStore as store } from '@dt/fe-base'
import { useLayoutEffect, useState } from 'react'
import sha1 from 'js-sha1'
import { appMobx } from '@mobx'
import i18n from '@dt/fe-base/dist/i18n'
import { Browser } from '@capacitor/browser'

const uuid = () => {
  const tempUrl = URL.createObjectURL(new Blob())
  const uuid = tempUrl.toString()
  URL.revokeObjectURL(tempUrl)
  return uuid.substr(uuid.lastIndexOf('/') + 1)
}

export default function Chat() {
  const isPro = envConfi.env === 'pro'
  const UDESK_CODE = isPro ? '2a0c2073' : '2696kgfe'
  const UDESK_LINK = isPro
    ? 'https://eshine.udesk.cn/im_client/?web_plugin_id=47086'
    : 'https://1320588.s4.udesk.cn/im_client/?web_plugin_id=62910'
  const [url, setUrl] = useState('')
  const webviewUrlOpen = async () => {
    if (window.bo === 'cn') {
      const nonce = uuid()
      const timestamp = new Date().getTime()
      const brandInfo = store.get('ls.brandInfo') || {}
      const userInfo = store.get('ls.userInfo') || {}
      const webToken = brandInfo?.brandId + (userInfo?.userId || '')
      const signature = isPro
        ? `nonce=${nonce}&timestamp=${timestamp}&web_token=${webToken}&6b5d72af9a63a462dba9f8ccadd38e0c`
        : `nonce=${nonce}&timestamp=${timestamp}&web_token=${webToken}&3a9dae8ba19ac9c138378ee5032c5416`
      let signStr = sha1(signature)
      signStr = signStr.toUpperCase()
      const cTags = brandInfo?.brandId ? `品牌ID: [${brandInfo?.brandId}]` : ''

      const searchParamsMap: Record<string, string | number> = {
        code: UDESK_CODE,
        cur_title: document.title,
        cur_url: location.origin,
        pre_url: location.origin + '/#' + appMobx.prePath,
        free: 'noAgent',
        c_tags: cTags,
        nonce,
        timestamp,
        web_token: webToken,
        signature: signStr,
      }

      const lastUrl = await Object.keys(searchParamsMap).reduce((prev, key) => {
        return prev + '&' + key + `=${encodeURIComponent(searchParamsMap[key])}`
      }, '')

      const frameUrl = `${UDESK_LINK}&${lastUrl}`
      setUrl(frameUrl)
      await Browser.open({ url: frameUrl })
    }
  }
  useLayoutEffect(() => {
    webviewUrlOpen()
  }, [])

  return (
    <>
      <DtNavHeader>{i18n.t('menu.customerService')}</DtNavHeader>
      <DtContent>
        {url && <iframe style={{ height: '100%', width: '100%' }} src={url} />}
      </DtContent>
    </>
  )
}
