import { DtContent, DtNavHeader, DtIcon } from '@dt/ui-mobile'
import { PageWrapper } from '@cps'
import EditCardList from './components/CardList/EditCardList'
import i18n from '@dt/fe-base/dist/i18n'
import { DtBusinessFab } from '@dt/ui-mobile-business'
import AddCardModal from './modals/AddCardModal'
import cardMobx from '@mobx/card.mobx'
import { useState } from 'react'
import { useHistory } from 'react-router'
import { observer } from 'mobx-react'
import { saveCards } from './components/CardList/hooks'
import { plus } from '@dt/ui-ionic-icon'
import translate from '@utils/translate'
import './Edit.scss'

const HomeEdit = () => {
  const history = useHistory()
  const trans = translate('moduleCard')
  const [visible, setVisble] = useState(false)
  const [showDelete, setShowDelete] = useState(true)
  const onFinish = async () => {
    await saveCards()
    setShowDelete(false)
    history.goBack()
  }
  const { unaddedCardList, cardList } = cardMobx.group
  return (
    <PageWrapper>
      <DtNavHeader
        title={i18n.t('home.edit')}
        // hideBtn
        extra={
          <span className='finish-btn' onClick={onFinish}>
            {i18n.t('common.finish')}
          </span>
        }
      />
      <DtContent>
        <div className='edit-home-content-wrapper'>
          {unaddedCardList.length ? (
            <>
              {cardList.length === 0 && (
                <div className='empty-card' onClick={() => setVisble(true)}>
                  <DtIcon icon={plus}></DtIcon>
                  {trans('addCard')}
                </div>
              )}
              <AddCardModal isOpen={visible} onClose={() => setVisble(false)} />
            </>
          ) : null}
          <EditCardList
            isImg
            showDelete={showDelete}
            setShowDelete={setShowDelete}
          />
        </div>
      </DtContent>
      {cardMobx.group.unaddedCardList.length ? (
        <>
          <DtBusinessFab
            onAdd={() => setVisble(true)}
            addText={i18n.t('common.add')}
          />
          <AddCardModal isOpen={visible} onClose={() => setVisble(false)} />
        </>
      ) : null}
    </PageWrapper>
  )
}

export default observer(HomeEdit)
