import { CSSProperties, HTMLAttributes, ReactNode, useRef } from 'react'
import { minus, checkmark } from '@dt/ui-ionic-icon'
import { DtIcon } from '@dt/ui-mobile'
import { classNames } from '@dt/fe-base'
import './index.scss'
export interface IBaseCardProps extends HTMLAttributes<HTMLDivElement> {
  title?: string
  children: ReactNode
  className?: string
  style?: CSSProperties
  showDelete?: boolean
  onDelete?: () => void
  selected?: boolean
  onClick?: () => void
  onLongPress?: () => void
  disabledClick?: boolean
  showMask?: boolean
}

function BaseCard(props: IBaseCardProps) {
  const {
    children,
    title,
    style,
    className,
    showDelete,
    selected,
    onDelete,
    onClick,
    onLongPress,
    disabledClick,
    showMask,
  } = props
  const timerRef = useRef<NodeJS.Timeout>()
  const ref = useRef<HTMLDivElement>(null)

  const timestampRef = useRef(0)

  const handleTouchStart = () => {
    if (onLongPress) {
      timestampRef.current = Date.now()
      timerRef.current = setTimeout(() => {
        timerRef.current = undefined
        const timestamp = Date.now()
        if (timestamp - timestampRef.current < 1100) {
          onLongPress()
        }
      }, 1000)
    }
  }
  const clearTimer = () => {
    if (timerRef.current) {
      clearTimeout(timerRef.current)
      timerRef.current = undefined
    }
  }
  return (
    <div
      ref={ref}
      className={classNames('module-card', className, { shake: showDelete })}
      onClick={() => !disabledClick && onClick?.()}
      style={style}
      onTouchStart={handleTouchStart}
      onTouchMove={clearTimer}
      onTouchEnd={clearTimer}
    >
      {children}
      {showMask && <div className='module-card-mask' />}
      {title && <div className='module-card-title'>{title}</div>}
      {showDelete && (
        <div className='module-card-icon-wrapper delete' onClick={onDelete}>
          <DtIcon icon={minus} />
        </div>
      )}
      {selected && (
        <div className='module-card-icon-wrapper selected'>
          <DtIcon icon={checkmark} />
        </div>
      )}
    </div>
  )
}

export default BaseCard
