import { useQuery } from '@apollo/client'
import { GetDiscountTagPage } from '@/gqlDocuments/moduleCard'
import { useIonViewWillEnter } from '@ionic/react'
import BaseCard from './BaseCard'
import lightPng from '@/assets/img/card/light/discountLabel.png'
import darkPng from '@/assets/img/card/dark/discountLabel.png'
import translate from '@utils/translate'
import { classNames } from '@dt/fe-base'
import { IModuleCardProps } from './types'
import { useHistory } from 'react-router'
import './index.scss'

export default function DiscountLabelCard(props: IModuleCardProps) {
  const { item, isRefetch, isImg, ...otherProps } = props
  const trans = translate('moduleCard')
  const history = useHistory()
  const isDark = localStorage.getItem('ls.currentTheme') === 'dark'
  const { data, refetch } = useQuery(GetDiscountTagPage, {
    variables: { input: {} },
    fetchPolicy: 'cache-first',
  })
  useIonViewWillEnter(() => {
    isRefetch && refetch()
  })
  return (
    <BaseCard
      {...otherProps}
      title={isImg ? '' : trans('discountLabel')}
      className={classNames({ 'hq-small-common-card': isImg })}
      onClick={() => {
        history.push(item.path!)
      }}
    >
      {isImg ? (
        <img
          src={isDark ? darkPng : lightPng}
          alt='light'
          className='discount-label-card-light'
        />
      ) : (
        <>
          <div className='card-count-container discountLabel'>
            <span className='count'>{data?.GetDiscountTagPage.total}</span>
            {trans('strip')}
          </div>
          <div>{trans('discountLabel')}</div>
        </>
      )}
    </BaseCard>
  )
}
