import { DtIcon } from '@dt/ui-mobile'
import { eleme } from '@dt/ui-ionic-icon'
import { useQuery } from '@apollo/client'
import { GetMergeTakeoutInfo } from '@/gqlDocuments/moduleCard'
import { useIonViewWillEnter } from '@ionic/react'
import lightPng from '@/assets/img/card/light/eleme.png'
import darkPng from '@/assets/img/card/dark/eleme.png'
import BaseCard from './BaseCard'
import translate from '@utils/translate'
import { IModuleCardProps } from './types'
import { useHistory } from 'react-router'
import './index.scss'
import { classNames } from '@dt/fe-base'
export default function ElemeCard(props: IModuleCardProps) {
  const { item, isRefetch, isImg, ...otherProps } = props
  const trans = translate('moduleCard')
  const history = useHistory()
  const isDark = localStorage.getItem('ls.currentTheme') === 'dark'
  const { data, refetch } = useQuery(GetMergeTakeoutInfo, {
    variables: {
      GetTakeoutStoreInfoInput: { channelType: 'eleme' },
      CountRelationProductInput: { channelType: 'eleme' },
    },
    fetchPolicy: 'cache-first',
  })
  useIonViewWillEnter(() => {
    isRefetch && refetch()
  })
  const hasAuth = data?.GetTakeoutStoreInfo.hasAuth
  const isAllAssociated = data?.CountRelationProduct.isAllAssociated
  return (
    <BaseCard
      {...otherProps}
      title={isImg ? '' : trans('elm')}
      className={classNames({ 'hq-small-common-card': isImg })}
      onClick={() => {
        if (hasAuth) {
          history.push('/menu/takeout/productRelation/eleme')
        } else {
          history.push('/mainline/takeoutAuth/eleme')
        }
      }}
    >
      {isImg ? (
        <img
          src={isDark ? darkPng : lightPng}
          alt='light'
          className='eleme-card-light'
        />
      ) : (
        <>
          <DtIcon icon={eleme} className='module-card-eleme-icon' />
          <div>
            {hasAuth === undefined ? (
              ''
            ) : !hasAuth ? (
              trans('goOpen')
            ) : (
              <span
                style={{
                  color: !isAllAssociated ? 'var(--dt-danger)' : undefined,
                }}
                dangerouslySetInnerHTML={{
                  __html: isAllAssociated
                    ? trans('allAssociated')
                    : trans('partAssociated'),
                }}
              />
            )}
          </div>
        </>
      )}
    </BaseCard>
  )
}
