import { useQuery } from '@apollo/client'
import { GetShelfSuCount } from '@/gqlDocuments/moduleCard'
import { useIonViewWillEnter } from '@ionic/react'
import BaseCard from './BaseCard'
import lightPng from '@/assets/img/card/light/food.png'
import darkPng from '@/assets/img/card/dark/food.png'
import translate from '@utils/translate'
import { IModuleCardProps } from './types'
import { useHistory } from 'react-router'
import './index.scss'
import { classNames } from '@dt/fe-base'
export default function FoodCard(props: IModuleCardProps) {
  const { item, isRefetch, isImg, ...otherProps } = props
  const trans = translate('moduleCard')
  const history = useHistory()
  const isDark = localStorage.getItem('ls.currentTheme') === 'dark'
  const { data, refetch } = useQuery(GetShelfSuCount, {
    variables: { input: {} },
    fetchPolicy: 'cache-first',
  })
  useIonViewWillEnter(() => {
    isRefetch && refetch()
  })
  const total = data?.GetShelfSuCount.shelfSuNum
  return (
    <BaseCard
      {...otherProps}
      title={isImg ? '' : trans('foodStorage')}
      className={classNames({ 'hq-small-common-card': isImg })}
      onClick={() => {
        history.replace(item.path!)
      }}
    >
      {isImg ? (
        <img
          src={isDark ? darkPng : lightPng}
          alt='light'
          className='food-card-light'
        />
      ) : (
        <>
          {total === 0 ? (
            <div className='card-empty'>{trans('empty')}</div>
          ) : (
            <div className='card-count-container food'>
              <span className='count'>{total}</span>
              {trans('unit')}
            </div>
          )}
          <div>{trans('food')}</div>
        </>
      )}
    </BaseCard>
  )
}
