import { useQuery } from '@apollo/client'
import { GetMergedPrinterList } from '@/gqlDocuments/moduleCard'
import { useIonViewWillEnter } from '@ionic/react'
import BaseCard from './BaseCard'
import translate from '@utils/translate'
import lightPng from '@/assets/img/card/light/printer.png'
import darkPng from '@/assets/img/card/dark/printer.png'
import { useMemo } from 'react'
import { IModuleCardProps } from './types'
import { useHistory } from 'react-router'
import { DtIcon } from '@dt/ui-mobile'
import { classNames } from '@dt/fe-base'
import { printerColor } from '@dt/ui-ionic-icon'
import './index.scss'

export default function PrinterCard(props: IModuleCardProps) {
  const { item, isRefetch, isImg, ...otherProps } = props
  const trans = translate('moduleCard')
  const history = useHistory()
  const isDark = localStorage.getItem('ls.currentTheme') === 'dark'
  const { data, refetch } = useQuery(GetMergedPrinterList, {
    variables: {
      GetOrderReceiptListInput: { storeId: window.storeInfo?.storeId },
      ListKitchenInput: { storeId: window.storeInfo?.storeId },
    },
    fetchPolicy: 'cache-first',
  })
  useIonViewWillEnter(() => {
    isRefetch && refetch()
  })
  const { bindTotal, unbindTotal } = useMemo(() => {
    if (data) {
      let bindTotal = 0
      let unbindTotal = 0
      data?.GetOrderReceiptList?.forEach((item) => {
        if (item.printer?.address) {
          bindTotal++
        } else {
          unbindTotal++
        }
      })
      data?.ListKitchen?.list?.forEach((o) => {
        o.printerList.forEach((item) => {
          if (item.printer?.address) {
            bindTotal++
          } else {
            unbindTotal++
          }
        })
      })
      return { bindTotal, unbindTotal }
    }
    return {}
  }, [data])
  return (
    <BaseCard
      {...otherProps}
      className={classNames({ 'hq-printer-card': isImg })}
      title={isImg ? '' : trans('printer')}
      onClick={() => {
        history.push(item.path!)
      }}
    >
      {isImg ? (
        <img
          src={isDark ? darkPng : lightPng}
          alt='light'
          className='printer-card-light'
        />
      ) : (
        <>
          <div className='printer-title-wrapper'>
            <DtIcon className='printer-title-icon' icon={printerColor}></DtIcon>
          </div>
          <div className='printer-count'>
            <span className='bind-count'>{bindTotal}</span>
            {trans('bindDeviceCount')}
            <span className='unbind-count'>{unbindTotal}</span>
            {trans('unbindDeviceCount')}
          </div>
        </>
      )}
    </BaseCard>
  )
}
