import { useQuery } from '@apollo/client'
import { GetMergedReason } from '@/gqlDocuments/moduleCard'
import { useIonViewWillEnter } from '@ionic/react'
import BaseCard from './BaseCard'
import lightPng from '@/assets/img/card/light/reason.png'
import darkPng from '@/assets/img/card/dark/reason.png'
import translate from '@utils/translate'
import { useMemo } from 'react'
import { IModuleCardProps } from './types'
import { useHistory } from 'react-router'
import './index.scss'
import { classNames } from '@dt/fe-base'
export default function ReasonCard(props: IModuleCardProps) {
  const { item, isRefetch, isImg, ...otherProps } = props
  const trans = translate('moduleCard')
  const history = useHistory()
  const isDark = localStorage.getItem('ls.currentTheme') === 'dark'
  const { data, refetch } = useQuery(GetMergedReason, {
    variables: { GetRefundReasonInput: {}, GetDiscountReasonInput: {} },
    fetchPolicy: 'cache-first',
  })
  useIonViewWillEnter(() => {
    isRefetch && refetch()
  })
  const reasonList = useMemo(() => {
    if (data) {
      return [
        ...(data.GetRefundReason.items?.map((o) => o.name) ?? []),
        ...(data.GetDiscountReason?.map((o) => o.name) ?? []),
      ].slice(0, 3)
    }
    return []
  }, [data])
  return (
    <BaseCard
      {...otherProps}
      title={isImg ? '' : trans('reason')}
      className={classNames({ 'hq-small-common-card': isImg })}
      onClick={() => {
        history.push(item.path!)
      }}
    >
      {isImg ? (
        <img
          src={isDark ? darkPng : lightPng}
          alt='light'
          className='reason-card-light'
        />
      ) : (
        <div className='reason-list'>
          {(reasonList || []).map((item, index) => (
            <div key={index} className='reason-text'>
              {item}
            </div>
          ))}
        </div>
      )}
    </BaseCard>
  )
}
