import taskMobx from '@mobx/task.mobx'
import storeMobx from '@mobx/store.mobx'
import FoodCard from './FoodCard'
import DiscountLabelCard from './DiscountLabelCard'
import ReasonCard from './ReasonCard'
import PrinterCard from './PrinterCard'
import ReportCard from './ReportCard'
import MeituanCard from './MeituanCard'
import ElemeCard from './ElemeCard'
import { TCardItem } from './types'
import { PermissionSdk } from '@dt/fe-business'
import TaskBar from '../TaskBar'
import SaleTrendCard from './SaleTrendCard'
import ProductSaleCard from './ProductSaleCard'
import AdviserTipCard from './AdviserTipCard'
export { default as BaseCard } from './BaseCard'
export * from './types'

export const cardMap: Record<string, Omit<TCardItem, 'name'>> = {
  saleTrendReport: {
    size: 'large',
    component: SaleTrendCard,
    async validate() {
      return true
    },
  },
  productSaleReport: {
    size: 'large',
    component: ProductSaleCard,
    async validate() {
      return true
    },
  },
  adviserTipReport: {
    size: 'large',
    component: AdviserTipCard,
    async validate() {
      return true
    },
  },
  // 暂时隐藏
  guide: {
    size: 'large',
    component: TaskBar,
    height: 72,
    async validate() {
      if (storeMobx.currentStoreId) {
        await taskMobx.getTaskList()
        return !!taskMobx.unfinishedCnt
      }
      return false
    },
  },
  reason: {
    size: 'small',
    component: ReasonCard,
    path: '/mainline/RefundAndDiscountReason',
    validate: async () => {
      const show: boolean = await PermissionSdk.check(
        'hq.returnFoodRefundReasons',
      )
      if (show) {
        return PermissionSdk.checkModulePermissionKey(
          'hq.returnFoodRefundReasons',
        )
      }
      return show
    },
  },
  discountLabel: {
    size: 'small',
    component: DiscountLabelCard,
    path: '/mainline/discountLabel',
    validate: async () => {
      const show: boolean = await PermissionSdk.check('hq.manualDiscount')
      if (show) {
        return PermissionSdk.checkModulePermissionKey('hq.manualDiscount')
      }
      return show
    },
  },
  food: {
    size: 'small',
    component: FoodCard,
    path: '/menu/product',
    validate: async () => {
      const show: boolean = await PermissionSdk.check('/menu/product')
      if (show) {
        return PermissionSdk.checkModulePermissionKey('/menu/product')
      }
      return show
    },
  },
  printer: {
    size: 'large',
    component: PrinterCard,
    path: '/mainline/printer',
    validate: async () => {
      const show: boolean = await PermissionSdk.check('hq.printer')
      if (show) {
        return PermissionSdk.checkModulePermissionKey('hq.printer')
      }
      return show
    },
  },
  meituan: {
    size: 'small',
    component: MeituanCard,
    validate: async () => {
      const show: boolean = await PermissionSdk.check(
        '/mainline/takeoutAuth/meituan',
      )
      if (show) {
        return PermissionSdk.checkModulePermissionKey(
          '/mainline/takeoutAuth/meituan',
        )
      }
      return show
    },
  },
  eleme: {
    size: 'small',
    component: ElemeCard,
    validate: async () => {
      const show: boolean = await PermissionSdk.check(
        '/mainline/takeoutAuth/eleme',
      )
      if (show) {
        return PermissionSdk.checkModulePermissionKey(
          '/mainline/takeoutAuth/eleme',
        )
      }
      return show
    },
  },
}
