import cardMobx from '@mobx/card.mobx'
import { cardMap } from '../Card'
import { useEffect } from 'react'
import client, { useNewQuery, newMutate } from '@dt/fe-business/client'
import { localStore as store } from '@dt/fe-base'

import {
  GetCurrentUserHomeCard,
  CurrentUserHomeCard,
} from '@/gqlDocuments/newUser'
import { storeMobx } from '@mobx'

export function useCardList() {
  const { data } = useNewQuery(GetCurrentUserHomeCard, {
    variables: {
      input: {
        userId: window?.userInfo?.userId || store.get('ls.userInfo')?.userId,
        brandId:
          window?.brandInfo?.brandId || store.get('ls.brandInfo')?.brandId,
      },
    },
    nextFetchPolicy: 'cache-first',
  })

  useEffect(() => {
    const allList = Object.entries(cardMap)
    Promise.all(
      allList.map(([key, val]) => (val.validate ? val.validate() : true)),
    ).then((res) => {
      const allCards = res.reduce(
        (result, show, index) => {
          const [key, o] = allList[index]
          result[key] = {
            ...o,
            hide: !show,
          }
          return result
        },
        {} as typeof cardMap,
      )
      cardMobx.setAllCards(allCards)
    })
  }, [storeMobx.currentStoreId])

  useEffect(() => {
    if (data) {
      const cardNames = data?.GetCurrentUserHomeCardV3?.cards || [
        'guide',
        'report',
        'food',
      ]
      cardMobx.setCardNames(cardNames)
    }
  }, [data])
}

export async function saveCards() {
  const res = await newMutate(CurrentUserHomeCard, {
    cards: [...cardMobx.cardNames],
    userId: window?.userInfo?.userId || store.get('ls.userInfo')?.userId,
    brandId: window?.brandInfo?.brandId || store.get('ls.brandInfo')?.brandId,
  })
  client.cache.evict({
    id: 'ROOT_QUERY',
    fieldName: 'GetCurrentUserHomeCardV3',
  })
  return res
}
