import React, { Fragment, useEffect } from 'react'
import { storefrontOutline, flagOutline } from 'ionicons/icons'
import { DtIcon, DtProgressBar } from '@dt/ui-mobile'
import i18n from '@dt/fe-base/dist/i18n'
import { guideMobx, storeMobx } from '@mobx'
import { observer } from 'mobx-react'
import { GuideModal } from '@pages/home/modals'
import { useLocation, useHistory } from 'react-router'
import { localStore as store } from '@dt/fe-base'
import { useIonViewDidEnter } from '@ionic/react'
import { BaseCard, IModuleCardProps } from '../Card'
import './index.scss'

const GuideBar = (props: IModuleCardProps) => {
  const _ns = 'guide-bar-container'
  const [storeId, setStoreId] = React.useState<number>()
  const [progress, setProgress] = React.useState(0.5)
  const [showModal, setShowModal] = React.useState(false)
  const { todoCount } = guideMobx
  const location = useLocation<{ from?: string }>()
  const history = useHistory()

  const handToOpen = (url: string) => {
    setShowModal(false)
    history.push(url)
  }

  useEffect(() => {
    if (storeMobx.currentStoreId) {
      guideMobx.getList(true)
      setStoreId(storeMobx.currentStoreId)
    }
  }, [storeMobx.currentStoreId])

  useIonViewDidEnter(() => {
    const storeInfo = window.storeInfo || store.get('ls.storeInfo')
    setStoreId(storeInfo?.storeId)
    setTimeout(() => {
      guideMobx.getList(true)
    }, 500)
  })

  useEffect(() => {
    if (
      location?.state?.from === 'store' &&
      guideMobx.isInit &&
      !guideMobx.todoList.length
    ) {
      setTimeout(() => {
        guideMobx.getList(true)
      }, 2000)
    }
  }, [guideMobx.isInit])
  useEffect(() => {
    setProgress(todoCount.isFinish / todoCount.total)
    if (location?.state?.from === 'store' && todoCount.unFinishRequired) {
      setShowModal(true)
    }
  }, [todoCount])
  return todoCount?.unFinish ? (
    <Fragment>
      <BaseCard
        onClick={() => setShowModal(true)}
        className={_ns}
        style={{ height: 'auto' }}
        {...props}
      >
        <div className={`${_ns}__content`}>
          <div className={`${_ns}__content__img`}>
            <DtIcon icon={storefrontOutline} />
          </div>
          <div className={`${_ns}__content__num`}>
            <div className='title'>{i18n.t('guide.openTitle')}</div>
            <div className='num'>
              {i18n.t('guide.openLeave', { num: todoCount.unFinish })}
            </div>
          </div>
          <div className={`${_ns}__content__progress`}>
            <DtProgressBar
              value={progress}
              color='success'
              className='progress'
            />
            <div
              className='progress-icon'
              style={{ left: `${progress * 100 - 7}%` }}
            >
              <DtIcon icon={flagOutline} />
            </div>
          </div>
        </div>
      </BaseCard>
      {showModal && (
        <GuideModal
          visible={showModal}
          onClose={() => setShowModal(false)}
          onOpen={handToOpen}
        />
      )}
    </Fragment>
  ) : null
}

export default observer(GuideBar)
