import React, { useEffect, useMemo } from 'react'
import { classNames } from '@dt/fe-base'
import { observer } from 'mobx-react'
import { DtIcon } from '@dt/ui-mobile'
import i18n from '@dt/fe-base/dist/i18n'
import { arrowForwardOutline } from 'ionicons/icons'
import { checkmark } from '@dt/ui-ionic-icon'
import './index.scss'
import guideMobx, { ETodoType, todoPathMap } from '@mobx/guide.mobx'

interface IProps {
  data: IToDoList
  step: number
  onOpen?: (url: string) => void
}

const StepContentItem: React.FC<IProps> = ({ data, step, onOpen }) => {
  const _ns = 'step-content-item-container'
  const leaveNum = useMemo(
    () => data.checkList.filter((item) => !item.checkPass).length,
    [data.checkList],
  )
  const handleToSetting = () => {
    const nowSub = data?.checkList?.find((item) => !item.checkPass)
    const path = todoPathMap[nowSub?.subType || 0]
    const url = `${path}?from=guide&tt=${data.todoType}&st=${nowSub?.subType}`
    path && onOpen?.(url)
  }
  return (
    <div className={classNames(_ns, { success: data.finished })}>
      <div className={`${_ns}__icon`}>
        <div className='step-icon'>{step}</div>
        {step !== 1 && <div className='step-split'></div>}
      </div>
      <div className={`${_ns}__content`}>
        <div className={`${_ns}__content__name`}>
          <div className={classNames('name', { required: data.required })}>
            {data.name}
          </div>
        </div>
      </div>
      <div className={`${_ns}__content`}>
        {data.finished ? (
          <DtIcon icon={checkmark} className='success-icon' color='success' />
        ) : (
          <div className={`${_ns}__content__num`} onClick={handleToSetting}>
            <span>{i18n.t('guide.leaveNum', { num: leaveNum })}</span>
            <DtIcon icon={arrowForwardOutline} />
          </div>
        )}
      </div>
    </div>
  )
}

export default observer(StepContentItem)
