import React, { Fragment, useEffect } from 'react'
import { storefrontOutline, flagOutline } from 'ionicons/icons'
import { DtIcon, DtProgressBar } from '@dt/ui-mobile'
import i18n from '@dt/fe-base/dist/i18n'
import { observer } from 'mobx-react'
import { useLocation, useHistory } from 'react-router'
import { useIonViewDidEnter } from '@ionic/react'
import { BaseCard, IModuleCardProps } from '../Card'
import taskMobx from '@mobx/task.mobx'
import './index.scss'

const TaskBar = (props: IModuleCardProps) => {
  const _ns = 'guide-bar-container'
  const [progress, setProgress] = React.useState(0.5)
  const location = useLocation<{ from?: string }>()
  const history = useHistory()

  useIonViewDidEnter(() => {
    setTimeout(() => {
      taskMobx.getTaskList()
    }, 500)
  })
  useEffect(() => {
    setProgress(taskMobx.finishedCnt / (taskMobx.taskList.length || 1))
    if (location?.state?.from === 'store' && taskMobx.unfinishedCnt) {
      history.push('/task')
    }
  }, [taskMobx.unfinishedCnt])

  return taskMobx.unfinishedCnt ? (
    <BaseCard
      onClick={() => history.push('/task/home')}
      className={_ns}
      style={{ height: 'auto' }}
      {...props}
    >
      <div className={`${_ns}__content`}>
        <div className={`${_ns}__content__img`}>
          <DtIcon icon={storefrontOutline} />
        </div>
        <div className={`${_ns}__content__num`}>
          <div className='title'>{i18n.t('task.title')}</div>
          <div className='num'>
            {i18n.t('guide.openLeave', { num: taskMobx.unfinishedCnt })}
          </div>
        </div>
        <div className={`${_ns}__content__progress`}>
          <DtProgressBar
            value={progress}
            color='success'
            className='progress'
          />
          <div
            className='progress-icon'
            style={{ left: `${progress * 100 - 7}%` }}
          >
            <DtIcon icon={flagOutline} />
          </div>
        </div>
      </div>
    </BaseCard>
  ) : null
}

export default observer(TaskBar)
