import { FC, useEffect, useMemo, useRef, useState } from 'react'
import { DtContent, DtIcon } from '@dt/ui-mobile'
import { observer } from 'mobx-react'
import { appMobx, deviceMobx, storeMobx } from '@mobx'
import { init } from '@init'
import { PageWrapper } from '@cps'
import CardList from './components/CardList'
import {
  DtBusinessNavHeader,
  DtTaskMask,
  ITaskMaskProps,
} from '@dt/ui-mobile-business'
import i18n from '@dt/fe-base/dist/i18n'
import { useHistory } from 'react-router'
import { menuOutline } from 'ionicons/icons'
import taskMobx from '@mobx/task.mobx'
import { useIonViewDidEnter } from '@ionic/react'
import './index.scss'

const Home: FC = () => {
  const _ns = 'page-home-wrapper'
  const history = useHistory()
  const nativeTestClickRef = useRef(0)
  /** 展示任务弹窗 */
  const [isOpenTask, setIsOpenTask] = useState(false)
  const taskOptions = useMemo(() => {
    if (!taskMobx.targetTask) {
      return {
        isOpen: false,
        steps: [],
      }
    }
    return {
      isOpen: true,
      // 容器的id
      parentId: 'home-page-wrapper',
      nextType: 'touchChild',
      onClose: () => {
        setIsOpenTask(false)
      },
      steps: [
        {
          // 菜单按钮 classname
          target: '#home-page-wrapper ion-menu-button.in-toolbar',
          popover: {
            content: (
              <h2>
                {i18n.t('task.click')}
                <DtIcon icon={menuOutline} />
                {i18n.t('task.openMenu')}
              </h2>
            ),
            offset: 10,
          },
          targetId: 'home-menu-btn',
          padding: 0,
          handle: () => {
            ;(
              document?.querySelector('ion-menu-button.in-toolbar') as any
            )?.click()
            setIsOpenTask(false)
          },
        },
      ],
    }
  }, [taskMobx.targetTask])

  const initTask = (isEnter: boolean) => {
    if (taskMobx.targetTask) {
      setIsOpenTask(true)
    } else {
      setIsOpenTask(false)
    }
  }
  useIonViewDidEnter(() => {
    initTask(true)
  })
  useEffect(() => {
    initTask(false)
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [taskMobx.targetTask])

  useEffect(() => {
    if (!appMobx.inited) {
      init()
    }
  })

  return (
    <PageWrapper className={`${_ns}`} id='home-page-wrapper'>
      <DtBusinessNavHeader
        showExtra={storeMobx.isInit && !deviceMobx.deviceInfo?.deviceId}
        selectOptions={{
          showType: 'store',
        }}
        title={i18n.t('menu.home')}
        leftType='menu'
      />
      <DtContent>
        <div className='home-content-wrapper'>
          <CardList></CardList>
          <div className='edit-btn-text-container'>
            <span
              className='edit-btn-text'
              onClick={() => history.push('/home/edit')}
            >
              {i18n.t('home.editCard')}
            </span>
          </div>
          <div
            className='to-native-test'
            onClick={() => {
              nativeTestClickRef.current++
              if (nativeTestClickRef.current >= 10) {
                nativeTestClickRef.current = 0
                history.push('/nativeTest')
              }
            }}
          ></div>
        </div>
      </DtContent>
      {isOpenTask && <DtTaskMask {...(taskOptions as ITaskMaskProps)} />}
    </PageWrapper>
  )
}

export default observer(Home)
