import { useEffect, useState } from 'react'
import { Modal } from '@dt/ui-mobile'
import { observer } from 'mobx-react'
import cardMobx from '@mobx/card.mobx'
import translate from '@utils/translate'
import { classNames } from '@dt/fe-base'
import i18n from '@dt/fe-base/dist/i18n'
import '../../components/CardList/index.scss'
import './index.scss'

type TAddCardModalProps = {
  isOpen: boolean
  onClose: () => void
}

function AddCardModal(props: TAddCardModalProps) {
  const { isOpen, onClose } = props
  const trans = translate('home')
  const [selectedList, setSelectedList] = useState<string[]>([])
  const selects = new Set(selectedList)
  useEffect(() => {
    if (!isOpen) {
      setSelectedList([])
    }
  }, [isOpen])
  return (
    <Modal.PageModal
      className='card-modal'
      isOpen={isOpen}
      title={trans('addCard')}
      onClose={onClose}
      autoHeight={false}
      headerOptions={{
        leftIconClick: onClose,
        extra: (
          <span
            className='confirm-btn'
            onClick={() => {
              cardMobx.addCards(selectedList)
              onClose()
            }}
          >
            {i18n.t('common.confirm')}
            {selectedList.length ? ` (${selectedList.length})` : ''}
          </span>
        ),
      }}
    >
      <div className='card-modal-content'>
        <div className='module-card-container'>
          {cardMobx.group.unaddedCardList.map((item) => {
            const Compoent = item.component
            const selected = selects.has(item.name)
            return (
              <div
                key={item.name}
                className={classNames(
                  `item-card-wrapper ${item.name} ${item.size}`,
                  { hide: item.hide },
                )}
                onClick={() => {
                  if (selected) {
                    selects.delete(item.name)
                  } else {
                    selects.add(item.name)
                  }
                  setSelectedList([...selects])
                }}
              >
                <Compoent
                  key={item.name}
                  item={item}
                  disabledClick
                  selected={selected}
                  isImg={true}
                />
              </div>
            )
          })}
        </div>
      </div>
    </Modal.PageModal>
  )
}

export default observer(AddCardModal)
