import React, { useEffect } from 'react'
import {
  Button,
  DtContent,
  DtFooter,
  DtModal,
  DtNavHeader,
} from '@dt/ui-mobile'
import i18n from '@dt/fe-base/dist/i18n'
import { guideMobx } from '@mobx'
import { observer } from 'mobx-react'
import { StepContent } from '@pages/home/components'
import { todoPathMap } from '@mobx/guide.mobx'
import './index.scss'

interface IProps {
  visible: boolean
  onClose?: () => void
  onOpen?: (url: string) => void
}

const GuideModal: React.FC<IProps> = ({ visible, onClose, onOpen }) => {
  const _ns = 'guide-modal-container'
  const modalRef = React.useRef<any>(null)
  const { todoList } = guideMobx
  useEffect(() => {
    guideMobx.getList()
  }, [])

  const handleToSetting = () => {
    const nowTodo = todoList.find((item) => !item.finished)
    const nowSub = nowTodo?.checkList?.find((item) => !item.checkPass)
    const path = todoPathMap[nowSub?.subType || 0]
    const url = `${path}?from=guide&tt=${nowTodo?.todoType}&st=${nowSub?.subType}`
    path && onOpen?.(url)
  }
  return (
    <DtModal
      ref={modalRef}
      isOpen={visible}
      className={_ns}
      onDidDismiss={onClose}
    >
      <DtNavHeader
        leftType='modal'
        leftIconClick={() => modalRef.current?.dismiss()}
      >
        {i18n.t('guide.openTitle')}
      </DtNavHeader>
      <DtContent className={`${_ns}__content`}>
        <StepContent onOpen={onOpen} />
      </DtContent>
      <div className='guide-desc'>{i18n.t('guide.settingDesc')}</div>
      <DtFooter className={`${_ns}__footer`}>
        <Button usetype='primary' size='small' onClick={handleToSetting}>
          {i18n.t('common.toSetting')}
        </Button>
      </DtFooter>
    </DtModal>
  )
}

export default observer(GuideModal)
