import React, {
  useContext,
  useEffect,
  useLayoutEffect,
  useRef,
  useCallback,
} from 'react'
import { useNotifications, useNovu } from '@novu/react/hooks'
import { DtContent, DtLoading } from '@dt/ui-mobile'
import { debounce } from '@dt/fe-base/dist/lodash'
import { IonContentCustomEvent, ScrollDetail } from '@ionic/core'
import MessageItem from '../MessageItem'
import { MessageContext } from '../../context'

interface IProps {}

function CustomInBox(props: IProps) {
  const { type } = useContext(MessageContext)

  const novu = useNovu()

  const { notifications, hasMore, isFetching, fetchMore, refetch } =
    useNotifications({
      read: type === 'all' ? undefined : false,
    })

  const loadingRef = useRef<HTMLIonLoadingElement>(null)
  const contentRef = useRef<HTMLIonContentElement>(null)

  const handleScroll = useCallback(
    debounce(async (e: IonContentCustomEvent<ScrollDetail>) => {
      const target = e.target as HTMLElement
      const isBottom =
        Math.abs(target.scrollHeight - target.scrollTop - target.clientHeight) <
        1

      if (isBottom && hasMore && !isFetching) {
        fetchMore()
      }
    }, 100),
    [hasMore, isFetching, fetchMore],
  )

  useEffect(() => {
    const _refetch = () => {
      contentRef.current?.scrollToTop(0)
      refetch()
    }
    const cleanup = novu.on('notifications.notification_received', _refetch)
    const cleanup2 = novu.on('notifications.unread_count_changed', _refetch)

    return () => {
      cleanup()
      cleanup2()
    }
  }, [novu, refetch])

  useLayoutEffect(() => {
    if (isFetching) {
      loadingRef.current?.present()
    } else {
      loadingRef.current?.dismiss()
    }
  }, [isFetching])

  return (
    <DtContent ref={contentRef} scrollEvents={true} onIonScroll={handleScroll}>
      <DtLoading ref={loadingRef} key={type} duration={5000} />
      {notifications?.map((notification) => {
        const read = () => {
          notification.read()
        }

        return (
          <MessageItem key={notification.id} {...notification} read={read} />
        )
      })}
    </DtContent>
  )
}

export default CustomInBox
