import React, { useContext } from 'react'

import { DtChip, DtIcon, DtPopover } from '@dt/ui-mobile'
import { caretDownOutlined, checkmark } from '@dt/ui-ionic-icon'
import i18n from '@dt/fe-base/dist/i18n'
import './index.scss'
import { MessageContext } from '../../context'

const DropDownBar: React.FC = () => {
  const { type, setType } = useContext(MessageContext)

  return (
    <>
      <DtChip
        className='hq-message-popover-trigger'
        id='message-popover-trigger'
      >
        {type === 'all' ? i18n.t('message.all') : i18n.t('message.unread')}
        <DtIcon icon={caretDownOutlined} />
      </DtChip>

      <DtPopover
        className='hq-message-popover'
        trigger='message-popover-trigger'
        side='bottom'
        alignment='end'
        dismissOnSelect={true}
      >
        <div className='hq-message-popover-item' onClick={() => setType('all')}>
          <div className='hq-message-popover-item-icon'>
            {type === 'all' && <DtIcon icon={checkmark} />}
          </div>
          <div>
            <span>{i18n.t('message.all')}</span>
          </div>
        </div>
        <div
          className='hq-message-popover-item'
          onClick={() => setType('unread')}
        >
          <div className='hq-message-popover-item-icon'>
            {type === 'unread' && <DtIcon icon={checkmark} />}
          </div>
          <div>
            <span>{i18n.t('message.unread')}</span>
          </div>
        </div>
      </DtPopover>
    </>
  )
}

export default DropDownBar
