import { DtItemBlock, DtIcon } from '@dt/ui-mobile'
import { chevronRight } from '@dt/ui-ionic-icon'
import { dayjs } from '@dt/fe-base'
import i18n from '@dt/fe-base/dist/i18n'
import { useHistory } from 'react-router-dom'
import './index.scss'

const _ns = 'hq-message-item-container'

interface IMessageItemProps {
  id: string
  subject?: string
  body: string
  isRead: boolean
  createdAt: string | Date
  data?: any
  read: () => any
}

export default function MessageItem(props: IMessageItemProps) {
  const { isRead, subject, id, body, createdAt, data } = props
  const history = useHistory()
  return (
    <DtItemBlock
      className={_ns}
      key={id}
      onClick={() => {
        !isRead && props.read()
        if (data?.url) {
          history?.push(data?.url)
        }
      }}
    >
      <div className={`${_ns}-header`}>
        <div className={`${_ns}-header-left`}>
          {!isRead && <div className={`${_ns}-header-unread`}></div>}
          <div className={`${_ns}-header-title`}>{subject}</div>
        </div>
        <div className={`${_ns}-header-right`}>
          {dayjs(createdAt).format('YYYY/MM/DD')}
        </div>
      </div>
      <div className={`${_ns}-body`}>{body}</div>
      {data?.url && (
        <div className={`${_ns}-detail`}>
          <div className={`${_ns}-detail-text`}>
            {i18n.t('common.lookDetail')}
          </div>
          <DtIcon icon={chevronRight} />
        </div>
      )}
    </DtItemBlock>
  )
}
