import { useEffect, useRef } from 'react'
import { Permissions } from '@dt/fe-capacitor'
import { toastLayer } from '@dt/ui-mobile'
import i18n from '@dt/fe-base/dist/i18n'
import { close } from '@dt/ui-ionic-icon'

export const useToastMange = () => {
  const layerRef = useRef<HTMLIonToastElement | null>(null)

  const onClose = () => {
    layerRef.current?.dismiss()
    layerRef.current = null
  }

  useEffect(() => {
    const checkPermission = async () => {
      const permission = await Permissions.check('notice', false)

      if (permission !== 'granted') {
        const toast = await toastLayer.info({
          cssClass: 'message-setting-toast',
          message: i18n.t('message.setting'),
          duration: 3000,

          buttons: [
            {
              text: i18n.t('message.open'),

              handler: () => {
                Permissions.check('notice')
                onClose()
              },
            },
            {
              icon: close,
              handler: onClose,
            },
          ],
        })
        layerRef.current = toast
      }
    }
    checkPermission()

    return () => {
      if (layerRef.current) {
        layerRef.current.dismiss()
        layerRef.current = null
      }
    }
  }, [])
}
