import React, { useEffect, useRef } from 'react'
import { DtContent, DtIcon } from '@dt/ui-mobile'
import { observer } from 'mobx-react'
import guideMobx from '@/mobx/guide.mobx'
import { guideSuccessColor } from '@dt/ui-ionic-icon'
import { DtGuideWrapper } from '@dt/ui-mobile-business'
import i18n from '@dt/fe-base/dist/i18n'
import { getParams } from '@dt/fe-base/dist/url'
import './index.scss'
import { useIonViewDidEnter } from '@ionic/react'
import { useHistory } from 'react-router-dom'

interface IProps {
  visible: boolean
  onClose?: () => void
  onOk?: () => void
}

const PosOrderModal: React.FC<IProps> = () => {
  const _ns = 'dt-mainline-guide-success-page-container'
  const guideRef = useRef<any>(null)
  const { tt: todoType, st: subType } = getParams({ url: window.location.href })
  const { todoTypeToMap } = guideMobx
  const todoData = todoTypeToMap[todoType]
  const history = useHistory()

  useIonViewDidEnter(() => {
    guideMobx.getList()
  })

  return (
    <DtGuideWrapper
      className={_ns}
      history={history}
      ref={guideRef}
      headerProps={{
        leftType: 'back',
      }}
    >
      <DtContent className={`${_ns}__content`}>
        <div className='success-content'>
          <div className='success-icon'>
            <DtIcon icon={guideSuccessColor} />
          </div>
          <div className='success-title'>{i18n.t('guide.goodJobTips')}</div>
          <div className='success-sub'>
            {i18n.t('guide.successConfigTips', { name: todoData?.name })}
          </div>
          <div className='success-tips'>
            <div className='tip-title'>{i18n.t('guide.toTestOrder')}</div>
            <div className='tip'>{i18n.t('guide.orderTips1')}</div>
            <div className='tip'>{i18n.t('guide.orderTips2')}</div>
            <div className='tip'>{i18n.t('guide.orderTips3')}</div>
            <div className='tip'>{i18n.t('guide.orderTips4')}</div>
          </div>
        </div>
      </DtContent>
    </DtGuideWrapper>
  )
}

export default observer(PosOrderModal)
