import i18n from '@dt/fe-base/dist/i18n'
import { useEffect, useState } from 'react'
import { brandMobx, storeMobx, appMobx } from '@mobx'
import {
  DtContent,
  DtIcon,
  DtItemCard,
  DtNavHeader,
  Modal,
  Button,
} from '@dt/ui-mobile'
import { localStore as store } from '@dt/fe-base'
import { observer } from 'mobx-react'
import { Clipboard, Browser } from '@dt/fe-capacitor'
import { chevronRight } from '@dt/ui-ionic-icon'
import { useHistory } from 'react-router-dom'
import { DtBusinessAvatar } from '@dt/ui-mobile-business'
import { PermissionSdk } from '@dt/fe-business'
import './index.scss'
import { useIonViewDidEnter } from '@ionic/react'

const eshineUrl = 'http://hq.eshine.cn'

function SelectBrand() {
  const _ns = 'page-select-brand-wrapper'

  const history = useHistory()
  useIonViewDidEnter(() => {
    const initBrand = async () => {
      if (appMobx.prePath.includes('/login')) {
        await brandMobx.getBrandList(true, { notRefresh: true })
      } else {
        await brandMobx.getBrandList(false, { notRefresh: true })
      }
    }

    initBrand()
  })

  useEffect(() => {
    const handleStore = async () => {
      if (
        brandMobx.brandList.length === 1 &&
        appMobx.prePath.includes('/login')
      ) {
        await storeMobx.justUpdateList()
        if (storeMobx.storeList.length === 0) {
          store.set('ls.isSelectedBrand', 1)
          history.replace('/home')
        } else {
          let prevStoreId = (await brandMobx.getPrevLoginBrandRecordNew(
            brandMobx.currentBrandId!,
          )) as number
          if (!prevStoreId) {
            prevStoreId =
              storeMobx.storeList.find((i) => i.status === 'enable')?.storeId ||
              storeMobx.storeList[0].storeId
          }
          window.Config.storeId = prevStoreId as number
          const res = await storeMobx.setCurrentStore(prevStoreId)
          appMobx.setPageLoading(false)
          if (res) {
            store.set('ls.isSelectedBrand', 1)

            history.replace('/home')
            brandMobx.reload()
            // setTimeout(() => {
            //   location.reload()
            // }, 200)
          }
        }
      }
    }

    handleStore()
  }, [brandMobx.brandList.length])
  return (
    <>
      <DtNavHeader
        hideBtn={appMobx.prePath.includes('/login')}
        confirmText={i18n.t('brand.addBrand')}
        showConfirm
        onConfirmClick={() => {
          brandMobx.setBrandEdit(false)
          history.push('/brand')
        }}
      >
        {i18n.t('store.plChooseBrand')}
      </DtNavHeader>
      <DtContent className={`${_ns}-content`}>
        <div>
          {brandMobx.brandList.map((br) => {
            return (
              <DtItemCard key={br.brandId} type='list'>
                <DtItemCard.Header
                  className='select-brand-list'
                  onClick={async () => {
                    try {
                      if (br.brandId === brandMobx.currentBrandId) {
                        if (storeMobx.currentStoreId) {
                          history.goBack()
                        } else {
                          history.replace('/store')
                        }
                        return
                      }
                      appMobx.setPageLoading(true)
                      const resp = await brandMobx.switchBrand({
                        token: store.get('ls.authorization')?.accessToken,
                        newBrandId: br.brandId!,
                        notRefresh: true,
                        noCheck: true,
                      })
                      brandMobx.setBrandInfo(br, true, false)
                      if (!resp) {
                        appMobx.setPageLoading(false)
                        return
                      }

                      storeMobx.clear()

                      // 有门店直接进入
                      if (br.storeCnt > 0) {
                        await storeMobx.justUpdateList()

                        let prevStoreId =
                          (await brandMobx.getPrevLoginBrandRecordNew(
                            br.brandId,
                          )) as number

                        console.log('prev', prevStoreId)
                        if (!prevStoreId) {
                          prevStoreId =
                            storeMobx.storeList.find(
                              (i) => i.status === 'enable',
                            )?.storeId || storeMobx.storeList[0].storeId
                        }
                        window.Config.storeId = prevStoreId as number

                        const res = await storeMobx.setCurrentStore(prevStoreId)
                        appMobx.setPageLoading(false)
                        if (res) {
                          store.set('ls.isSelectedBrand', 1)

                          history.replace('/home')
                          brandMobx.reload()
                          // setTimeout(() => {
                          //   location.reload()
                          // }, 200)
                        }
                        return
                      } else {
                        appMobx.setPageLoading(false)
                        storeMobx.sendFinishChangeStore()
                        // 创建门店
                        store.set('ls.isSelectedBrand', 1)
                        history.push('/store')
                        brandMobx.reload()
                        // setTimeout(() => {
                        //   location.reload()
                        // }, 200)
                      }
                    } catch (error) {
                      appMobx.setPageLoading(false)
                    }
                  }}
                  prefix={<DtBusinessAvatar url={br.logo || ''} />}
                  extra={
                    <div className='brand-store-choose'>
                      {i18n.t('store.storeNum', { num: br.storeCnt })}
                      <DtIcon icon={chevronRight} />
                    </div>
                  }
                >
                  {br.brandName}
                  {br.dataSource === 'oldPos' && (
                    <span className='old'>{i18n.t('brand.oldSys')}</span>
                  )}
                </DtItemCard.Header>
              </DtItemCard>
            )
          })}
        </div>
        <Modal.ConfirmModal
          title={i18n.t('common.info')}
          isOpen={brandMobx.oldPosNoBrandModal}
          autoHeight
          headerOptions={{ hideBtn: true }}
          onClose={() => brandMobx.updateOldPosNoBrandModal(false)}
        >
          <div className={`${_ns}_modal-message`}>
            <div>{i18n.t('brand.noBrand')}</div>
            <div>
              {i18n.t('brand.plLink')}
              <span
                onClick={() => {
                  Browser.open({
                    url: eshineUrl,
                  })
                }}
              >
                {eshineUrl}
              </span>
              {i18n.t('brand.createAbout')}
            </div>
          </div>
          <div className={`${_ns}_btn-group`}>
            <Button
              size='small'
              colorOptions={{ textColor: '#7a7a7a' }}
              usetype='text'
              onClick={() => {
                brandMobx.updateOldPosNoBrandModal(false)
                history.replace('/login')
              }}
            >
              {i18n.t('common.cancel')}
            </Button>
            <Button
              size='small'
              usetype='primary'
              onClick={() => {
                Clipboard.write({ string: eshineUrl })
              }}
            >
              {i18n.t('brand.copy')}
            </Button>
          </div>
        </Modal.ConfirmModal>
      </DtContent>
    </>
  )
}

export default observer(SelectBrand)
