import React, { useEffect, useMemo, useState } from 'react'
import { DtContent, DtHeader, DtIcon, DtProgressBar } from '@dt/ui-mobile'
import { observer } from 'mobx-react'
import { useIonViewDidEnter } from '@ionic/react'
import { closeOutline } from 'ionicons/icons'
import { PageWrapper } from '@cps'
import TaskItem from './components/TaskItem'
import taskMobx from '@mobx/task.mobx'
import { map } from '@dt/fe-base/dist/lodash'
import './index.scss'
import i18n from '@dt/fe-base/dist/i18n'
import { useHistory, useParams } from 'react-router'
import { useSafeArea } from '@common/hooks'
import { Capacitor } from '@dt/fe-capacitor'
import { storeMobx } from '@mobx'

interface IProps {
  visible: boolean
  onClose?: () => void
  onOk?: () => void
}

const Task: React.FC<IProps> = () => {
  const _ns = 'dt-mobile-main-task-page-container'
  const history = useHistory()
  const progress = useMemo(() => {
    return taskMobx.finishedCnt / taskMobx.taskList.length
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [taskMobx.finishedCnt, taskMobx.taskList.length])
  const { from } = useParams<{ from?: string }>()
  const [paddingTop, setPaddingTop] = useState('')
  const [safeArea] = useSafeArea()

  const handleBack = () => {
    history.replace('/home')
  }

  useIonViewDidEnter(() => {
    taskMobx.getTaskList()
  })

  useEffect(() => {
    taskMobx.getTaskList()
  }, [storeMobx.currentStoreId])

  useEffect(() => {
    Capacitor.getPlatform() !== 'web' &&
      setPaddingTop(safeArea?.top ? safeArea?.top + 'px' : '')
  }, [safeArea])

  return (
    <PageWrapper className={_ns}>
      <DtHeader className={`${_ns}__header`} style={{ paddingTop }}>
        <div className='close-btn' onClick={handleBack}>
          <DtIcon icon={closeOutline} />
        </div>
        <div className='title'>{i18n.t('task.title')}</div>
        <div className='progress'>
          <DtProgressBar
            value={progress}
            color='success'
            className='progress'
          />
          <div className='progress-cnt'>
            {taskMobx.finishedCnt}/{taskMobx.taskList.length}
          </div>
        </div>
      </DtHeader>
      <DtContent className={`${_ns}__content`}>
        <div className='task-content'>
          {map(taskMobx.taskList, (item) => {
            return <TaskItem from={from} key={item.type} item={item} />
          })}
        </div>
      </DtContent>
    </PageWrapper>
  )
}

export default observer(Task)
