import { App, Camera } from '@dt/fe-capacitor'
import { CameraResultType, CameraSource } from '@dt/fe-capacitor/dist/Camera'
import { CommonApi } from '@api'

/** 系统相机 */
async function getPhotoToSystem(source: CameraSource) {
  // Take a photo
  const capturedPhoto = await Camera.getPhoto({
    resultType: CameraResultType.DataUrl,
    source,
    allowEditing: false,
    quality: 100,
  })
  return capturedPhoto
}

/** 系统相册 */
async function getPhotoFromGallery() {
  // Take a photo
  const capturedPhoto = await Camera.getPhoto({
    resultType: CameraResultType.Uri,
    source: CameraSource.Photos,
    quality: 100,
  })
  console.log(capturedPhoto)
  return capturedPhoto
}

async function uploadFile(file: Blob, fileType: string = 'jpg') {
  console.log(file, 'file', fileType, 'fileType')
  // 将 Blob 转换为文件并保存到临时目录
  const fileName = 'temp-image.' + fileType
  // 准备 FormData
  const formData = new FormData()
  formData.append('brandId', window.storeInfo?.brandId?.toString() || '')
  formData.append(
    'file',
    new Blob([file], { type: 'image/' + fileType }),
    fileName,
  )

  console.log(formData, 'formData')
  const res: any = await CommonApi.upload(formData)
  return res
}

/**
 * 上传图片
 * @returns { url: string type: 'img' | 'video' }
 */
export const upload = async (channel?: CameraSource) => {
  let path: any
  let fileType: string
  if (App.getPlatform() === 'web') {
    const res = await getPhotoFromGallery()
    console.log(res, 'web')
    path = res.webPath
    fileType = res.format
  } else {
    const res = await getPhotoToSystem(channel || CameraSource.Photos)
    console.log(res, 'noweb')
    path = res.dataUrl
    fileType = res.format
  }
  const response = await fetch(path)
  console.log(response)
  const blob = await response.blob()

  try {
    const fileData: {
      url: string
      type: 'img' | 'video'
    } = await uploadFile(blob, fileType)
    console.log('图片上传服务器 ===>', fileData, 'uploadImage')
    return fileData
  } catch (error) {
    console.error('上传图片失败', error)
    return []
  }
}

/**
 * 判断文件类型
 * @param filePath 文件路径
 * @returns
 */
export function getFileType(filePath: string): 'img' | 'video' | undefined {
  // 定义图片和视频的扩展名
  const imageExtensions = ['jpg', 'jpeg', 'png', 'gif', 'bmp', 'svg']
  const videoExtensions = ['mp4', 'mov', 'wmv', 'flv', 'avi', 'mkv', 'webm']

  // 使用正则表达式提取文件扩展名
  // eslint-disable-next-line no-useless-escape
  const extensionMatch = filePath.match(/\.([0-9a-z]+)(?:[\?#]|$)/i)
  if (extensionMatch && extensionMatch[1]) {
    const extension = extensionMatch[1].toLowerCase()

    // 判断扩展名是否属于图片或视频
    if (imageExtensions.includes(extension)) {
      return 'img'
    } else if (videoExtensions.includes(extension)) {
      return 'video'
    }
  }

  // 如果扩展名既不是图片也不是视频，则返回'unknown'
  return undefined
}
