import { App } from '@dt/fe-capacitor'
import MQTTClient from './'
import { getDeviceId } from '@utils/device'

export default class Task {
  static brandId: string | number
  static storeId: string | number
  static bo: string
  static deviceId: string
  static token: string
  static initialized: boolean
  /**
   * 初始化
   */
  static async init({
    domain,
    token,
    brandId,
    deviceId,
    storeId,
  }: {
    domain: string
    token: string
    brandId: string
    deviceId?: string
    storeId: string
  }) {
    try {
      this.token = token
      this.brandId = brandId
      this.storeId = storeId
      console.log('init', { domain, brandId, storeId })
      if (!App.isNativePlatform()) {
        console.info('non-real environment, not initialized')
        return false
      }
      this.deviceId = deviceId || (await getDeviceId('rms'))
      MQTTClient.init({
        token,
        url: domain,
        clientId: `s-${storeId}-d-${this.deviceId}`,
      })
      this.initialized = true
      await MQTTClient.connect().catch((e) => {
        console.log('init failed', e)
      })
      console.log('init successful')
      return true
    } catch (error) {
      return false
    }
  }
}
