import { MQTT, MQTTCallback } from '@capacitor-eshine/mqtt'
import { App } from '@dt/fe-capacitor'

export default class TCPMQTT {
  private port
  private qos
  private keepAlive
  private clientId
  private url
  private token

  constructor(url: string, clientId: string, token: string, port?: number) {
    this.port = 1883
    this.qos = 2
    this.keepAlive = 30
    console.info('new TCPMQTT')
    if (App.getPlatform() === 'android') {
      this.url = 'tcp://' + url
    } else {
      this.url = url
    }
    port && (this.port = port)
    this.clientId = clientId
    this.token = token
  }
  // 连接mq
  connect(callback: MQTTCallback) {
    return MQTT.connect(
      {
        url: this.url,
        port: this.port,
        clientId: this.clientId,
        userName: this.token,
        password: '',
        keepAlive: this.keepAlive,
        cleanSession: true,
      },
      callback,
    )
  }
  // 断开连接
  disconnect() {
    return MQTT.disconnect()
  }
  // 订阅消息
  subscribe(topic: string) {
    return MQTT.subscribe({ topic, qos: this.qos })
  }
  // 发送消息
  publish(topic: string, payload: any) {
    return MQTT.publish({ topic, payload, qos: this.qos })
  }
  // 取消订阅
  unsubscribe(topic: string) {
    return MQTT.unsubscribe({ topic })
  }
}
