interface IStoreProps {
  storeId?: number // Unique identifier for the store
  brandId?: number // Identifier of the associated brand
  storeName?: string | null // Name of the store (currently empty)
  logo?: string // URL or path to the store's logo (currently empty)
  tel?: string // Telephone number of the store (currently empty)
  mobile?: string // Mobile contact number (currently empty)
  state?: string // State where the store is located (currently empty)
  county?: string // County, in this case, it's "浙江省"
  city?: string // City where the store is, here it's "杭州市"
  address?: string // Full address of the store
  addressDetail?: string | null
  cityCode?: string // Code representing the city (currently empty)
  lbsLng?: string // Longitude coordinate for location-based services
  lbsLat?: string // Latitude coordinate for location-based services
  status?: string // Status of the store, e.g., "enable", "disable"
  remark?: string // Additional remarks about the store (currently empty)
  storeNumber?: string // Store's unique number (currently empty)
  isPosAll?: boolean // Flag indicating if all items are for POS (Point of Sale), true in this case
  autoSoldOut?: number // Configuration for auto marking items as sold out, value here is 0
  isPlate?: boolean // Indicates if the store uses plates, false here
  isPlateRequired?: boolean // Specifies if plate usage is required, also false
  id?: string // Another identifier, possibly a database primary key, with a value of "9"
}

interface IStoreBusinessTime {
  loopMethod?: 'day' | 'week'
  id?: string
  isPosAll?: boolean
  /** 时间类型 */
  configMethod?: 'day' | 'week'
  /** 周一 */
  monday: IDate[]
  /** 周二 */
  tuesday: IDate[]
  /** 周三 */
  wednesday: IDate[]
  /** 周四 */
  thursday: IDate[]
  /** 周五 */
  friday: IDate[]
  /** 周六 */
  saturday: IDate[]
  /** 周日 */
  sunday: IDate[]
}

type TWeekday =
  | 'monday'
  | 'tuesday'
  | 'wednesday'
  | 'thursday'
  | 'friday'
  | 'saturday'
  | 'sunday'
